@@ -38,7 +38,6 @@ extern GtkWidget *mainnotebook;
 extern statetype state;
 extern preferencestype preferences;
 extern GList *logwindowlist;
-extern gchar **modesplit, **bandsplit;
 
 /* a row is selected, update the qso frame */
 void
@@ -49,7 +48,7 @@ on_log_select_row (GtkTreeSelection *selection, gpointer user_data)
 		*incheckbutton, *powerentry, *nameentry, *qthentry, *locatorentry,
 		*unknownentry1, *unknownentry2, *modeoptionmenu, *bandoptionmenu,
 		*qsoframe, *framelabel;
-	gchar *frametext, *bandcopy, *entry;
+	gchar *frametext, *bandcopy, *entry, **bandspl, **modespl;
 	guint i, page, bandindex = 0, modeindex = 0;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
@@ -110,40 +109,45 @@ on_log_select_row (GtkTreeSelection *selection, gpointer user_data)
 		gtk_tree_model_get (model, &iter, BAND, &entry, -1);
 		gtk_entry_set_text (GTK_ENTRY (bandentry), entry);
 
-		bandsplit = g_strsplit (preferences.bands, ",", 0);
+		bandspl = g_strsplit (preferences.bands, ",", 0);
 		if (strlen (entry) <= 2)
 			bandcopy = g_strdup (entry);
 		else
 			bandcopy = g_strdup(finddot (entry));
+
 		for (;;)
+		{
+			if (!bandspl[bandindex])
+				break;
+			if (g_ascii_strcasecmp (bandcopy, bandspl[bandindex]) == 0)
 			{
-				if (!bandsplit[bandindex])
-					break;
-				if (g_ascii_strcasecmp (bandcopy, bandsplit[bandindex]) == 0)
-					{
-						gtk_option_menu_set_history (GTK_OPTION_MENU (bandoptionmenu), bandindex);
-						break;
-					}
-				bandindex++;
+				gtk_combo_box_set_active (GTK_COMBO_BOX (bandoptionmenu), 
+					bandindex);
+				break;
 			}
+			bandindex++;
+		}
 		g_free (bandcopy);
+		g_strfreev (bandspl);
 
 		/* update modeoptionmenu and entry */
 		gtk_tree_model_get (model, &iter, MODE, &entry, -1);
 		gtk_entry_set_text (GTK_ENTRY (modeentry), entry);
 
-		modesplit = g_strsplit (preferences.modes, ",", 0);
+		modespl = g_strsplit (preferences.modes, ",", 0);
 		for (;;)
-			{
-				if (!modesplit[modeindex])
+		{
+			if (!modespl[modeindex])
+				break;
+			if (g_ascii_strcasecmp (entry, modespl[modeindex]) == 0)
+				{
+					gtk_combo_box_set_active (GTK_COMBO_BOX (modeoptionmenu), 
+						modeindex);
 					break;
-				if (g_ascii_strcasecmp (entry, modesplit[modeindex]) == 0)
-					{
-						gtk_option_menu_set_history (GTK_OPTION_MENU (modeoptionmenu), modeindex);
-						break;
-					}
-				modeindex++;
-			}
+				}
+			modeindex++;
+		}
+		g_strfreev (modespl);
 
 		gtk_tree_model_get (model, &iter, POWER, &entry, -1);
 		gtk_entry_set_text (GTK_ENTRY (powerentry), entry);
