@@ -21,9 +21,10 @@
  * callbacks_mainwindow_menu.h
  */
 
+void on_menu_log_activate (GtkAction *action, gpointer user_data);
 void on_menu_exit_activate (GtkMenuItem * menuitem, gpointer user_data);
 void on_menu_save_activate (GtkMenuItem * menuitem, gpointer user_data);
 void on_clearframe_activate (GtkMenuItem * menuitem, gpointer user_data);
 void on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data);
-void on_view_toolbar_activate (GtkMenuItem *menuitem, gpointer user_data);
+void on_view_toolbar_activate (GtkAction *action, gpointer user_data);
 void on_sort_log_activate (GtkMenuItem *menuitem, gpointer user_data);
