@@ -50,11 +50,11 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 	GtkWidget *dateentry, *gmtentry, *callentry, *rstentry, *myrstentry,
 		*remarksentry, *bandentry, *modeentry, *bandoptionmenu,
 		*modeoptionmenu, *incheckbutton, *outcheckbutton,
-		*qsoframe, *menu, *active_item, *endhbox, *endentry, *powerhbox,
+		*qsoframe, *endhbox, *endentry, *powerhbox,
 		*powerentry, *namehbox, *nameentry, *qthhbox, *qthentry,
 		*locatorhbox, *locatorentry, *unknown1hbox, *unknownentry1,
 		*unknown2hbox, *unknownentry2, *qslhbox, *remarksvbox, *framelabel;
-	gchar *temp, *logfile;
+	gchar *temp;
 	gint bandindex, modeindex, i = 0, page;
 	logtype *logw = NULL;
 	GtkTreeIter iter, selected;
@@ -83,19 +83,15 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		qso[CALL] = gtk_editable_get_chars (GTK_EDITABLE (callentry), 0, -1);
 		if (preferences.bandseditbox == 0)
 		{
-			menu = GTK_OPTION_MENU (bandoptionmenu)->menu;
-			active_item = gtk_menu_get_active (GTK_MENU (menu));
-			bandindex = g_list_index (GTK_MENU_SHELL (menu)->children, active_item);
-			qso[BAND] = lookup_band (bandsplit[bandindex]);
+			bandindex = gtk_combo_box_get_active (GTK_COMBO_BOX(bandoptionmenu));
+			qso[BAND] = lookup_band (bandindex);
 		}
 		else
 			qso[BAND] = gtk_editable_get_chars (GTK_EDITABLE (bandentry), 0, -1);
 		if (preferences.modeseditbox == 0)
 		{
-			menu = GTK_OPTION_MENU (modeoptionmenu)->menu;
-			active_item = gtk_menu_get_active (GTK_MENU (menu));
-			modeindex = g_list_index (GTK_MENU_SHELL (menu)->children, active_item);
-			qso[MODE] = lookup_mode (modesplit[modeindex]);
+			modeindex = gtk_combo_box_get_active (GTK_COMBO_BOX(modeoptionmenu));
+			qso[MODE] = lookup_mode (modeindex);
 		}
 		else
 			qso[MODE] = gtk_editable_get_chars (GTK_EDITABLE (modeentry), 0, -1);
@@ -214,8 +210,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 
 		if (preferences.saving == 2)
 		{
-			logfile = g_strconcat (preferences.savedir, G_DIR_SEPARATOR_S, logw->logname, ".xlog", NULL);
-			savelog (logw, logfile, TYPE_FLOG, 1, logw->qsos);
+			savelog (logw, logw->filename, TYPE_FLOG, 1, logw->qsos);
 			logw->logchanged = FALSE;
 			temp = g_strdup_printf (_("QSO %s added to %s log, log saved"), qso[NR], logw->logname);
 		}
@@ -246,21 +241,21 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 		*modeentry, *rstentry, *myrstentry, *remarksentry, *powerentry,
 		*nameentry, *qthentry, *unknownentry1, *unknownentry2,
 		*locatorentry, *incheckbutton, *outcheckbutton;
-	gchar *statustext, *qsonumber, *logfile;
+	gchar *statustext, *qsonumber;
 	gint i, page;
-	logtype *logwindow;
+	logtype *logw;
 	GtkTreeIter selected, iter;
 	GtkTreeModel *model;
  
 	page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mainnotebook));
-	logwindow = g_list_nth_data (logwindowlist, page);
+	logw = g_list_nth_data (logwindowlist, page);
 
 	if (page >= 0)
 	{
-		if (gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW(logwindow->treeview)), &model, &selected))
+		if (gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW(logw->treeview)), &model, &selected))
 		{
 			gtk_tree_model_get (model, &selected, NR, &qsonumber, -1);
-			statustext = g_strdup_printf (_("QSO %s deleted, %s log renumbered"), qsonumber, logwindow->logname);
+			statustext = g_strdup_printf (_("QSO %s deleted, %s log renumbered"), qsonumber, logw->logname);
 			update_statusbar (statustext);
 			g_free (statustext);
 
@@ -299,19 +294,19 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 
 			/* now remove the QSO from the log */
 			gtk_tree_store_remove (GTK_TREE_STORE (model), &selected);
-			logwindow->qsos--;
+			logw->qsos--;
 
 			if (preferences.saving != 2)
 			{
-				logwindow->logchanged = TRUE;
-				gtk_label_set_text (GTK_LABEL (logwindow->label),	g_strconcat (logwindow->logname, " *", NULL));
+				logw->logchanged = TRUE;
+				gtk_label_set_text (GTK_LABEL (logw->label),	g_strconcat (logw->logname, " *", NULL));
 			}
 
 			/* update the first column with the number of qso's */
 			gtk_tree_model_get_iter_first (model, &iter);
-			for (i = 0; i < logwindow->qsos; i++)
+			for (i = 0; i < logw->qsos; i++)
 			{
-				qsonumber = g_strdup_printf ("%d", logwindow->qsos - i);
+				qsonumber = g_strdup_printf ("%d", logw->qsos - i);
 				gtk_tree_store_set (GTK_TREE_STORE(model), &iter, NR, qsonumber, -1); 
 				g_free (qsonumber);
 				if (!(i % 50)) /* needed for responsiveness */
@@ -326,9 +321,8 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 
 			if (preferences.saving == 2)
 			{
-				logfile = g_strconcat (preferences.savedir, G_DIR_SEPARATOR_S, logwindow->logname, ".xlog", NULL);
-				savelog (logwindow, logfile, TYPE_FLOG, 1, logwindow->qsos);
-				logwindow->logchanged = FALSE;
+				savelog (logw, logw->filename, TYPE_FLOG, 1, logw->qsos);
+				logw->logchanged = FALSE;
 			}
 		}
 	}
@@ -341,14 +335,14 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 {
 	GtkWidget *dateentry, *gmtentry, *callentry, *rstentry, *myrstentry,
 		*remarksentry, *bandentry, *modeentry, *incheckbutton,
-		*outcheckbutton, *modeoptionmenu, *bandoptionmenu, *menu,
-		*active_item, *qsoframe, *endhbox, *endentry, *powerhbox,
+		*outcheckbutton, *modeoptionmenu, *bandoptionmenu,
+		*qsoframe, *endhbox, *endentry, *powerhbox,
 		*powerentry, *namehbox, *nameentry, *qthhbox, *qthentry,
 		*locatorhbox, *locatorentry, *unknown1hbox, *unknownentry1,
 		*unknown2hbox, *unknownentry2, *qslhbox, *remarksvbox, *gmtbutton,
 		*framelabel;
 	gint bandindex, modeindex, i = 0, page;
-	gchar *statustext, *logfile;
+	gchar *statustext;
 	logtype *logw;
 	GtkTreeIter selected;
 	GtkTreeModel *model;
@@ -385,10 +379,8 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			}
 			else
 			{
-				menu = GTK_OPTION_MENU (bandoptionmenu)->menu;
-				active_item = gtk_menu_get_active (GTK_MENU (menu));
-				bandindex = g_list_index (GTK_MENU_SHELL (menu)->children, active_item);
-				qso[BAND] = lookup_band (bandsplit[bandindex]);
+				bandindex = gtk_combo_box_get_active (GTK_COMBO_BOX(bandoptionmenu));
+				qso[BAND] = lookup_band (bandindex);
 			}
 
 			if (preferences.modeseditbox == 1)
@@ -397,10 +389,8 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			}
 			else
 			{
-				menu = GTK_OPTION_MENU (modeoptionmenu)->menu;
-				active_item = gtk_menu_get_active (GTK_MENU (menu));
-				modeindex = g_list_index (GTK_MENU_SHELL (menu)->children, active_item);
-				qso[MODE] = lookup_mode (modesplit[modeindex]);
+				modeindex = gtk_combo_box_get_active (GTK_COMBO_BOX(modeoptionmenu));
+				qso[MODE] = lookup_mode (modeindex);
 			}
 
 			powerhbox = lookup_widget (mainwindow, "powerhbox");
@@ -512,8 +502,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 
 			if (preferences.saving == 2)
 			{
-				logfile = g_strconcat (preferences.savedir, G_DIR_SEPARATOR_S, logw->logname, ".xlog", NULL);
-				savelog (logw, logfile, TYPE_FLOG, 1, logw->qsos);
+				savelog (logw, logw->filename, TYPE_FLOG, 1, logw->qsos);
 				logw->logchanged = FALSE;
 				statustext = g_strdup_printf (_("QSO %s updated in %s log, log saved"),	qso[NR], logw->logname);
 			}
