@@ -44,8 +44,6 @@
 extern GtkWidget *mainwindow;
 extern preferencestype preferences;
 extern statetype state;
-extern gchar **bandsplit;
-extern gchar **modesplit;
 extern GtkWidget *preferencesdialog;
 extern gint clocktimer, savetimer;
 extern GList *logwindowlist;
@@ -79,15 +77,13 @@ set_autosave (gint value, gint saving)
 	else if (saving == 1 && preferences.saving != 1)
 	{
 		savetimer =
-			gtk_timeout_add (value * 60 * 1000,
-					 (GtkFunction) autosave, NULL);
+			g_timeout_add (value * 60 * 1000, (GSourceFunc) autosave, NULL);
 	}
 	else if (value != preferences.autosave)
 	{			/* new value, stop and start timer */
 		g_source_remove (savetimer);
 		savetimer =
-			gtk_timeout_add (value * 60 * 1000,
-					 (GtkFunction) autosave, NULL);
+			g_timeout_add (value * 60 * 1000, (GSourceFunc) autosave, NULL);
 	}
 	preferences.autosave = value;
 	preferences.saving = saving;
@@ -196,7 +192,7 @@ set_clock (gboolean on)
 	if (on)
 	{			/* yes, we want clock */
 		if (preferences.clock == 0)
-			clocktimer = gtk_timeout_add (1000, (GtkFunction) updateclock, NULL);
+			clocktimer = g_timeout_add (1000, (GSourceFunc) updateclock, NULL);
 		gtk_widget_show (clockhandlebox);
 		preferences.clock = 1;
 	}
@@ -212,7 +208,7 @@ set_clock (gboolean on)
 
 #if WANT_HAMLIB
 /* check if hamlib has changed */
-static gboolean hamlib_changed ( gint hamlibwidgets, gchar *radio, gchar *device, 
+static gboolean hamlib_changed (gint hamlibwidgets, gchar *radio, gchar *device, 
 	gint polltime, gchar *rigconf)
 {
 
@@ -237,10 +233,10 @@ static gboolean hamlib_changed ( gint hamlibwidgets, gchar *radio, gchar *device
 void
 on_preferencesokbutton_clicked (GtkButton * button, gpointer user_data)
 {
-	GtkWidget *latentry, *longentry, *NScomboentry, *EWcomboentry,
-		*unitscomboentry, *bandsentry, *bandoptionmenu, *modesentry,
+	GtkWidget *latentry, *longentry, *NScombo, *EWcombo,
+		*unitscombo, *bandsentry, *bandoptionmenu, *modesentry,
 		*modeoptionmenu, *bandsradiobutton1, *modesradiobutton1,
-		*clockcheckbutton, *examplelabel, *autosavecomboentry,
+		*clockcheckbutton, *examplelabel, *autosavecombo,
 		*themecheckbutton, *pathentry, *logsentry, *qthlocatorentry,
 		*callsignentry, *fontentry, *bandentry, *modeentry,
 		*savecheckbutton, *autosavecheckbutton, *typeaheadfindcheckbutton, 
@@ -249,9 +245,9 @@ on_preferencesokbutton_clicked (GtkButton * button, gpointer user_data)
 	gboolean toggletrue, logcoloryesno;
 	gint autosavevalue, saving;
 #if WANT_HAMLIB
-	GtkWidget *hamlibcheckbutton, *radiocomboentry, *devicecomboentry,
-		*frequencycheckbutton, *digitscomboentry, *smetercheckbutton,
-		*pollcomboentry, *pollingcheckbutton, *rigsetconfentry;
+	GtkWidget *hamlibcheckbutton, *radiocombo, *devicecombo,
+		*frequencycheckbutton, *digitscombo, *smetercheckbutton,
+		*pollcombo, *pollingcheckbutton, *rigsetconfentry;
 	gchar *radio = NULL, *device = NULL, *digits = NULL, *pollstr = NULL,
 		*rigconf = NULL;
 	gboolean hamlibyes, frequencyyesno, smeteryesno, pollingyes;
@@ -272,10 +268,10 @@ on_preferencesokbutton_clicked (GtkButton * button, gpointer user_data)
 		saving = 2;
 	else
 		saving = 0;
-	autosavecomboentry =
-		lookup_widget (preferencesdialog, "autosavecomboentry");
-	temp = gtk_editable_get_chars (GTK_EDITABLE (autosavecomboentry), 0,
-							 -1);
+	autosavecombo =
+		lookup_widget (preferencesdialog, "autosavecombo");
+	temp = gtk_editable_get_chars (GTK_EDITABLE (GTK_BIN(autosavecombo)->child),
+		0, -1);
 	autosavevalue = atoi (temp);
 	set_autosave (autosavevalue, saving);
 
@@ -334,10 +330,9 @@ on_preferencesokbutton_clicked (GtkButton * button, gpointer user_data)
 	/* set latitude, longitude and units */
 	latentry = lookup_widget (preferencesdialog, "latentry");
 	longentry = lookup_widget (preferencesdialog, "longentry");
-	NScomboentry = lookup_widget (preferencesdialog, "NScomboentry");
-	EWcomboentry = lookup_widget (preferencesdialog, "EWcomboentry");
-	unitscomboentry =
-		lookup_widget (preferencesdialog, "unitscomboentry");
+	NScombo = lookup_widget (preferencesdialog, "NScombo");
+	EWcombo = lookup_widget (preferencesdialog, "EWcombo");
+	unitscombo = lookup_widget (preferencesdialog, "unitscombo");
 	temp = gtk_editable_get_chars (GTK_EDITABLE (latentry), 0, -1);
 	g_strstrip (temp);
 	if (strlen (temp) == 0)
@@ -350,50 +345,34 @@ on_preferencesokbutton_clicked (GtkButton * button, gpointer user_data)
 		preferences.longitude = 0.0;
 	else
 		preferences.longitude = atof (temp);
-	temp = gtk_editable_get_chars (GTK_EDITABLE (NScomboentry), 0, 1);
-	if (g_ascii_strncasecmp (temp, _("N"), 1) == 0)
-		preferences.NS = 1;
-	else
-		preferences.NS = 2;
-	temp = gtk_editable_get_chars (GTK_EDITABLE (EWcomboentry), 0, 1);
-	if (g_ascii_strncasecmp (temp, _("E"), 1) == 0)
-		preferences.EW = 1;
-	else
-		preferences.EW = 2;
-	temp = gtk_editable_get_chars (GTK_EDITABLE (unitscomboentry), 0, -1);
-	if (g_ascii_strncasecmp (temp, "K", 1) == 0)
-		preferences.units = 1;
-	else
-		preferences.units = 0;
+
+	preferences.NS = gtk_combo_box_get_active (GTK_COMBO_BOX (NScombo)) + 1;
+	preferences.EW = gtk_combo_box_get_active (GTK_COMBO_BOX (EWcombo)) + 1;
+	preferences.units = gtk_combo_box_get_active 
+		(GTK_COMBO_BOX (unitscombo))  == 1 ? 0 : 1;
+
 	state.mylocation = setlocation (preferences.latitude, preferences.NS,
-					preferences.longitude,
-					preferences.EW);
+		preferences.longitude, preferences.EW);
 
 	/* get the comma seperated list of modes and assign 
 	 * to the optionmenu */
 	modesentry = lookup_widget (preferencesdialog, "modesentry");
-	modeoptionmenu = lookup_widget (mainwindow, "modeoptionmenu");
 	temp = gtk_editable_get_chars (GTK_EDITABLE (modesentry), 0, -1);
-	modesplit = g_strsplit (temp, ",", 0);
-	deletespaces (modesplit);
-	updateoptionmenu (modeoptionmenu, modesplit);
+	makemodeoptionmenu (temp);
+	preferences.modes = g_strdup (temp);
 
 	/* get the comma seperated list of bands and assign to the optionmenu */
 	bandsentry = lookup_widget (preferencesdialog, "bandsentry");
-	bandoptionmenu = lookup_widget (mainwindow, "bandoptionmenu");
 	temp = gtk_editable_get_chars (GTK_EDITABLE (bandsentry), 0, -1);
-	bandsplit = g_strsplit (temp, ",", 0);
-	deletespaces (bandsplit);
-	updateoptionmenu (bandoptionmenu, bandsplit);
-
-	preferences.modes = g_strjoinv (",", modesplit);
-	preferences.bands = g_strjoinv (",", bandsplit);
+	makebandoptionmenu (temp);
+	preferences.bands = g_strdup (temp);
 
 	/* set visibility of widgets in QSO frame depending on 
 	 * state of toggle buttons */
 	bandsradiobutton1 =
 		lookup_widget (preferencesdialog, "bandsradiobutton1");
 	bandentry = lookup_widget (mainwindow, "bandentry");
+	bandoptionmenu = lookup_widget (mainwindow, "bandoptionmenu");
 	toggletrue =
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
 								(bandsradiobutton1));
@@ -412,6 +391,7 @@ on_preferencesokbutton_clicked (GtkButton * button, gpointer user_data)
 	modesradiobutton1 =
 		lookup_widget (preferencesdialog, "modesradiobutton1");
 	modeentry = lookup_widget (mainwindow, "modeentry");
+	modeoptionmenu = lookup_widget (mainwindow, "modeoptionmenu");
 	toggletrue =
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON
 								(modesradiobutton1));
@@ -438,13 +418,10 @@ on_preferencesokbutton_clicked (GtkButton * button, gpointer user_data)
 		lookup_widget (preferencesdialog, "smetercheckbutton");
 	pollingcheckbutton =
 		lookup_widget (preferencesdialog, "pollingcheckbutton");
-	radiocomboentry =
-		lookup_widget (preferencesdialog, "radiocomboentry");
-	devicecomboentry =
-		lookup_widget (preferencesdialog, "devicecomboentry");
-	digitscomboentry =
-		lookup_widget (preferencesdialog, "digitscomboentry");
-	pollcomboentry = lookup_widget (preferencesdialog, "pollcomboentry");
+	radiocombo = lookup_widget (preferencesdialog, "radiocombo");
+	devicecombo = lookup_widget (preferencesdialog, "devicecombo");
+	digitscombo = lookup_widget (preferencesdialog, "digitscombo");
+	pollcombo = lookup_widget (preferencesdialog, "pollcombo");
 	rigsetconfentry = lookup_widget (preferencesdialog, "rigsetconfentry");
 
 	hamlibyes = gtk_toggle_button_get_active
@@ -455,42 +432,40 @@ on_preferencesokbutton_clicked (GtkButton * button, gpointer user_data)
 		(GTK_TOGGLE_BUTTON (smetercheckbutton));
 	pollingyes = gtk_toggle_button_get_active
 		(GTK_TOGGLE_BUTTON (pollingcheckbutton));
-	radio = gtk_editable_get_chars (GTK_EDITABLE (radiocomboentry), 0,
-					-1);
-	device = gtk_editable_get_chars (GTK_EDITABLE (devicecomboentry), 0,
-					 -1);
-	digits = gtk_editable_get_chars (GTK_EDITABLE (digitscomboentry), 0,
-					 -1);
-
-	if (!pollingyes)
+	radio = gtk_editable_get_chars
+		(GTK_EDITABLE (GTK_BIN(radiocombo)->child), 0,	-1);
+	device = gtk_editable_get_chars
+		(GTK_EDITABLE (GTK_BIN(devicecombo)->child), 0, -1);
+	digits = gtk_editable_get_chars
+		(GTK_EDITABLE (GTK_BIN(digitscombo)->child), 0, -1);
+	if (pollingyes)
+		pollstr = gtk_editable_get_chars 
+			(GTK_EDITABLE (GTK_BIN(pollcombo)->child), 0, -1);
+	else
 		pollstr = g_strdup ("0");
-	else
-		pollstr =	gtk_editable_get_chars (GTK_EDITABLE (pollcomboentry), 0, -1);
-
 	rigconf = gtk_editable_get_chars (GTK_EDITABLE (rigsetconfentry), 0, -1);
-	if ( strlen(rigconf) == 0 )
-		rigconf = g_strdup ("?");
+	if (strlen(rigconf) == 0) rigconf = g_strdup ("?");
 
-	if (!hamlibyes)
-		hamlibwidgets = 0;
-	else
+	if (hamlibyes)
 		hamlibwidgets =	whichhamlibwidgets (frequencyyesno, smeteryesno);
+	else
+		hamlibwidgets = 0;
+
 	if (smeteryesno)
 		sethamlibwidgets (hamlibwidgets, TRUE);
 	else
 		sethamlibwidgets (hamlibwidgets, FALSE);
 
+	/* hamlib should be started or restarted because settings have changed */
 	if (hamlib_changed (hamlibwidgets, radio, device, atoi(pollstr), rigconf))
 	{
 		if (preferences.hamlib > 0) stop_hamlib ();
 		preferences.rigconf = g_strdup (rigconf);
 		hamlibresult = start_hamlib (radio, device, RIG_DEBUG_NONE, atoi (pollstr));
-		if (hamlibresult)
-		{
-			preferences.radio = g_strdup (radio);
-			preferences.device = g_strdup (device);
-			preferences.polltime = atoi (pollstr);
-		}
+		preferences.radio = g_strdup (radio);
+		preferences.device = g_strdup (device);
+		preferences.polltime = atoi (pollstr);
+		preferences.round = atoi (digits);
 	}
 	else
 	{
@@ -505,8 +480,13 @@ on_preferencesokbutton_clicked (GtkButton * button, gpointer user_data)
 			preferences.polltime = 0;
 		}
 	}
-	preferences.round = atoi (digits);
 	preferences.hamlib = hamlibwidgets;
+
+		g_free (digits);
+	g_free (pollstr);
+	g_free (radio);
+	g_free (device);
+	g_free (rigconf);
 #endif
 
 	/* clock */
