@@ -28,7 +28,6 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <sys/types.h>
-#include <sys/wait.h>
 #include <string.h>
 #include <gtk/gtk.h>
 #include <libgnomeprint/gnome-print.h>
@@ -50,15 +49,17 @@ extern GList *logwindowlist;
 #define LEFTMARGIN	40
 #define BOTTOMMARGIN	40
 #define TOPMARGIN		60
+#define CSPACING	1.0
 
-/* calculate number of characters in a column for the next 30 or 50 QSO's */
+/* calculate width of a column for the next 30 or 50 QSO's */
 gint 
-colwidth (gpointer arg, gint column, gint firstqso, gint printorientation)
+colwidth (gpointer arg, gint column, gint firstqso, gint printorientation,
+	GnomeFont *f, GnomeFont *bf)
 {
 	GtkTreeIter iter;
 	GtkTreeModel *model;
 	GtkTreePath *path;
-	gint i, lastqso, width = 0;
+	gint i, lastqso, width = 0, savedwidth;
 	gchar *pathstr, *it;
 	logtype *logwindow = (logtype *) arg;
 
@@ -71,52 +72,58 @@ colwidth (gpointer arg, gint column, gint firstqso, gint printorientation)
 
 	/* make sure the header fits */
 	if (column == NR)
-		width = strlen ("Nr");
+		width = gnome_font_get_width_utf8 (bf, "Nr");
 	else if (column == DATE)
-		width = strlen ("Date");
+		width = gnome_font_get_width_utf8 (bf, "Date");
 	else if (column == GMT)
-		width = strlen ("GMT");
+		width = gnome_font_get_width_utf8 (bf, "GMT");
 	else if (column == GMTEND)
-		width = strlen ("END");
+		width = gnome_font_get_width_utf8 (bf, "END");
 	else if (column == CALL)
-		width = strlen ("Callsign");
+		width = gnome_font_get_width_utf8 (bf, "Callsign");
 	else if (column == BAND)
-		width = strlen ("MHz");
+		width = gnome_font_get_width_utf8 (bf, "MHz");
 	else if (column == MODE)
-		width = strlen ("Mode");
+		width = gnome_font_get_width_utf8 (bf, "Mode");
 	else if (column == RST)
-		width = strlen ("TX");
+		width = gnome_font_get_width_utf8 (bf, "TX");
 	else if (column == MYRST)
-		width = strlen ("RX");
+		width = gnome_font_get_width_utf8 (bf, "RX");
 	else if (column == QSLOUT)
-		width = strlen ("Out");
+		width = gnome_font_get_width_utf8 (bf, "Out");
 	else if (column == QSLIN)
-		width = strlen ("In");
+		width = gnome_font_get_width_utf8 (bf, "In");
 	else if (column == POWER)
-		width = strlen ("Pwr");
+		width = gnome_font_get_width_utf8 (bf, "Pwr");
 	else if (column == NAME)
-		width = strlen ("Name");
+		width = gnome_font_get_width_utf8 (bf, "Name");
 	else if (column == QTH)
-		width = strlen ("QTH");
+		width = gnome_font_get_width_utf8 (bf, "QTH");
 	else if (column == LOCATOR)
-		width = strlen ("Locator");
+		width = gnome_font_get_width_utf8 (bf, "Locator");
 	else if (column == U1)
-		width = strlen (preferences.freefield1);
+		width = gnome_font_get_width_utf8 (bf, preferences.freefield1);
 	else if (column == U2)
-		width = strlen (preferences.freefield1);
+		width = gnome_font_get_width_utf8 (bf, preferences.freefield1);
 	else if (column == REMARKS)
-		width = strlen ("Remarks");
+		width = gnome_font_get_width_utf8 (bf, "Remarks");
 	else
 		width = 4;
 
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW(logwindow->treeview));
+	savedwidth = width;
 	for (i = firstqso; i >= lastqso; i--)
 	{
 		pathstr = g_strdup_printf("%d", i);
 		path = gtk_tree_path_new_from_string (pathstr);
 		gtk_tree_model_get_iter (model, &iter, path);
 		gtk_tree_model_get (model, &iter, column, &it, -1);
-		width = strlen (it) > width ? strlen (it) : width;
+		if (column == CALL)
+			width = gnome_font_get_width_utf8 (bf, it) > width
+				? gnome_font_get_width_utf8 (bf, it) : width;
+		else
+			width = gnome_font_get_width_utf8 (f, it) > width
+				? gnome_font_get_width_utf8 (f, it) : width;
 		g_free (pathstr);
 	}
 	return width;
@@ -126,7 +133,7 @@ void
 on_printokbutton_clicked (GtkButton * button, gpointer user_data)
 {
 	GtkWidget *printallradiobutton, *printrangeradiobutton, *printlowentry,
-		*printhighentry, *sizecomboentry, *pointcomboentry, *orientationcomboentry,
+		*printhighentry, *papersizecombo, *pointsizecombo, *orientationcombo,
 		*filedestinationradiobutton, *printerdestinationradiobutton, 
 		*contestcheckbutton;
 	GtkWidget *p1, *p2, *p3, *p4, *p5, *p6, *p7, *p8, *p9, *p10,
@@ -141,8 +148,8 @@ on_printokbutton_clicked (GtkButton * button, gpointer user_data)
 	gint wnr = 100, wdate = 100, wgmt = 100, wgmtend = 100, wcall = 100, wband = 100,
 		wmode = 100, wrst = 100, wmyrst = 100, wqslout = 100,	wqslin = 100, wpower = 100,
 		wname = 100, wqth = 100, wlocator = 100, wu1 = 100, wu2 = 100, wremarks = 100;
-	double left, top, saved, pwidth, pheight, fheight, fwidth;
-	gboolean contest;
+	double left, top, saved, pwidth, pheight, fheight, ws;
+	gboolean contest, result = FALSE;
 	logtype *logwindow;
 	GtkTreeIter iter;
 	GtkTreeModel *model;
@@ -157,13 +164,13 @@ on_printokbutton_clicked (GtkButton * button, gpointer user_data)
 		lookup_widget (printdialog, "printrangeradiobutton");
 	printlowentry = lookup_widget (printdialog, "printlowentry");
 	printhighentry = lookup_widget (printdialog, "printhighentry");
-	sizecomboentry = lookup_widget (printdialog, "sizecomboentry");
-	pointcomboentry = lookup_widget (printdialog, "pointcomboentry");
+	papersizecombo = lookup_widget (printdialog, "papersizecombo");
+	pointsizecombo = lookup_widget (printdialog, "pointsizecombo");
 	filedestinationradiobutton = 
 		lookup_widget (printdialog, "filedestinationradiobutton");
 	printerdestinationradiobutton = 
 		lookup_widget (printdialog, "printerdestinationradiobutton");
-	orientationcomboentry = lookup_widget (printdialog, "orientationcomboentry");
+	orientationcombo = lookup_widget (printdialog, "orientationcombo");
 	contestcheckbutton = lookup_widget (printdialog, "contestcheckbutton");
 
 	/* toggle buttons */
@@ -242,14 +249,16 @@ on_printokbutton_clicked (GtkButton * button, gpointer user_data)
 	printlow = atoi (temp);
 	temp = gtk_editable_get_chars (GTK_EDITABLE (printhighentry), 0, -1);
 	printhigh = atoi (temp);
-	temp = gtk_editable_get_chars (GTK_EDITABLE (sizecomboentry), 0, -1);
 
+	temp = gtk_editable_get_chars
+		(GTK_EDITABLE (GTK_BIN(papersizecombo)->child), 0, -1);
 	if (g_ascii_strcasecmp (temp, "a4") == 0)
 		preferences.printsize = 0;
 	else
 		preferences.printsize = 1;
 
-	temp = gtk_editable_get_chars (GTK_EDITABLE (pointcomboentry), 0, -1);
+	temp = gtk_editable_get_chars
+		(GTK_EDITABLE (GTK_BIN(pointsizecombo)->child), 0, -1);
 	if (g_ascii_strcasecmp (temp, "10") == 0)
 		preferences.printpoint = 0;
 	else if (g_ascii_strcasecmp (temp, "11") == 0)
@@ -274,7 +283,8 @@ on_printokbutton_clicked (GtkButton * button, gpointer user_data)
 	else
 		preferences.printdestination = 1;
 
-	temp = gtk_editable_get_chars (GTK_EDITABLE (orientationcomboentry), 0, -1);
+	temp = gtk_editable_get_chars
+		(GTK_EDITABLE (GTK_BIN(orientationcombo)->child), 0, -1);
 	if (g_ascii_strcasecmp (temp, _("portrait")) == 0)
 		preferences.printorientation = 0;
 	else
@@ -310,14 +320,15 @@ on_printokbutton_clicked (GtkButton * button, gpointer user_data)
 
 	logwindow = g_list_nth_data (logwindowlist,	gtk_notebook_get_current_page (GTK_NOTEBOOK(mainnotebook)));
 	item = g_new0 (gchar *, QSO_FIELDS);
+	psfile = g_strconcat (xlogdir, G_DIR_SEPARATOR_S, "log.ps", NULL);
 
 	/* configure printing */
 	job = gnome_print_job_new (NULL);
 	config = gnome_print_job_get_config (job);
-	gnome_print_config_set (config, "Printer", "GENERIC");
-	gnome_print_config_set (config, GNOME_PRINT_KEY_PAPER_SIZE, papersize);
+	result = gnome_print_config_set (config, "Printer", "GENERIC");
+	result = gnome_print_config_set (config, GNOME_PRINT_KEY_PAPER_SIZE, 
+		papersize);
 	/* page size needed to calculate text position */
-	psfile = g_strconcat (xlogdir, G_DIR_SEPARATOR_S, "log.ps", NULL);
 	if (preferences.printdestination == 1)
 		gnome_print_job_print_to_file (job, psfile);
 	/* libgnomeprint fallback does not work for me */
@@ -328,25 +339,19 @@ on_printokbutton_clicked (GtkButton * button, gpointer user_data)
 		font = gnome_font_find_closest ("Helvetica", atoi(fontsize));
 	if (!font)
 		font = gnome_font_find_closest ("Times", atoi(fontsize));
-	if (!font)
-		font = gnome_font_find_closest ("Sans Regular", atoi(fontsize));
 
 	/* font width and height needed to calculate text position */
 	gpc = gnome_print_job_get_context (job);
+	if (!gpc) g_error ("Error getting print context");
 	gnome_print_config_get_page_size (config, &pwidth, &pheight);
 	if (font)
-	{
 		fheight = gnome_font_get_ascender (font) + gnome_font_get_descender (font);
-		fwidth = gnome_font_get_width_utf8 (font, "#");
-	}
 	else
-	{
 		fheight = atoi (fontsize);
-		fwidth = fheight * 0.8;
-	}
 
 	bfont = gnome_font_find_closest ("Sans Bold", atoi (fontsize));
 	ifont = gnome_font_find_closest ("Sans Italic", atoi (fontsize));
+	ws = gnome_font_get_width_utf8 (font, "  ");
 
 	if (preferences.printall == 0)
 	{
@@ -382,140 +387,140 @@ on_printokbutton_clicked (GtkButton * button, gpointer user_data)
 				}
 				saved = top;
 				top = top + 3 * fheight;
-				/* print header and calculate widths */
+				/* print header and calculate widths for every column */
 				if (bfont) 
 					gnome_print_setfont (gpc, bfont);
 				if (nrok) 
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, "Nr");
-					wnr = colwidth (logwindow, NR, i, preferences.printorientation);
-					left = left + 0.5 + wnr * fwidth;
+					wnr = colwidth (logwindow, NR, i, preferences.printorientation, font, bfont);
+					left = left + ws + wnr;
 				}
 				if (dateok) 
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, "Date");
-					wdate = colwidth (logwindow, DATE, i, preferences.printorientation);
-					left = left + 0.5 + wdate * fwidth;
+					wdate = colwidth (logwindow, DATE, i, preferences.printorientation, font, bfont);
+					left = left + ws + wdate;
 				}
 				if (gmtok) 
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, "GMT");
-					wgmt = colwidth (logwindow, GMT, i, preferences.printorientation);
-					left = left + 0.5 + wgmt * fwidth;
+					wgmt = colwidth (logwindow, GMT, i, preferences.printorientation, font, bfont);
+					left = left + ws + wgmt;
 				}
 				if (gmtendok) 
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, "END");
-					wgmtend = colwidth (logwindow, GMTEND, i, preferences.printorientation);
-					left = left + 0.5 + wgmtend * fwidth;
+					wgmtend = colwidth (logwindow, GMTEND, i, preferences.printorientation, font, bfont);
+					left = left + ws + wgmtend;
 				}
 				if (callok) 
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, "Callsign");
-					wcall = colwidth (logwindow, CALL, i, preferences.printorientation);
-					left = left + 0.5 + wcall * fwidth;
+					wcall = colwidth (logwindow, CALL, i, preferences.printorientation, font, bfont);
+					left = left + ws + wcall;
 				}
 				if (bandok) 
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, "MHz");
-					wband = colwidth (logwindow, BAND, i, preferences.printorientation);
-					left = left + 0.5 + wband * fwidth;
+					wband = colwidth (logwindow, BAND, i, preferences.printorientation, font, bfont);
+					left = left + ws + wband;
 				}
 				if (modeok) 
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, "Mode");
-					wmode = colwidth (logwindow, MODE, i, preferences.printorientation);
-					left = left + 0.5 + wmode * fwidth;
+					wmode = colwidth (logwindow, MODE, i, preferences.printorientation, font, bfont);
+					left = left + ws + wmode;
 				}
 				if (rstok) 
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, "TX");
-					wrst = colwidth (logwindow, RST, i, preferences.printorientation);
-					left = left + 0.5 + wrst * fwidth;
+					wrst = colwidth (logwindow, RST, i, preferences.printorientation, font, bfont);
+					left = left + ws + wrst;
 				}
 				if (myrstok) 
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, "RX");
-					wmyrst = colwidth (logwindow, MYRST, i, preferences.printorientation);
-					left = left + 0.5 + wmyrst * fwidth;
+					wmyrst = colwidth (logwindow, MYRST, i, preferences.printorientation, font, bfont);
+					left = left + ws + wmyrst;
 				}
 				if (qsloutok) 
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, "Out");
-					wqslout = colwidth (logwindow, QSLOUT, i, preferences.printorientation);
-					left = left + 0.5 + wqslout * fwidth;
+					wqslout = colwidth (logwindow, QSLOUT, i, preferences.printorientation, font, bfont);
+					left = left + ws + wqslout;
 				}
 				if (qslinok) 
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, "In");
-					wqslin = colwidth (logwindow, QSLIN, i, preferences.printorientation);
-					left = left + 0.5 + wqslin * fwidth;
+					wqslin = colwidth (logwindow, QSLIN, i, preferences.printorientation, font, bfont);
+					left = left + ws + wqslin;
 				}
 				if (powerok) 
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, "Pwr");
-					wpower = colwidth (logwindow, POWER, i, preferences.printorientation);
-					left = left + 0.5 + wpower * fwidth;
+					wpower = colwidth (logwindow, POWER, i, preferences.printorientation, font, bfont);
+					left = left + ws + wpower;
 				}
 				if (nameok) 
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, "Name");
-					wname = colwidth (logwindow, NAME, i, preferences.printorientation);
-					left = left + 0.5 + wname * fwidth;
+					wname = colwidth (logwindow, NAME, i, preferences.printorientation, font, bfont);
+					left = left + ws + wname;
 				}
 				if (qthok) 
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, "QTH");
-					wqth = colwidth (logwindow, QTH, i, preferences.printorientation);
-					left = left + 0.5 + wqth * fwidth;
+					wqth = colwidth (logwindow, QTH, i, preferences.printorientation, font, bfont);
+					left = left + ws + wqth;
 				}
 				if (locatorok) 
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, "Locator");
-					wlocator = colwidth (logwindow, LOCATOR, i, preferences.printorientation);
-					left = left + 0.5 + wlocator * fwidth;
+					wlocator = colwidth (logwindow, LOCATOR, i, preferences.printorientation, font, bfont);
+					left = left + ws + wlocator;
 				}
 				if (u1ok)
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, preferences.freefield1);
-					wu1 = colwidth (logwindow, U1, i, preferences.printorientation);
-					left = left + 0.5 + wu1 * fwidth;
+					wu1 = colwidth (logwindow, U1, i, preferences.printorientation, font, bfont);
+					left = left + ws + wu1;
 				}
 				if (u2ok) 
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, preferences.freefield2);
-					wu2 = colwidth (logwindow, U2, i, preferences.printorientation);
-					left = left + 0.5 + wu2 * fwidth;
+					wu2 = colwidth (logwindow, U2, i, preferences.printorientation, font, bfont);
+					left = left + ws + wu2;
 				}
 				if (remarksok) 
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, "Remarks");
-					wremarks = colwidth (logwindow, REMARKS, i, preferences.printorientation);
-					left = left + 0.5 + wremarks * fwidth;
+					wremarks = colwidth (logwindow, REMARKS, i, preferences.printorientation, font, bfont);
+					left = left + ws + wremarks;
 				}
 				if (contest)
 				{
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, "Mult");
-					left = left + 0.5 + 4 * fwidth;
+					left = left + ws + gnome_font_get_width_utf8 (bfont, "Mult");
 					gnome_print_moveto (gpc, left, top);
 					gnome_print_show (gpc, "Points");
 				}
@@ -543,25 +548,25 @@ on_printokbutton_clicked (GtkButton * button, gpointer user_data)
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, item[NR]);
-				left = left + 0.5 + wnr * fwidth;
+				left = left + ws + wnr;
 			}
 			if (dateok) 
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, item[DATE]);
-				left = left + 0.5 + wdate * fwidth;
+				left = left + ws + wdate;
 			}
 			if (gmtok) 
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, item[GMT]);
-				left = left + 0.5 + wgmt * fwidth;
+				left = left + ws + wgmt;
 			}
 			if (gmtendok) 
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, item[GMTEND]);
-				left = left + 0.5 + wgmtend * fwidth;
+				left = left + ws + wgmtend;
 			}
 			if (callok) 
 			{
@@ -569,7 +574,7 @@ on_printokbutton_clicked (GtkButton * button, gpointer user_data)
 					gnome_print_setfont (gpc, bfont);
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, item[CALL]);
-				left = left + 0.5 + wcall * fwidth;
+				left = left + ws + wcall;
 				if (font) 
 					gnome_print_setfont (gpc, font);
 			}
@@ -577,79 +582,79 @@ on_printokbutton_clicked (GtkButton * button, gpointer user_data)
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, item[BAND]);
-				left = left + 0.5 + wband * fwidth;
+				left = left + ws + wband;
 			}
 			if (modeok) 
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, item[MODE]);
-				left = left + 0.5 + wmode * fwidth;
+				left = left + ws + wmode;
 			}
 			if (rstok) 
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, item[RST]);
-				left = left + 0.5 + wrst * fwidth;
+				left = left + ws + wrst;
 			}
 			if (myrstok) 
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, item[MYRST]);
-				left = left + 0.5 + wmyrst * fwidth;
+				left = left + ws + wmyrst;
 			}
 			if (qsloutok) 
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, item[QSLOUT]);
-				left = left + 0.5 + wqslout * fwidth;
+				left = left + ws + wqslout;
 			}
 			if (qslinok) 
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, item[QSLIN]);
-				left = left + 0.5 + wqslin * fwidth;
+				left = left + ws + wqslin;
 			}
 			if (powerok) 
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, item[POWER]);
-				left = left + 0.5 + wpower * fwidth;
+				left = left + ws + wpower;
 			}
 			if (nameok) 
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, item[NAME]);
-				left = left + 0.5 + wname * fwidth;
+				left = left + ws + wname;
 			}
 			if (qthok) 
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, item[QTH]);
-				left = left + 0.5 + wqth * fwidth;
+				left = left + ws + wqth;
 			}
 			if (locatorok) 
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, item[LOCATOR]);
-				left = left + 0.5 + wlocator * fwidth;
+				left = left + ws + wlocator;
 			}
 			if (u1ok) 
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, item[U1]);
-				left = left + 0.5 + wu1 * fwidth;
+				left = left + ws + wu1;
 			}
 			if (u2ok) 
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, item[U2]);
-				left = left + 0.5 + wu2 * fwidth;
+				left = left + ws + wu2;
 			}
 			if (remarksok) 
 			{
 				gnome_print_moveto (gpc, left, top);
 				gnome_print_show (gpc, item[REMARKS]);
-				left = left + 0.5 + wremarks * fwidth;
+				left = left + ws + wremarks;
 			}
 			if (contest)
 			{
