@@ -33,11 +33,30 @@
 extern GtkWidget *mainwindow;
 extern preferencestype preferences;
 extern statetype state;
-dxcc_data *dxcc;
+GPtrArray *dxcc;
 GHashTable *prefixes;
 gchar *searchpx = NULL;
 gint excwaz, excitu;
 
+void
+cleanup_dxcc (void)
+{
+	gint i;
+
+	/* free the dxcc array */
+	for (i = 0; i < dxcc->len; i++)
+	{
+		dxcc_data *d = g_ptr_array_index (dxcc, i);
+		g_free (d->countryname);
+		g_free (d->continent);
+		g_free (d->px);
+		g_free (d->exceptions);
+		g_free (d);
+	}
+	g_ptr_array_free (dxcc, TRUE);
+	if (prefixes) g_hash_table_destroy (prefixes);
+}
+
 static gchar *
 findpfx (gchar * pfx)
 {
@@ -167,6 +186,23 @@ lookup_dxcc (gchar * callsign)
 	return (country);
 }
 
+static void
+dxcc_add (gchar *c, gint w, gint i, gchar *cont, gint lat, gint lon,
+	gint tz, gchar *p, gchar *e)
+{
+	dxcc_data *new_dxcc = g_new (dxcc_data, 1);
+
+	new_dxcc -> countryname = g_strdup (c);
+	new_dxcc -> waz = w;
+	new_dxcc -> itu = i;
+	new_dxcc -> continent = g_strdup (cont);
+	new_dxcc -> latitude = lat;
+	new_dxcc -> longitude = lon;
+	new_dxcc -> timezone = tz;
+	new_dxcc -> px = g_strdup (p);
+	new_dxcc -> exceptions = g_strdup (e);
+	g_ptr_array_add (dxcc, new_dxcc);
+}
 
 gint
 readctydata (void)
@@ -177,7 +213,7 @@ readctydata (void)
 	FILE *fp;
 	gchar **split, **pfxsplit;
 
-	cty_location = g_strconcat (PACKAGE_DATA_DIR, G_DIR_SEPARATOR_S, "dxcc", G_DIR_SEPARATOR_S, "cty.dat", NULL);
+	cty_location = g_strconcat (XLOG_DATADIR, G_DIR_SEPARATOR_S, "dxcc", G_DIR_SEPARATOR_S, "cty.dat", NULL);
 
 	if ((fp = fopen (cty_location, "r")) == NULL)
 		{
@@ -185,20 +221,12 @@ readctydata (void)
 			return (1);
 		}
 
-	dxcc = g_new0 (dxcc_data, 400);
-	prefixes = g_hash_table_new (g_str_hash, g_str_equal);
+	dxcc = g_ptr_array_new ();
+	prefixes = g_hash_table_new_full (g_str_hash, g_str_equal, 
+		(GDestroyNotify)g_free, NULL);
 
 	/* first field in case hash_table_lookup returns NULL */
-	dxcc[0].countryname = g_strdup ("");
-	dxcc[0].waz = -1;
-	dxcc[0].itu = -1;
-	dxcc[0].continent = g_strdup ("");
-	dxcc[0].latitude = 0;
-	dxcc[0].longitude = 0;
-	dxcc[0].timezone = 0;
-	dxcc[0].px = g_strdup ("");
-	dxcc[0].exceptions = g_strdup ("");
-
+	dxcc_add ("", -1, -1, "", 0, 0, 0, "", "");
 	state.countries = 1;
 
 	while (!feof (fp))
@@ -222,15 +250,9 @@ readctydata (void)
 		/* split up the second line */
 		pfxsplit = g_strsplit (split[8], ",", 0);
 
-		dxcc[state.countries].countryname = g_strdup (split[0]);
-		dxcc[state.countries].waz = atoi (split[1]);
-		dxcc[state.countries].itu = atoi (split[2]);
-		dxcc[state.countries].continent = g_strdup (split[3]);
-		dxcc[state.countries].latitude = (gint)(atof(split[4]) * 100);
-		dxcc[state.countries].longitude = (gint)(atof(split[5]) * 100);
-		dxcc[state.countries].timezone = (gint)(atof(split[6]) * 10);
-		dxcc[state.countries].px = g_strdup (split[7]);
-		dxcc[state.countries].exceptions = g_strdup (split[8]);
+		dxcc_add (split[0], atoi(split[1]), atoi(split[2]), split[3],
+			(gint)atof(split[4]) * 100, (gint)atof(split[5]) * 100,
+			(gint)atof(split[6]) * 10, split[7], split[8]);
 
 		/* official prefix */
 		g_ascii_strup(split[7], -1); /* some chars are lowercase */
@@ -261,7 +283,7 @@ readxlogdata (void)
 	FILE *fp;
 	gint ichar = 0, ch = 0, country, newcountry;
 
-	dat_location = g_strconcat (PACKAGE_DATA_DIR, G_DIR_SEPARATOR_S, "dxcc", G_DIR_SEPARATOR_S, "xlog.dat", NULL);
+	dat_location = g_strconcat (XLOG_DATADIR, G_DIR_SEPARATOR_S, "dxcc", G_DIR_SEPARATOR_S, "xlog.dat", NULL);
 
 	if ((fp = fopen (dat_location, "r")) == NULL)
 		{
@@ -277,6 +299,8 @@ readxlogdata (void)
 			if (ch == EOF) break;
 			buf[ichar++] = ch;
 		}
+		if(feof(fp) && (ichar == 0))
+			break;
 		buf[ichar] = '\0';
 		ichar = 0;
 		ch = 0;
@@ -348,18 +372,19 @@ updatedxccframe (gchar * callsign)
 
 	if (country > 0)
 	{
-		labeltext1 = g_strdup (dxcc[country].countryname);
+		dxcc_data *d = g_ptr_array_index (dxcc, country);
+		labeltext1 = g_strdup (d->countryname);
 		/* look for exceptions */ 
-		if (strchr(dxcc[country].exceptions, '(') || strchr(dxcc[country].exceptions, '['))
+		if (strchr(d->exceptions, '(') || strchr(d->exceptions, '['))
 		{
-			excsplit = g_strsplit(dxcc[country].exceptions, ",", 0);
+			excsplit = g_strsplit(d->exceptions, ",", 0);
 			for (iexc = 0;; iexc++)
 			{
 				if (!excsplit[iexc]) break;
 				exc = findexc(excsplit[iexc]);
 				if (g_ascii_strcasecmp(searchpx, exc) == 0)
 				{ 
-					labeltext2 = g_strdup_printf ("%s - ITU %d - CQ %d", dxcc[country].continent, excitu, excwaz);
+					labeltext2 = g_strdup_printf ("%s - ITU %d - CQ %d", d->continent, excitu, excwaz);
 					exception = TRUE;
 				}
 			}
@@ -367,10 +392,10 @@ updatedxccframe (gchar * callsign)
 		}
 
 		if (! exception)
-			labeltext2 = g_strdup_printf ("%s - ITU %d - CQ %d", dxcc[country].continent, dxcc[country].itu, dxcc[country].waz);
-		labeltext3 = g_strdup_printf (_("Timezone: %+1.1f"), (gdouble)dxcc[country].timezone/10);
-		labeltext4 = g_strdup_printf (_("Location: %+1.2f %+1.2f"),	(gdouble)dxcc[country].latitude/100, (gdouble)dxcc[country].longitude/100);
-		gcresult = g_strdup (gc(preferences.units, state.mylocation, (gdouble)dxcc[country].latitude/100, (gdouble)dxcc[country].longitude/100));
+			labeltext2 = g_strdup_printf ("%s - ITU %d - CQ %d", d->continent, d->itu, d->waz);
+		labeltext3 = g_strdup_printf (_("Timezone: %+1.1f"), (gdouble)d->timezone/10);
+		labeltext4 = g_strdup_printf (_("Location: %+1.2f %+1.2f"),	(gdouble)d->latitude/100, (gdouble)d->longitude/100);
+		gcresult = g_strdup (gc(preferences.units, state.mylocation, (gdouble)d->latitude/100, (gdouble)d->longitude/100));
 	}
 	else
 	{
