@@ -20,4 +20,4 @@
 /* gui_b4dialog.h */
 
 GtkWidget* create_b4dialog (void);
-void on_menu_worked_activate (GtkMenuItem * menuitem, gpointer user_data);
+void on_menu_worked_activate (GtkAction *action, gpointer user_data);
