@@ -20,6 +20,6 @@
 
 void on_helpfaq_activate (GtkMenuItem *menuitem, gpointer user_data);
 void on_helpmanual_activate (GtkMenuItem *menuitem, gpointer user_data);
-void on_helpreadme_activate (GtkMenuItem *menuitem, gpointer user_data);
 void on_helptodo_activate (GtkMenuItem *menuitem, gpointer user_data);
 void on_helpthanks_activate (GtkMenuItem *menuitem, gpointer user_data);
+void on_helpchangelog_activate (GtkMenuItem *menuitem, gpointer user_data);
