@@ -52,7 +52,7 @@ compare_fields (void *f1, void *f2, gpointer user_data)
 
 /* update logfields and return number of columns */
 static void
-update_logfields (gint column, gint logfields[], gchar * showhide)
+update_logfields (gint column, gint logfields[], gint showhide)
 {
 	gint i, j;
 
@@ -67,7 +67,7 @@ update_logfields (gint column, gint logfields[], gchar * showhide)
 	 */
 	if (i == QSO_FIELDS)
 	{
-		if (strcasecmp (showhide, _("Show")) == 0)
+		if (showhide == 0)
 		{
 			for (j = 0; j < QSO_FIELDS; j++)
 				if (logfields[j] == 0)
@@ -84,7 +84,7 @@ update_logfields (gint column, gint logfields[], gchar * showhide)
 	 */
 	else
 	{
-		if (strcasecmp (showhide, _("Hide")) == 0)
+		if (showhide == 1)
 		{
 			logfields[i] = 0;
 			for (j = 0; j < QSO_FIELDS; j++)
@@ -102,45 +102,57 @@ update_logfields (gint column, gint logfields[], gchar * showhide)
 	}
 }
 
+/* check if column width entries have changed */
+static gboolean wchanged (gpointer arg)
+{
+	gchar *temp;
+	gboolean ret = FALSE;
+
+	temp = g_strjoinv (",", arg);
+	if (g_ascii_strcasecmp (temp, preferences.logcwidths) != 0)
+		ret = TRUE;
+	g_free (temp);
+	return ret;
+}
+
 void
 on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
 	GtkWidget *logeditor, 
-		*lecomboentry11, *lecomboentry3, *lecomboentry9_10, *lecomboentry12, 
-		*lecomboentry13, *lecomboentry14, *lecomboentry15, *lecomboentry17, 
-		*lecomboentry16, *leentry15, *leentry16,
 		*endhbox, *powerhbox,*qslhbox, *namehbox, *qthhbox, *locatorhbox, 
-		*unknown1hbox, *unknown2hbox, *remarksvbox, *unknownlabel1, *unknownlabel2,
-		*dialog_vbox, *mainvbox, *mainhbox, *fieldlabel, *showhidelabel, *hseparator, 
-		*lehbox0, *lelabel0_1, *lelabel0_2, 
-		*lehbox1, *lelabel1_1, *lelabel1_2, 
-		*lehbox2, *lelabel2_1, *lelabel2_2, 
-		*lehbox3, *lelabel3_1, *lecombo3, 
-		*lehbox4, *lelabel4_1, *lelabel4_2, 
-		*lehbox5, *lelabel5_1, *lelabel5_2, 
-		*lehbox6, *lelabel6_1, *lelabel6_2, 
-		*lehbox7, *lelabel7_1, *lelabel7_2, 
-		*lehbox8, *lelabel8_1, *lelabel8_2, 
-		*lehbox9_10, *lelabel9_10, *lecombo9_10, 
-		*lehbox11, *lelabel11, *lecombo11, 
-		*lehbox12, *lelabel12, *lecombo12, 
-		*lehbox13, *lelabel13, *lecombo13, 
-		*lehbox14, *lelabel14, *lecombo14, 
-		*lehbox15, *lecombo15, 
-		*lehbox16, *lecombo16,
-		*lehbox17, *lelabel17_1, *lecombo17, 
+		*unknown1hbox, *unknown2hbox, *remarksvbox, *unknownlabel1, 
+		*unknownlabel2, *dialog_vbox, *mainvbox, *mainhbox, *fieldlabel, 
+		*showhidelabel, *widthlabel, *hseparator, 
+		*lehbox0, *lelabel0_1, *lelabel0_2, *lee0,
+		*lehbox1, *lelabel1_1, *lelabel1_2, *lee1,
+		*lehbox2, *lelabel2_1, *lelabel2_2, *lee2,
+		*lehbox3, *lelabel3_1, *lecombo3, *lee3,
+		*lehbox4, *lelabel4_1, *lelabel4_2, *lee4,
+		*lehbox5, *lelabel5_1, *lelabel5_2, *lee5,
+		*lehbox6, *lelabel6_1, *lelabel6_2, *lee6,
+		*lehbox7, *lelabel7_1, *lelabel7_2, *lee7,
+		*lehbox8, *lelabel8_1, *lelabel8_2, *lee8,
+		*lehbox9_10, *lelabel9_10, *lecombo9_10, *lee9_10,
+		*lehbox11, *lelabel11, *lecombo11, *lee11,
+		*lehbox12, *lelabel12, *lecombo12, *lee12,
+		*lehbox13, *lelabel13, *lecombo13, *lee13,
+		*lehbox14, *lelabel14, *lecombo14, *lee14,
+		*lehbox15, *leentry15, *lecombo15, *lee15,
+		*lehbox16, *leentry16, *lecombo16, *lee16,
+		*lehbox17, *lelabel17_1, *lecombo17, *lee17,
 		*dialog_action_area, *logeditorcancelbutton, *logeditorokbutton;
-	GList *lecombo_items = NULL;
 	GdkPixbuf *logeditor_icon_pixbuf;
 	logtype *logw;
-	gchar *temp;
-	gint i, j, page, response, columns, fields[QSO_FIELDS];
+	gchar *temp, **w;
+	gint i, j, index, page, response, columns, fields[QSO_FIELDS];
 	GtkTreeViewColumn *column;
 
 	page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mainnotebook));
 
 	if (page >= 0)
 	{
+		w = g_strsplit(preferences.logcwidths, ",", 0);
+		
 		logeditor = gtk_dialog_new ();
 		gtk_window_set_title (GTK_WINDOW (logeditor), _("xlog - logeditor"));
 		gtk_window_set_position (GTK_WINDOW (logeditor), GTK_WIN_POS_MOUSE);
@@ -154,308 +166,261 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 		dialog_vbox = GTK_DIALOG (logeditor)->vbox;
 		gtk_widget_show (dialog_vbox);
 
-		mainvbox = gtk_vbox_new (TRUE, 1);
+		mainvbox = gtk_vbox_new (FALSE, 0);
 		gtk_widget_show (mainvbox);
 		gtk_box_pack_start (GTK_BOX (dialog_vbox), mainvbox, FALSE, FALSE, 0);
-		gtk_container_set_border_width (GTK_CONTAINER (mainvbox), 5);
 
 		mainhbox = gtk_hbox_new (TRUE, 0);
+		gtk_widget_set_size_request (mainhbox, -1, 50);
 		gtk_widget_show (mainhbox);
 		gtk_box_pack_start (GTK_BOX (mainvbox), mainhbox, TRUE, TRUE, 0);
 	
 		fieldlabel = gtk_label_new (_("Fieldname"));
-		gtk_widget_show (fieldlabel);
 		gtk_box_pack_start (GTK_BOX (mainhbox), fieldlabel, FALSE, FALSE, 0);
-	
-		showhidelabel = gtk_label_new (_("Show / Hide"));
-		gtk_widget_show (showhidelabel);
+		showhidelabel = gtk_label_new (_("Show / Hide\n-This log-"));
 		gtk_box_pack_start (GTK_BOX (mainhbox), showhidelabel, FALSE, FALSE, 0);
-		gtk_label_set_justify (GTK_LABEL (showhidelabel), GTK_JUSTIFY_CENTER);
+		widthlabel = gtk_label_new (_("Width (Pixels)\n-All logs-"));
+		gtk_box_pack_start (GTK_BOX (mainhbox), widthlabel, FALSE, FALSE, 0);
+		gtk_widget_show_all (mainhbox);
 
 		hseparator = gtk_hseparator_new ();
 		gtk_widget_show (hseparator);
 		gtk_box_pack_start (GTK_BOX (mainvbox), hseparator, FALSE, FALSE, 0);
 	
 		lehbox0 = gtk_hbox_new (TRUE, 0);
-		gtk_widget_show (lehbox0);
 		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox0, TRUE, TRUE, 0);
-
+		gtk_widget_set_size_request (lehbox0, -1, 30);
 		lelabel0_1 = gtk_label_new (_("QSO Number"));
-		gtk_widget_show (lelabel0_1);
 		gtk_box_pack_start (GTK_BOX (lehbox0), lelabel0_1, FALSE, FALSE, 0);
-
 		lelabel0_2 = gtk_label_new (_("Show"));
-		gtk_widget_show (lelabel0_2);
 		gtk_box_pack_start (GTK_BOX (lehbox0), lelabel0_2, FALSE, FALSE, 0);
-		gtk_label_set_justify (GTK_LABEL (lelabel0_2), GTK_JUSTIFY_CENTER);
+		lee0 = gtk_entry_new ();
+		gtk_widget_set_size_request (lee0, 50, -1);
+		gtk_box_pack_start (GTK_BOX (lehbox0), lee0, FALSE, FALSE, 0);
+		gtk_entry_set_text (GTK_ENTRY(lee0), w[NR]);
+		gtk_widget_show_all (lehbox0);
 
 		lehbox1 = gtk_hbox_new (TRUE, 0);
-		gtk_widget_show (lehbox1);
 		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox1, TRUE, TRUE, 0);
-	
+		gtk_widget_set_size_request (lehbox1, -1, 30);
 		lelabel1_1 = gtk_label_new (_("Date"));
-		gtk_widget_show (lelabel1_1);
 		gtk_box_pack_start (GTK_BOX (lehbox1), lelabel1_1, FALSE, FALSE, 0);
-
 		lelabel1_2 = gtk_label_new (_("Show"));
-		gtk_widget_show (lelabel1_2);
 		gtk_box_pack_start (GTK_BOX (lehbox1), lelabel1_2, FALSE, FALSE, 0);
-		gtk_label_set_justify (GTK_LABEL (lelabel1_2), GTK_JUSTIFY_CENTER);
+		lee1 = gtk_entry_new ();
+		gtk_widget_set_size_request (lee1, 50, -1);
+		gtk_box_pack_start (GTK_BOX (lehbox1), lee1, FALSE, FALSE, 0);
+		gtk_entry_set_text (GTK_ENTRY(lee1), w[DATE]);
+		gtk_widget_show_all (lehbox1);
 
 		lehbox2 = gtk_hbox_new (TRUE, 0);
-		gtk_widget_show (lehbox2);
 		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox2, TRUE, TRUE, 0);
-	
+		gtk_widget_set_size_request (lehbox2, -1, 30);
 		lelabel2_1 = gtk_label_new ("GMT");
-		gtk_widget_show (lelabel2_1);
 		gtk_box_pack_start (GTK_BOX (lehbox2), lelabel2_1, FALSE, FALSE, 0);
-	
 		lelabel2_2 = gtk_label_new (_("Show"));
-		gtk_widget_show (lelabel2_2);
 		gtk_box_pack_start (GTK_BOX (lehbox2), lelabel2_2, FALSE, FALSE, 0);
-		gtk_label_set_justify (GTK_LABEL (lelabel2_2), GTK_JUSTIFY_CENTER);
+		lee2 = gtk_entry_new ();
+		gtk_widget_set_size_request (lee2, 50, -1);
+		gtk_box_pack_start (GTK_BOX (lehbox2), lee2, FALSE, FALSE, 0);
+		gtk_entry_set_text (GTK_ENTRY(lee2), w[GMT]);
+		gtk_widget_show_all (lehbox2);
 
 		lehbox3 = gtk_hbox_new (TRUE, 0);
-		gtk_widget_show (lehbox3);
 		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox3, TRUE, TRUE, 0);
-
 		lelabel3_1 = gtk_label_new (_("Endtime (GMT)"));
-		gtk_widget_show (lelabel3_1);
 		gtk_box_pack_start (GTK_BOX (lehbox3), lelabel3_1, FALSE, FALSE, 0);
-	
-		lecombo3 = gtk_combo_new ();
-		g_object_set_data (G_OBJECT (GTK_COMBO (lecombo3)->popwin), "GladeParentKey", lecombo3);
-		gtk_widget_show (lecombo3);
+		lecombo3 = gtk_combo_box_new_text ();
 		gtk_box_pack_start (GTK_BOX (lehbox3), lecombo3, TRUE, TRUE, 0);
-		gtk_widget_set_size_request (lecombo3, 100, 23);
-		lecombo_items = g_list_append (lecombo_items, (gpointer) _("Show"));
-		lecombo_items = g_list_append (lecombo_items, (gpointer) _("Hide"));
-		gtk_combo_set_popdown_strings (GTK_COMBO (lecombo3), lecombo_items);
-
-		lecomboentry3 = GTK_COMBO (lecombo3)->entry;
-		gtk_widget_show (lecomboentry3);
-		gtk_editable_set_editable (GTK_EDITABLE (lecomboentry3), FALSE);
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo3), _("Show"));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo3), _("Hide"));
+		lee3 = gtk_entry_new ();
+		gtk_widget_set_size_request (lee3, 50, -1);
+		gtk_box_pack_start (GTK_BOX (lehbox3), lee3, FALSE, FALSE, 0);
+		gtk_entry_set_text (GTK_ENTRY(lee3), w[GMTEND]);
+		gtk_widget_show_all (lehbox3);
 
 		lehbox4 = gtk_hbox_new (TRUE, 0);
-		gtk_widget_show (lehbox4);
 		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox4, TRUE, TRUE, 0);
-
+		gtk_widget_set_size_request (lehbox4, -1, 30);
 		lelabel4_1 = gtk_label_new (_("Call"));
-		gtk_widget_show (lelabel4_1);
 		gtk_box_pack_start (GTK_BOX (lehbox4), lelabel4_1, FALSE, FALSE, 0);
-
 		lelabel4_2 = gtk_label_new (_("Show"));
-		gtk_widget_show (lelabel4_2);
 		gtk_box_pack_start (GTK_BOX (lehbox4), lelabel4_2, FALSE, FALSE, 0);
-		gtk_label_set_justify (GTK_LABEL (lelabel4_2), GTK_JUSTIFY_CENTER);
+		lee4 = gtk_entry_new ();
+		gtk_widget_set_size_request (lee4, 50, -1);
+		gtk_box_pack_start (GTK_BOX (lehbox4), lee4, FALSE, FALSE, 0);
+		gtk_entry_set_text (GTK_ENTRY(lee4), w[CALL]);
+		gtk_widget_show_all (lehbox4);
 
 		lehbox5 = gtk_hbox_new (TRUE, 0);
-		gtk_widget_show (lehbox5);
 		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox5, TRUE, TRUE, 0);
-
+		gtk_widget_set_size_request (lehbox5, -1, 30);
 		lelabel5_1 = gtk_label_new ("MHz");
-		gtk_widget_show (lelabel5_1);
 		gtk_box_pack_start (GTK_BOX (lehbox5), lelabel5_1, FALSE, FALSE, 0);
-	
 		lelabel5_2 = gtk_label_new (_("Show"));
-		gtk_widget_show (lelabel5_2);
 		gtk_box_pack_start (GTK_BOX (lehbox5), lelabel5_2, FALSE, FALSE, 0);
-		gtk_label_set_justify (GTK_LABEL (lelabel5_2), GTK_JUSTIFY_CENTER);
+		lee5 = gtk_entry_new ();
+		gtk_widget_set_size_request (lee5, 50, -1);
+		gtk_box_pack_start (GTK_BOX (lehbox5), lee5, FALSE, FALSE, 0);
+		gtk_entry_set_text (GTK_ENTRY(lee5), w[BAND]);
+		gtk_widget_show_all (lehbox5);
 
 		lehbox6 = gtk_hbox_new (TRUE, 0);
-		gtk_widget_show (lehbox6);
 		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox6, TRUE, TRUE, 0);
-
+		gtk_widget_set_size_request (lehbox6, -1, 30);
 		lelabel6_1 = gtk_label_new (_("Mode"));
-		gtk_widget_show (lelabel6_1);
 		gtk_box_pack_start (GTK_BOX (lehbox6), lelabel6_1, FALSE, FALSE, 0);
-
 		lelabel6_2 = gtk_label_new (_("Show"));
-		gtk_widget_show (lelabel6_2);
 		gtk_box_pack_start (GTK_BOX (lehbox6), lelabel6_2, FALSE, FALSE, 0);
-		gtk_label_set_justify (GTK_LABEL (lelabel6_2), GTK_JUSTIFY_CENTER);
+		lee6 = gtk_entry_new ();
+		gtk_widget_set_size_request (lee6, 50, -1);
+		gtk_box_pack_start (GTK_BOX (lehbox6), lee6, FALSE, FALSE, 0);
+		gtk_entry_set_text (GTK_ENTRY(lee6), w[MODE]);
+		gtk_widget_show_all (lehbox6);
 
 		lehbox7 = gtk_hbox_new (TRUE, 0);
-		gtk_widget_show (lehbox7);
 		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox7, TRUE, TRUE, 0);
-
+		gtk_widget_set_size_request (lehbox7, -1, 30);
 		lelabel7_1 = gtk_label_new ("TX(RST)");
-		gtk_widget_show (lelabel7_1);
 		gtk_box_pack_start (GTK_BOX (lehbox7), lelabel7_1, FALSE, FALSE, 0);
-
 		lelabel7_2 = gtk_label_new (_("Show"));
-		gtk_widget_show (lelabel7_2);
 		gtk_box_pack_start (GTK_BOX (lehbox7), lelabel7_2, FALSE, FALSE, 0);
-		gtk_label_set_justify (GTK_LABEL (lelabel7_2), GTK_JUSTIFY_CENTER);
+		lee7 = gtk_entry_new ();
+		gtk_widget_set_size_request (lee7, 50, -1);
+		gtk_box_pack_start (GTK_BOX (lehbox7), lee7, FALSE, FALSE, 0);
+		gtk_entry_set_text (GTK_ENTRY(lee7), w[RST]);
+		gtk_widget_show_all (lehbox7);
 
 		lehbox8 = gtk_hbox_new (TRUE, 0);
-		gtk_widget_show (lehbox8);
 		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox8, TRUE, TRUE, 0);
-
+		gtk_widget_set_size_request (lehbox8, -1, 30);
 		lelabel8_1 = gtk_label_new ("RX(RST)");
-		gtk_widget_show (lelabel8_1);
 		gtk_box_pack_start (GTK_BOX (lehbox8), lelabel8_1, FALSE, FALSE, 0);
-
 		lelabel8_2 = gtk_label_new (_("Show"));
-		gtk_widget_show (lelabel8_2);
 		gtk_box_pack_start (GTK_BOX (lehbox8), lelabel8_2, FALSE, FALSE, 0);
-		gtk_label_set_justify (GTK_LABEL (lelabel8_2), GTK_JUSTIFY_CENTER);
+		lee8 = gtk_entry_new ();
+		gtk_widget_set_size_request (lee8, 50, -1);
+		gtk_box_pack_start (GTK_BOX (lehbox8), lee8, FALSE, FALSE, 0);
+		gtk_entry_set_text (GTK_ENTRY(lee8), w[MYRST]);
+		gtk_widget_show_all (lehbox8);
 
 		lehbox9_10 = gtk_hbox_new (TRUE, 0);
-		gtk_widget_show (lehbox9_10);
 		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox9_10, TRUE, TRUE, 0);
-	
 		lelabel9_10 = gtk_label_new (_("QSL out/in"));
-		gtk_widget_show (lelabel9_10);
 		gtk_box_pack_start (GTK_BOX (lehbox9_10), lelabel9_10, FALSE, FALSE, 0);
-
-		lecombo9_10 = gtk_combo_new ();
-		g_object_set_data (G_OBJECT (GTK_COMBO (lecombo9_10)->popwin), "GladeParentKey", lecombo9_10);
-		gtk_widget_show (lecombo9_10);
+		lecombo9_10 = gtk_combo_box_new_text ();
 		gtk_box_pack_start (GTK_BOX (lehbox9_10), lecombo9_10, TRUE, TRUE, 0);
-		gtk_widget_set_size_request (lecombo9_10, 100, 23);
-		gtk_combo_set_popdown_strings (GTK_COMBO (lecombo9_10), lecombo_items);
-
-		lecomboentry9_10 = GTK_COMBO (lecombo9_10)->entry;
-		gtk_widget_show (lecomboentry9_10);
-		gtk_editable_set_editable (GTK_EDITABLE (lecomboentry9_10), FALSE);
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo9_10), _("Show"));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo9_10), _("Hide"));
+		lee9_10 = gtk_entry_new ();
+		gtk_widget_set_size_request (lee9_10, 50, -1);
+		gtk_box_pack_start (GTK_BOX (lehbox9_10), lee9_10, FALSE, FALSE, 0);
+		gtk_entry_set_text (GTK_ENTRY(lee9_10), w[QSLIN]);
+		gtk_widget_show_all (lehbox9_10);
 
 		lehbox11 = gtk_hbox_new (TRUE, 0);
 		gtk_widget_show (lehbox11);
 		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox11, TRUE, TRUE, 0);
 
 		lelabel11 = gtk_label_new (_("Power"));
-		gtk_widget_show (lelabel11);
 		gtk_box_pack_start (GTK_BOX (lehbox11), lelabel11, FALSE, FALSE, 0);
-
-		lecombo11 = gtk_combo_new ();
-		g_object_set_data (G_OBJECT (GTK_COMBO (lecombo11)->popwin), "GladeParentKey", lecombo11);
-		gtk_widget_show (lecombo11);
+		lecombo11 = gtk_combo_box_new_text ();
 		gtk_box_pack_start (GTK_BOX (lehbox11), lecombo11, TRUE, TRUE, 0);
-		gtk_widget_set_size_request (lecombo11, 100, 23);
-		gtk_combo_set_popdown_strings (GTK_COMBO (lecombo11), lecombo_items);
-
-		lecomboentry11 = GTK_COMBO (lecombo11)->entry;
-		gtk_widget_show (lecomboentry11);
-		gtk_editable_set_editable (GTK_EDITABLE (lecomboentry11), FALSE);
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo11), _("Show"));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo11), _("Hide"));
+		lee11 = gtk_entry_new ();
+		gtk_widget_set_size_request (lee11, 50, -1);
+		gtk_box_pack_start (GTK_BOX (lehbox11), lee11, FALSE, FALSE, 0);
+		gtk_entry_set_text (GTK_ENTRY(lee11), w[POWER]);
+		gtk_widget_show_all (lehbox11);
 
 		lehbox12 = gtk_hbox_new (TRUE, 0);
-		gtk_widget_show (lehbox12);
 		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox12, TRUE, TRUE, 0);
-
 		lelabel12 = gtk_label_new (_("Name"));
-		gtk_widget_show (lelabel12);
 		gtk_box_pack_start (GTK_BOX (lehbox12), lelabel12, FALSE, FALSE, 0);
-
-		lecombo12 = gtk_combo_new ();
-		g_object_set_data (G_OBJECT (GTK_COMBO (lecombo12)->popwin), "GladeParentKey", lecombo12);
-		gtk_widget_show (lecombo12);
+		lecombo12 = gtk_combo_box_new_text ();
 		gtk_box_pack_start (GTK_BOX (lehbox12), lecombo12, TRUE, TRUE, 0);
-		gtk_widget_set_size_request (lecombo12, 100, 23);
-		gtk_combo_set_popdown_strings (GTK_COMBO (lecombo12), lecombo_items);
-
-		lecomboentry12 = GTK_COMBO (lecombo12)->entry;
-		gtk_widget_show (lecomboentry12);
-		gtk_editable_set_editable (GTK_EDITABLE (lecomboentry12), FALSE);
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo12), _("Show"));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo12), _("Hide"));
+		lee12 = gtk_entry_new ();
+		gtk_widget_set_size_request (lee12, 50, -1);
+		gtk_box_pack_start (GTK_BOX (lehbox12), lee12, FALSE, FALSE, 0);
+		gtk_entry_set_text (GTK_ENTRY(lee12), w[NAME]);
+		gtk_widget_show_all (lehbox12);
 
 		lehbox13 = gtk_hbox_new (TRUE, 0);
-		gtk_widget_show (lehbox13);
 		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox13, TRUE, TRUE, 0);
-
 		lelabel13 = gtk_label_new ("QTH");
-		gtk_widget_show (lelabel13);
 		gtk_box_pack_start (GTK_BOX (lehbox13), lelabel13, FALSE, FALSE, 0);
-
-		lecombo13 = gtk_combo_new ();
-		g_object_set_data (G_OBJECT (GTK_COMBO (lecombo13)->popwin), "GladeParentKey", lecombo13);
-		gtk_widget_show (lecombo13);
+		lecombo13 = gtk_combo_box_new_text ();
 		gtk_box_pack_start (GTK_BOX (lehbox13), lecombo13, TRUE, TRUE, 0);
-		gtk_widget_set_size_request (lecombo13, 100, 23);
-		gtk_combo_set_popdown_strings (GTK_COMBO (lecombo13), lecombo_items);
-
-		lecomboentry13 = GTK_COMBO (lecombo13)->entry;
-		gtk_widget_show (lecomboentry13);
-		gtk_editable_set_editable (GTK_EDITABLE (lecomboentry13), FALSE);
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo13), _("Show"));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo13), _("Hide"));
+		lee13 = gtk_entry_new ();
+		gtk_widget_set_size_request (lee13, 50, -1);
+		gtk_box_pack_start (GTK_BOX (lehbox13), lee13, FALSE, FALSE, 0);
+		gtk_entry_set_text (GTK_ENTRY(lee13), w[QTH]);
+		gtk_widget_show_all (lehbox13);
 
 		lehbox14 = gtk_hbox_new (TRUE, 0);
-		gtk_widget_show (lehbox14);
 		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox14, TRUE, TRUE, 0);
-
 		lelabel14 = gtk_label_new (_("QTH Locator"));
-		gtk_widget_show (lelabel14);
 		gtk_box_pack_start (GTK_BOX (lehbox14), lelabel14, FALSE, FALSE, 0);
-
-		lecombo14 = gtk_combo_new ();
-		g_object_set_data (G_OBJECT (GTK_COMBO (lecombo14)->popwin), "GladeParentKey", lecombo14);
-		gtk_widget_show (lecombo14);
+		lecombo14 = gtk_combo_box_new_text ();
 		gtk_box_pack_start (GTK_BOX (lehbox14), lecombo14, TRUE, TRUE, 0);
-		gtk_widget_set_size_request (lecombo14, 100, 23);
-		gtk_combo_set_popdown_strings (GTK_COMBO (lecombo14), lecombo_items);
-
-		lecomboentry14 = GTK_COMBO (lecombo14)->entry;
-		gtk_widget_show (lecomboentry14);
-		gtk_editable_set_editable (GTK_EDITABLE (lecomboentry14), FALSE);
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo14), _("Show"));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo14), _("Hide"));
+		lee14 = gtk_entry_new ();
+		gtk_widget_set_size_request (lee14, 50, -1);
+		gtk_box_pack_start (GTK_BOX (lehbox14), lee14, FALSE, FALSE, 0);
+		gtk_entry_set_text (GTK_ENTRY(lee14), w[LOCATOR]);
+		gtk_widget_show_all (lehbox14);
 
 		lehbox15 = gtk_hbox_new (TRUE, 0);
-		gtk_widget_show (lehbox15);
 		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox15, TRUE, TRUE, 0);
-
 		leentry15 = gtk_entry_new ();
-		gtk_widget_show (leentry15);
+		gtk_widget_set_size_request (leentry15, 100, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox15), leentry15, FALSE, FALSE, 0);
-		gtk_widget_set_size_request (leentry15, 100, 23);
-
-		lecombo15 = gtk_combo_new ();
-		g_object_set_data (G_OBJECT (GTK_COMBO (lecombo15)->popwin), "GladeParentKey", lecombo15);
-		gtk_widget_show (lecombo15);
+		lecombo15 = gtk_combo_box_new_text ();
 		gtk_box_pack_start (GTK_BOX (lehbox15), lecombo15, TRUE, TRUE, 0);
-		gtk_widget_set_size_request (lecombo15, 100, 23);
-		gtk_combo_set_popdown_strings (GTK_COMBO (lecombo15), lecombo_items);
-
-		lecomboentry15 = GTK_COMBO (lecombo15)->entry;
-		gtk_widget_show (lecomboentry15);
-		gtk_editable_set_editable (GTK_EDITABLE (lecomboentry15), FALSE);
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo15), _("Show"));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo15), _("Hide"));
+		lee15 = gtk_entry_new ();
+		gtk_widget_set_size_request (lee15, 50, -1);
+		gtk_box_pack_start (GTK_BOX (lehbox15), lee15, FALSE, FALSE, 0);
+		gtk_entry_set_text (GTK_ENTRY(lee15), w[U1]);
+		gtk_widget_show_all (lehbox15);
 
 		lehbox16 = gtk_hbox_new (TRUE, 0);
-		gtk_widget_show (lehbox16);
 		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox16, TRUE, TRUE, 0);
-
 		leentry16 = gtk_entry_new ();
-		gtk_widget_show (leentry16);
+		gtk_widget_set_size_request (leentry16, 100, -1);
 		gtk_box_pack_start (GTK_BOX (lehbox16), leentry16, FALSE, FALSE, 0);
-		gtk_widget_set_size_request (leentry16, 100, 23);
-	
-		lecombo16 = gtk_combo_new ();
-		g_object_set_data (G_OBJECT (GTK_COMBO (lecombo16)->popwin), "GladeParentKey", lecombo16);
-		gtk_widget_show (lecombo16);
+		lecombo16 = gtk_combo_box_new_text ();
 		gtk_box_pack_start (GTK_BOX (lehbox16), lecombo16, TRUE, TRUE, 0);
-		gtk_widget_set_size_request (lecombo16, 100, 23);
-		gtk_combo_set_popdown_strings (GTK_COMBO (lecombo16), lecombo_items);
-
-		lecomboentry16 = GTK_COMBO (lecombo16)->entry;
-		gtk_widget_show (lecomboentry16);
-		gtk_editable_set_editable (GTK_EDITABLE (lecomboentry16), FALSE);
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo16), _("Show"));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo16), _("Hide"));
+		lee16 = gtk_entry_new ();
+		gtk_widget_set_size_request (lee16, 50, -1);
+		gtk_box_pack_start (GTK_BOX (lehbox16), lee16, FALSE, FALSE, 0);
+		gtk_entry_set_text (GTK_ENTRY(lee16), w[U2]);
+		gtk_widget_show_all (lehbox16);
 
 		lehbox17 = gtk_hbox_new (TRUE, 0);
-		gtk_widget_show (lehbox17);
 		gtk_box_pack_start (GTK_BOX (mainvbox), lehbox17, TRUE, TRUE, 0);
-
 		lelabel17_1 = gtk_label_new (_("Remarks"));
-		gtk_widget_show (lelabel17_1);
 		gtk_box_pack_start (GTK_BOX (lehbox17), lelabel17_1, FALSE, FALSE, 0);
-
-		lecombo17 = gtk_combo_new ();
-		g_object_set_data (G_OBJECT (GTK_COMBO (lecombo17)->popwin), "GladeParentKey", lecombo17);
-		gtk_widget_show (lecombo17);
+		lecombo17 = gtk_combo_box_new_text ();
 		gtk_box_pack_start (GTK_BOX (lehbox17), lecombo17, TRUE, TRUE, 0);
-		gtk_widget_set_size_request (lecombo17, 100, 23);
-		gtk_combo_set_popdown_strings (GTK_COMBO (lecombo17), lecombo_items);
-		g_list_free (lecombo_items);
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo17), _("Show"));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (lecombo17), _("Hide"));
+		lee17 = gtk_entry_new ();
+		gtk_widget_set_size_request (lee17, 50, -1);
+		gtk_box_pack_start (GTK_BOX (lehbox17), lee17, FALSE, FALSE, 0);
+		gtk_entry_set_text (GTK_ENTRY(lee17), w[REMARKS]);
+		gtk_widget_show_all (lehbox17);
 
-		lecomboentry17 = GTK_COMBO (lecombo17)->entry;
-		gtk_widget_show (lecomboentry17);
-		gtk_editable_set_editable (GTK_EDITABLE (lecomboentry17), FALSE);
-	
 		dialog_action_area = GTK_DIALOG (logeditor)->action_area;
 		gtk_widget_show (dialog_action_area);
 		gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area), GTK_BUTTONBOX_SPREAD);
@@ -472,61 +437,61 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 
 		endhbox = lookup_widget (mainwindow, "endhbox");
 		if (GTK_WIDGET_VISIBLE (endhbox))
-			gtk_entry_set_text (GTK_ENTRY (lecomboentry3), _("Show"));
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo3), 0);
 		else
-			gtk_entry_set_text (GTK_ENTRY (lecomboentry3), _("Hide"));
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo3), 1);
 	
 		qslhbox = lookup_widget (mainwindow, "qslhbox");
 		if (GTK_WIDGET_VISIBLE (qslhbox))
-			gtk_entry_set_text (GTK_ENTRY (lecomboentry9_10), _("Show"));
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo9_10), 0);
 		else
-			gtk_entry_set_text (GTK_ENTRY (lecomboentry9_10), _("Hide"));
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo9_10), 1);
 
 		powerhbox = lookup_widget (mainwindow, "powerhbox");
 		if (GTK_WIDGET_VISIBLE (powerhbox))
-			gtk_entry_set_text (GTK_ENTRY (lecomboentry11), _("Show"));
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo11), 0);
 		else
-			gtk_entry_set_text (GTK_ENTRY (lecomboentry11), _("Hide"));
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo11), 1);
 
 		namehbox = lookup_widget (mainwindow, "namehbox");
 		if (GTK_WIDGET_VISIBLE (namehbox))
-			gtk_entry_set_text (GTK_ENTRY (lecomboentry12), _("Show"));
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo12), 0);
 		else
-			gtk_entry_set_text (GTK_ENTRY (lecomboentry12), _("Hide"));
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo12), 1);
 
 		qthhbox = lookup_widget (mainwindow, "qthhbox");
 		if (GTK_WIDGET_VISIBLE (qthhbox))
-			gtk_entry_set_text (GTK_ENTRY (lecomboentry13), _("Show"));
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo13), 0);
 		else
-			gtk_entry_set_text (GTK_ENTRY (lecomboentry13), _("Hide"));
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo13), 1);
 
 		locatorhbox = lookup_widget (mainwindow, "locatorhbox");
 		if (GTK_WIDGET_VISIBLE (locatorhbox))
-			gtk_entry_set_text (GTK_ENTRY (lecomboentry14), _("Show"));
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo14), 0);
 		else
-			gtk_entry_set_text (GTK_ENTRY (lecomboentry14), _("Hide"));
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo14), 1);
 
 		unknown1hbox = lookup_widget (mainwindow, "unknown1hbox");
 		if (GTK_WIDGET_VISIBLE (unknown1hbox))
-			gtk_entry_set_text (GTK_ENTRY (lecomboentry15), _("Show"));
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo15), 0);
 		else
-			gtk_entry_set_text (GTK_ENTRY (lecomboentry15), _("Hide"));
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo15), 1);
 
 		unknown2hbox = lookup_widget (mainwindow, "unknown2hbox");
 		if (GTK_WIDGET_VISIBLE (unknown2hbox))
-			gtk_entry_set_text (GTK_ENTRY (lecomboentry16), _("Show"));
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo16), 0);
 		else
-			gtk_entry_set_text (GTK_ENTRY (lecomboentry16), _("Hide"));
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo16), 1);
 
 		gtk_entry_set_text (GTK_ENTRY (leentry15), preferences.freefield1);
 		gtk_entry_set_text (GTK_ENTRY (leentry16), preferences.freefield2);
 	
 		remarksvbox = lookup_widget (mainwindow, "remarksvbox");
 		if (GTK_WIDGET_VISIBLE (remarksvbox))
-			gtk_entry_set_text (GTK_ENTRY (lecomboentry17), _("Show"));
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo17), 0);
 		else
-			gtk_entry_set_text (GTK_ENTRY (lecomboentry17), _("Hide"));
-	
+			gtk_combo_box_set_active (GTK_COMBO_BOX (lecombo17), 1);
+
 		response = gtk_dialog_run (GTK_DIALOG(logeditor));
 		if (response == GTK_RESPONSE_OK)
 		{
@@ -539,16 +504,17 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 			for (i = logw->columns; i < QSO_FIELDS; i++)
 				fields[i] = 0;
 
-			temp = gtk_editable_get_chars (GTK_EDITABLE (lecomboentry3), 0, -1);
+			/* show/hide columns and update the array */
+			index = gtk_combo_box_get_active (GTK_COMBO_BOX (lecombo3));
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), GMTEND);
-			if (strcasecmp (temp, _("Hide")) == 0)
+			if (index == 1)
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), FALSE);
 			else
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
-			update_logfields (GMTEND, fields, temp);
+			update_logfields (GMTEND, fields, index);
 		
-			temp = gtk_editable_get_chars (GTK_EDITABLE (lecomboentry9_10), 0, -1);
-			if (strcasecmp (temp, _("Hide")) == 0)
+			index = gtk_combo_box_get_active (GTK_COMBO_BOX (lecombo9_10));
+			if (index == 1)
 			{
 				column = gtk_tree_view_get_column (GTK_TREE_VIEW(logw->treeview), QSLOUT);
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), FALSE);
@@ -562,64 +528,64 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 				column = gtk_tree_view_get_column (GTK_TREE_VIEW(logw->treeview), QSLIN);
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
 			}
-			update_logfields (QSLOUT, fields, temp);
-			update_logfields (QSLIN, fields, temp);
+			update_logfields (QSLOUT, fields, index);
+			update_logfields (QSLIN, fields, index);
 		
-			temp = gtk_editable_get_chars (GTK_EDITABLE (lecomboentry11), 0, -1);
+			index = gtk_combo_box_get_active (GTK_COMBO_BOX (lecombo11));
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), POWER);
-			if (strcasecmp (temp, _("Hide")) == 0)
+			if (index == 1)
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), FALSE);
 			else
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
-			update_logfields (POWER, fields, temp);
+			update_logfields (POWER, fields, index);
 		
-			temp = gtk_editable_get_chars (GTK_EDITABLE (lecomboentry12), 0, -1);
+			index = gtk_combo_box_get_active (GTK_COMBO_BOX (lecombo12));
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), NAME);
-			if (strcasecmp (temp, _("Hide")) == 0)
+			if (index == 1)
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), FALSE);
 			else
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
-			update_logfields (NAME, fields, temp);
+			update_logfields (NAME, fields, index);
 		
-			temp = gtk_editable_get_chars (GTK_EDITABLE (lecomboentry13), 0, -1);
+			index = gtk_combo_box_get_active (GTK_COMBO_BOX (lecombo13));
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), QTH);
-			if (strcasecmp (temp, _("Hide")) == 0)
+			if (index == 1)
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), FALSE);
 			else
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
-			update_logfields (QTH, fields, temp);
+			update_logfields (QTH, fields, index);
 		
-			temp = gtk_editable_get_chars (GTK_EDITABLE (lecomboentry14), 0, -1);
+			index = gtk_combo_box_get_active (GTK_COMBO_BOX (lecombo14));
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), LOCATOR);
-			if (strcasecmp (temp, _("Hide")) == 0)
+			if (index == 1)
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), FALSE);
 			else
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
-			update_logfields (LOCATOR, fields, temp);
+			update_logfields (LOCATOR, fields, index);
 		
-			temp = gtk_editable_get_chars (GTK_EDITABLE (lecomboentry15), 0, -1);
+			index = gtk_combo_box_get_active (GTK_COMBO_BOX (lecombo15));
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), U1);
-			if (strcasecmp (temp, _("Hide")) == 0)
+			if (index == 1)
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), FALSE);
 			else
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
-			update_logfields (U1, fields, temp);
+			update_logfields (U1, fields, index);
 
-			temp = gtk_editable_get_chars (GTK_EDITABLE (lecomboentry16), 0, -1);
+			index = gtk_combo_box_get_active (GTK_COMBO_BOX (lecombo16));
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), U2);
-			if (strcasecmp (temp, _("Hide")) == 0)
+			if (index == 1)
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), FALSE);
 			else
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
-			update_logfields (U2, fields, temp);
+			update_logfields (U2, fields, index);
 	
-			temp = gtk_editable_get_chars (GTK_EDITABLE (lecomboentry17), 0, -1);
+			index = gtk_combo_box_get_active (GTK_COMBO_BOX (lecombo17));
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW (logw->treeview), REMARKS);
-			if (strcasecmp (temp, _("Hide")) == 0)
+			if (index == 1)
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), FALSE);
 			else
 				gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN(column), TRUE);
-			update_logfields (REMARKS, fields, temp);
+			update_logfields (REMARKS, fields, index);
 
 			/* how many columns do we have now */
 			for (i = 0; i < QSO_FIELDS; i++)
@@ -628,6 +594,7 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 				break;
 			}
 			columns = i;
+
 			/* is the log changed? */
 			for (i = 0; i < QSO_FIELDS; i++)
 			{
@@ -676,6 +643,49 @@ on_menu_logeditor_activate (GtkMenuItem * menuitem, gpointer user_data)
 			g_free (temp);
 			set_qsoframe (logw);
 		}
+
+		/* now set column widths for all visible logs if changed */
+		w[NR] = gtk_editable_get_chars (GTK_EDITABLE (lee0), 0, -1);
+		w[DATE] = gtk_editable_get_chars (GTK_EDITABLE (lee1), 0, -1);
+		w[GMT] = gtk_editable_get_chars (GTK_EDITABLE (lee2), 0, -1);
+		w[GMTEND] = gtk_editable_get_chars (GTK_EDITABLE (lee3), 0, -1);
+		w[CALL] = gtk_editable_get_chars (GTK_EDITABLE (lee4), 0, -1);
+		w[BAND] = gtk_editable_get_chars (GTK_EDITABLE (lee5), 0, -1);
+		w[MODE] = gtk_editable_get_chars (GTK_EDITABLE (lee6), 0, -1);
+		w[RST] = gtk_editable_get_chars (GTK_EDITABLE (lee7), 0, -1);
+		w[MYRST] = gtk_editable_get_chars (GTK_EDITABLE (lee8), 0, -1);
+		w[QSLIN] = gtk_editable_get_chars (GTK_EDITABLE (lee9_10), 0, -1);
+		w[QSLOUT] = gtk_editable_get_chars (GTK_EDITABLE (lee9_10), 0, -1);
+		w[POWER] = gtk_editable_get_chars (GTK_EDITABLE (lee11), 0, -1);
+		w[NAME] = gtk_editable_get_chars (GTK_EDITABLE (lee12), 0, -1);
+		w[QTH] = gtk_editable_get_chars (GTK_EDITABLE (lee13), 0, -1);
+		w[LOCATOR] = gtk_editable_get_chars (GTK_EDITABLE (lee14), 0, -1);
+		w[U1] = gtk_editable_get_chars (GTK_EDITABLE (lee15), 0, -1);
+		w[U2] = gtk_editable_get_chars (GTK_EDITABLE (lee16), 0, -1);
+		w[REMARKS] = gtk_editable_get_chars (GTK_EDITABLE (lee17), 0, -1);
+		if (wchanged(w))
+		{
+			for (i = 0; i < g_list_length (logwindowlist); i++)
+			{
+				logw = g_list_nth_data (logwindowlist, i);
+				for (j = 0; j < QSO_FIELDS; j++)
+				{
+					column = gtk_tree_view_get_column 
+						(GTK_TREE_VIEW(logw->treeview), j);
+					if (atoi(w[j]) > 19)
+						gtk_tree_view_column_set_fixed_width 
+							(GTK_TREE_VIEW_COLUMN(column), atoi(w[j]));
+					else
+					{
+						gtk_tree_view_column_set_fixed_width 
+							(GTK_TREE_VIEW_COLUMN(column), 20);
+						w[j] = g_strdup ("20");
+					}
+				}
+			}
+			preferences.logcwidths = g_strjoinv (",", w);
+		}
+		g_strfreev (w);
 		gtk_widget_destroy (logeditor);
 	}
 }
