@@ -41,83 +41,22 @@
 #include "gui_preferencesdialog.h"
 #include "gui_saveasdialog.h"
 #include "gui_searchdialog.h"
+#include "support.h"
+#include "types.h"
+
 #if WANT_HAMLIB
 #	include "gui_tracedialog.h"
 #endif
-#include "support.h"
 
 GtkWidget *mainwindow, *mainnotebook;
+GtkUIManager *ui_manager;
+extern preferencestype preferences;
 
 GtkWidget*
 create_mainwindow (void)
 {
-	GtkWidget *mainwindow;
+	GtkWidget *mainwindow, *mainvbox, *menubar;
 	GdkPixbuf *mainwindow_icon_pixbuf;
-	GtkWidget *mainvbox;
-	GtkWidget *menubar;
-	GtkWidget *log;
-	GtkWidget *log_menu;
-	GtkWidget *new;
-	GtkWidget *image703;
-	GtkWidget *open;
-	GtkWidget *image704;
-	GtkWidget *scheidslijn1;
-	GtkWidget *save;
-	GtkWidget *image705;
-	GtkWidget *saveas;
-	GtkWidget *image706;
-	GtkWidget *close;
-	GtkWidget *image707;
-	GtkWidget *scheidslijn2;
-	GtkWidget *print;
-	GtkWidget *image708;
-	GtkWidget *exit;
-	GtkWidget *image709;
-	GtkWidget *edit;
-	GtkWidget *edit_menu;
-	GtkWidget *clearframe;
-	GtkWidget *image710;
-	GtkWidget *search;
-	GtkWidget *image711;
-	GtkWidget *clickall;
-	GtkWidget *image712;
-	GtkWidget *tools;
-	GtkWidget *tools_menu;
-	GtkWidget *log_editor;
-	GtkWidget *image713;
-	GtkWidget *dupecheck;
-	GtkWidget *trace_hamlib;
-	GtkWidget *image791;
-	GtkWidget *sort_log;
-	GtkWidget *image733;
-	GtkWidget *image714;
-	GtkWidget *separator2;
-	GtkWidget *view_toolbar;
-	GtkWidget *worked;
-	GtkWidget *settings;
-	GtkWidget *settings_menu;
-	GtkWidget *defaults;
-	GtkWidget *image715;
-	GtkWidget *dialogs;
-	GtkWidget *image716;
-	GtkWidget *separator1;
-	GtkWidget *preferences;
-	GtkWidget *image717;
-	GtkWidget *help;
-	GtkWidget *help_menu;
-	GtkWidget *documentation1;
-	GtkWidget *image718;
-	GtkWidget *documentation1_menu;
-	GtkWidget *helpfaq;
-	GtkWidget *helpmanual;
-	GtkWidget *image719;
-	GtkWidget *helpreadme;
-	GtkWidget *image720;
-	GtkWidget *helpthanks;
-	GtkWidget *helptodo;
-	GtkWidget *scheidingslijn1;
-	GtkWidget *about;
-	GtkWidget *image721;
 	GtkWidget *hpaned;
 	GtkWidget *qsomainvbox;
 	GtkWidget *handlebox;
@@ -156,16 +95,12 @@ create_mainwindow (void)
 	GtkWidget *mhzbutton;
 	GtkWidget *mhzlabel;
 	GtkWidget *bandhbox2;
-	GtkWidget *bandoptionmenu;
-	GtkWidget *convertwidget3;
 	GtkWidget *bandentry;
 	GtkWidget *modehbox;
 	GtkWidget *modehbox1;
 	GtkWidget *modebutton;
 	GtkWidget *modelabel;
 	GtkWidget *modehbox2;
-	GtkWidget *modeoptionmenu;
-	GtkWidget *convertwidget4;
 	GtkWidget *modeentry;
 	GtkWidget *hrsthbox;
 	GtkWidget *hbox39;
@@ -231,290 +166,188 @@ create_mainwindow (void)
 	GtkWidget *clockpixmap;
 	GtkWidget *clocklabel;
 	GtkAccelGroup *accel_group;
-	GtkTooltips *tooltips;
+	GtkActionGroup *action_group;
+	GtkTooltips *buttontooltips;
+	GError *error;
+	gint merge_id;
+#if !WANT_HAMLIB
+	GtkWidget *trace_hamlib;
+#endif
 
-	tooltips = gtk_tooltips_new ();
+/* Normal items */
+static GtkActionEntry entries[] = 
+{
+  { "LogMenu", NULL, N_("_Log") },
+  { "EditMenu", NULL, N_("_Edit") },
+  { "OptionMenu", NULL, N_("_Options") },
+  { "ToolsMenu", NULL, N_("_Tools") },
+  { "TabsMenu", NULL, N_("T_abs") },
+  { "SettingsMenu", NULL, N_("_Settings") },
+  { "HelpMenu", NULL, N_("_Help") },
 
-	accel_group = gtk_accel_group_new ();
+  { "New", GTK_STOCK_NEW, N_("New..."), "<control>N", "New log", G_CALLBACK(on_menu_new_activate) },
+  { "Open", GTK_STOCK_OPEN, N_("Open"), "<control>O", "Open a log", G_CALLBACK(on_menu_open_activate) },
+  { "Save", GTK_STOCK_SAVE, N_("Save"), "<control>S", "Save log", G_CALLBACK(on_menu_save_activate) },
+  { "Save As", GTK_STOCK_SAVE_AS, N_("Save As..."), "", "Save log as", G_CALLBACK(on_menu_saveas_activate) },
+  { "Close", GTK_STOCK_CLOSE, N_("Close"), "<control>Q", "Close log", G_CALLBACK(on_menu_close_activate) },
+  { "Print", GTK_STOCK_PRINT, N_("Print"), "<control>P", "Print log", G_CALLBACK(on_menu_print_activate) },
+  { "Exit", GTK_STOCK_QUIT, N_("Exit"), "<control>X", "Exit program", G_CALLBACK(on_menu_exit_activate) },
+
+  { "Clear All", GTK_STOCK_CLEAR, N_("Clear All"), "<control>Y", "Clear all fields", G_CALLBACK(on_clearframe_activate) },
+  { "Find", GTK_STOCK_FIND, N_("Find"), "<control>F", "Find callsign", G_CALLBACK(on_menu_search_activate) },
+  { "Click All", GTK_STOCK_APPLY, N_("Click All"), "<control>K", "Click all buttons", G_CALLBACK(on_clickall_activate) },
+
+  { "Log Editor", GTK_STOCK_PROPERTIES, N_("Log Editor"), "", "Format fields in the log", G_CALLBACK(on_menu_logeditor_activate) },
+  { "Dupe Check", GTK_STOCK_COPY, N_("Dupe Check..."), "", "Check the log(s) for dupes", G_CALLBACK(on_menu_dupecheck_activate) },
+#if WANT_HAMLIB
+  { "Trace Hamlib", GTK_STOCK_EXECUTE, N_("Trace Hamlib"), "", "Show hamlib debugging output", G_CALLBACK(on_trace_hamlib_activate) },
+#endif
+  { "Sort", GTK_STOCK_SORT_ASCENDING, N_("Sort by Date"), "", "Sort log by date", G_CALLBACK(on_sort_log_activate) },
+
+  { "Defaults", GTK_STOCK_INDEX, N_("Defaults"), "", "Default values to use for logging", G_CALLBACK(on_menu_defaults_activate) },
+  { "Dialogs", GTK_STOCK_JUSTIFY_FILL, N_("Dialogs"), "", "Settings for dialogs used", G_CALLBACK(on_menu_dialogs_activate) },
+  { "Preferences", GTK_STOCK_PREFERENCES, N_("Preferences..."), "", "Preferences for xlog", G_CALLBACK(on_menu_preferences_activate) },
+
+  { "Documentation", GTK_STOCK_HELP, N_("Documentation"), "", "Important documents", NULL },
+  { "About", GTK_STOCK_DIALOG_INFO, N_("About..."), "", "About xlog", G_CALLBACK(on_menu_about_activate) },
+
+  { "Changelog", GTK_STOCK_DIALOG_INFO, N_("Changelog"), "", "Read the changelog", G_CALLBACK(on_helpchangelog_activate) },
+  { "Faq", GTK_STOCK_DIALOG_QUESTION, N_("Faq"), "", "Frequently asked quenstions", G_CALLBACK(on_helpfaq_activate) },
+  { "Manual", GTK_STOCK_DIALOG_INFO, N_("Manual"), "", "Xlog manual", G_CALLBACK(on_helpmanual_activate) },
+  { "Thanks", GTK_STOCK_DIALOG_INFO, N_("Thanks"), "", "Thanks to these hams", G_CALLBACK(on_helpthanks_activate) },
+  { "Todo", GTK_STOCK_DIALOG_INFO, N_("Todo"), "", "Things to do for future versions", G_CALLBACK(on_helptodo_activate) },
+
+  { "1", GTK_STOCK_JUMP_TO, "Log 1", "<alt>1", "", G_CALLBACK(on_menu_log_activate) },
+  { "2", GTK_STOCK_JUMP_TO, "Log 2", "<alt>2", "", G_CALLBACK(on_menu_log_activate) },
+  { "3", GTK_STOCK_JUMP_TO, "Log 3", "<alt>3", "", G_CALLBACK(on_menu_log_activate) },
+  { "4", GTK_STOCK_JUMP_TO, "Log 4", "<alt>4", "", G_CALLBACK(on_menu_log_activate) },
+  { "5", GTK_STOCK_JUMP_TO, "Log 5", "<alt>5", "", G_CALLBACK(on_menu_log_activate) },
+  { "6", GTK_STOCK_JUMP_TO, "Log 6", "<alt>6", "", G_CALLBACK(on_menu_log_activate) },
+  { "7", GTK_STOCK_JUMP_TO, "Log 7", "<alt>7", "", G_CALLBACK(on_menu_log_activate) },
+  { "8", GTK_STOCK_JUMP_TO, "Log 8", "<alt>8", "", G_CALLBACK(on_menu_log_activate) },
+  { "9", GTK_STOCK_JUMP_TO, "Log 9", "<alt>9", "", G_CALLBACK(on_menu_log_activate) },
+  { "10", GTK_STOCK_JUMP_TO, "Log 10", "<alt>0", "", G_CALLBACK(on_menu_log_activate) },
+};
+
+static GtkToggleActionEntry toggle_entries[] = 
+{
+  { "ShowToolbar", NULL, N_("Show Toolbar"), "<control>T", "Show/hide the toolbar", G_CALLBACK(on_view_toolbar_activate) },
+  { "WorkedBefore", NULL, N_("Worked Before"), "<control>W", "Show/hide the worked before dialog", G_CALLBACK(on_menu_worked_activate) },
+};
+
+static const char *ui_description =
+"<ui>"
+"  <menubar name='MainMenu'>"
+"    <menu action='LogMenu'>"
+"      <menuitem action='New'/>"
+"      <menuitem action='Open'/>"
+"      <separator name='sep1'/>"
+"      <menuitem action='Save'/>"
+"      <menuitem action='Save As'/>"
+"      <menuitem action='Close'/>"
+"      <separator name='sep2'/>"
+"      <menuitem action='Print'/>"
+"      <menuitem action='Exit'/>"
+"    </menu>"
+"    <menu action='EditMenu'>"
+"      <menuitem action='Clear All'/>"
+"      <menuitem action='Find'/>"
+"      <menuitem action='Click All'/>"
+"    </menu>"
+"    <menu action='OptionMenu'>"
+"      <menuitem action='ShowToolbar'/>"
+"      <menuitem action='WorkedBefore'/>"
+"    </menu>"
+"    <menu action='ToolsMenu'>"
+"      <menuitem action='Log Editor'/>"
+"      <menuitem action='Dupe Check'/>"
+#if WANT_HAMLIB
+"      <menuitem action='Trace Hamlib'/>"
+#endif
+"      <menuitem action='Sort'/>"
+"    </menu>"
+"    <menu action='TabsMenu'>"
+"      <menuitem action='1'/>"
+"      <menuitem action='2'/>"
+"      <menuitem action='3'/>"
+"      <menuitem action='4'/>"
+"      <menuitem action='5'/>"
+"      <menuitem action='6'/>"
+"      <menuitem action='7'/>"
+"      <menuitem action='8'/>"
+"      <menuitem action='9'/>"
+"      <menuitem action='10'/>"
+"    </menu>"
+"    <menu action='SettingsMenu'>"
+"      <menuitem action='Defaults'/>"
+"      <menuitem action='Dialogs'/>"
+"      <separator name='sep'/>"
+"      <menuitem action='Preferences'/>"
+"    </menu>"
+"    <menu action='HelpMenu'>"
+"      <menu action='Documentation'>"
+"        <menuitem action='Changelog'/>"
+"        <menuitem action='Faq'/>"
+"        <menuitem action='Manual'/>"
+"        <menuitem action='Thanks'/>"
+"        <menuitem action='Todo'/>"
+"      </menu>"
+"      <separator name='sep'/>"
+"      <menuitem action='About'/>"
+"    </menu>"
+"  </menubar>"
+"</ui>";
 
 	mainwindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_widget_set_events (mainwindow, GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK);
 	gtk_window_set_title (GTK_WINDOW (mainwindow), "xlog");
 	mainwindow_icon_pixbuf = create_pixbuf ("xlog.png");
 	if (mainwindow_icon_pixbuf)
-		{
-			gtk_window_set_icon (GTK_WINDOW (mainwindow), mainwindow_icon_pixbuf);
-			g_object_unref (mainwindow_icon_pixbuf);
-		}
+	{
+		gtk_window_set_icon (GTK_WINDOW (mainwindow), mainwindow_icon_pixbuf);
+		g_object_unref (mainwindow_icon_pixbuf);
+	}
 
 	mainvbox = gtk_vbox_new (FALSE, 0);
 	gtk_widget_show (mainvbox);
 	gtk_container_add (GTK_CONTAINER (mainwindow), mainvbox);
 
-	menubar = gtk_menu_bar_new ();
-	gtk_widget_show (menubar);
+	action_group = gtk_action_group_new ("MenuActions");
+	gtk_action_group_set_translation_domain (action_group, PACKAGE);
+	gtk_action_group_add_actions (action_group, entries,
+		G_N_ELEMENTS (entries), mainwindow);
+
+	if (preferences.viewtoolbar == 1)
+		toggle_entries[0].is_active = TRUE;
+	if (preferences.viewb4 == 1)
+		toggle_entries[1].is_active = TRUE;
+	gtk_action_group_add_toggle_actions (action_group,
+		toggle_entries, G_N_ELEMENTS (toggle_entries), mainwindow);
+
+	ui_manager = gtk_ui_manager_new ();
+	gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
+
+	accel_group = gtk_ui_manager_get_accel_group (ui_manager);
+	gtk_window_add_accel_group (GTK_WINDOW (mainwindow), accel_group);
+
+	error = NULL;
+	merge_id = gtk_ui_manager_add_ui_from_string 
+		(ui_manager, ui_description, -1, &error);
+	if (!merge_id)
+	{
+		g_message ("building menus failed: %s", error->message);
+		g_error_free (error);
+		return (NULL);
+	}
+	menubar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
 	gtk_box_pack_start (GTK_BOX (mainvbox), menubar, FALSE, FALSE, 0);
+	gtk_widget_show (menubar);
 
-	log = gtk_menu_item_new_with_mnemonic ("_Log");
-	gtk_widget_show (log);
-	gtk_container_add (GTK_CONTAINER (menubar), log);
-
-	log_menu = gtk_menu_new ();
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (log), log_menu);
-
-	new = gtk_image_menu_item_new_with_mnemonic (_("New..."));
-	gtk_widget_show (new);
-	gtk_container_add (GTK_CONTAINER (log_menu), new);
-	gtk_widget_add_accelerator (new, "activate", accel_group, GDK_n, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
-
-	image703 = gtk_image_new_from_stock ("gtk-new", GTK_ICON_SIZE_MENU);
-	gtk_widget_show (image703);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (new), image703);
-
-	open = gtk_image_menu_item_new_with_mnemonic (_("Open"));
-	gtk_widget_show (open);
-	gtk_container_add (GTK_CONTAINER (log_menu), open);
-	gtk_widget_add_accelerator (open, "activate", accel_group, GDK_o, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
-
-	image704 = gtk_image_new_from_stock ("gtk-open", GTK_ICON_SIZE_MENU);
-	gtk_widget_show (image704);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (open), image704);
-
-	scheidslijn1 = gtk_menu_item_new ();
-	gtk_widget_show (scheidslijn1);
-	gtk_container_add (GTK_CONTAINER (log_menu), scheidslijn1);
-	gtk_widget_set_sensitive (scheidslijn1, FALSE);
-
-	save = gtk_image_menu_item_new_with_mnemonic (_("Save"));
-	gtk_widget_show (save);
-	gtk_container_add (GTK_CONTAINER (log_menu), save);
-	gtk_widget_add_accelerator (save, "activate", accel_group, GDK_s, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
-
-	image705 = gtk_image_new_from_stock ("gtk-save", GTK_ICON_SIZE_MENU);
-	gtk_widget_show (image705);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (save), image705);
-
-	saveas = gtk_image_menu_item_new_with_mnemonic (_("Save As..."));
-	gtk_widget_show (saveas);
-	gtk_container_add (GTK_CONTAINER (log_menu), saveas);
-
-	image706 = gtk_image_new_from_stock ("gtk-save-as", GTK_ICON_SIZE_MENU);
-	gtk_widget_show (image706);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (saveas), image706);
-
-	close = gtk_image_menu_item_new_with_mnemonic (_("Close"));
-	gtk_widget_show (close);
-	gtk_container_add (GTK_CONTAINER (log_menu), close);
-	gtk_widget_add_accelerator (close, "activate", accel_group, GDK_q, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
-
-	image707 = gtk_image_new_from_stock ("gtk-close", GTK_ICON_SIZE_MENU);
-	gtk_widget_show (image707);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (close), image707);
-
-	scheidslijn2 = gtk_menu_item_new ();
-	gtk_widget_show (scheidslijn2);
-	gtk_container_add (GTK_CONTAINER (log_menu), scheidslijn2);
-	gtk_widget_set_sensitive (scheidslijn2, FALSE);
-
-	print = gtk_image_menu_item_new_with_mnemonic (_("Print"));
-	gtk_widget_show (print);
-	gtk_container_add (GTK_CONTAINER (log_menu), print);
-
-	image708 = gtk_image_new_from_stock ("gtk-print", GTK_ICON_SIZE_MENU);
-	gtk_widget_show (image708);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (print), image708);
-
-	exit = gtk_image_menu_item_new_with_mnemonic (_("Exit"));
-	gtk_widget_show (exit);
-	gtk_container_add (GTK_CONTAINER (log_menu), exit);
-	gtk_widget_add_accelerator (exit, "activate", accel_group, GDK_x, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
-
-	image709 = gtk_image_new_from_stock ("gtk-quit", GTK_ICON_SIZE_MENU);
-	gtk_widget_show (image709);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (exit), image709);
-
-	edit = gtk_menu_item_new_with_mnemonic (_("_Edit"));
-	gtk_widget_show (edit);
-	gtk_container_add (GTK_CONTAINER (menubar), edit);
-
-	edit_menu = gtk_menu_new ();
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (edit), edit_menu);
-
-	clearframe = gtk_image_menu_item_new_with_mnemonic (_("Clear all"));
-	gtk_widget_show (clearframe);
-	gtk_container_add (GTK_CONTAINER (edit_menu), clearframe);
-	gtk_widget_add_accelerator (clearframe, "activate", accel_group, GDK_y, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
-
-	image710 = gtk_image_new_from_stock ("gtk-clear", GTK_ICON_SIZE_MENU);
-	gtk_widget_show (image710);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (clearframe), image710);
-
-	search = gtk_image_menu_item_new_with_mnemonic (_("Find Callsign"));
-	gtk_widget_show (search);
-	gtk_container_add (GTK_CONTAINER (edit_menu), search);
-	gtk_widget_add_accelerator (search, "activate", accel_group, GDK_f, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
-
-	image711 = gtk_image_new_from_stock ("gtk-find", GTK_ICON_SIZE_MENU);
-	gtk_widget_show (image711);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (search), image711);
-
-	clickall = gtk_image_menu_item_new_with_mnemonic (_("Click all"));
-	gtk_widget_show (clickall);
-	gtk_container_add (GTK_CONTAINER (edit_menu), clickall);
-	gtk_widget_add_accelerator (clickall, "activate", accel_group, GDK_k, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
-
-	image712 = gtk_image_new_from_stock ("gtk-apply", GTK_ICON_SIZE_MENU);
-	gtk_widget_show (image712);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (clickall), image712);
-
-	tools = gtk_menu_item_new_with_mnemonic (_("_Tools"));
-	gtk_widget_show (tools);
-	gtk_container_add (GTK_CONTAINER (menubar), tools);
-
-	tools_menu = gtk_menu_new ();
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (tools), tools_menu);
-
-	log_editor = gtk_image_menu_item_new_with_mnemonic (_("Log Editor"));
-	gtk_widget_show (log_editor);
-	gtk_container_add (GTK_CONTAINER (tools_menu), log_editor);
-
-	image713 = gtk_image_new_from_stock ("gtk-properties", GTK_ICON_SIZE_MENU);
-	gtk_widget_show (image713);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (log_editor), image713);
-
-	dupecheck = gtk_image_menu_item_new_with_mnemonic (_("Dupe Check..."));
-	gtk_widget_show (dupecheck);
-	gtk_container_add (GTK_CONTAINER (tools_menu), dupecheck);
-
-  image791 = gtk_image_new_from_stock ("gtk-find-and-replace", GTK_ICON_SIZE_MENU);
-  gtk_widget_show (image791);
-  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (dupecheck), image791);
-
-	trace_hamlib = gtk_image_menu_item_new_with_mnemonic (_("Trace Hamlib"));
-	gtk_widget_show (trace_hamlib);
-	gtk_container_add (GTK_CONTAINER (tools_menu), trace_hamlib);
-
-	image714 = gtk_image_new_from_stock ("gtk-execute", GTK_ICON_SIZE_MENU);
-	gtk_widget_show (image714);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (trace_hamlib), image714);
-
-	sort_log = gtk_image_menu_item_new_with_mnemonic (_("Sort Log by Date"));
-	gtk_widget_show (sort_log);
-	gtk_container_add (GTK_CONTAINER (tools_menu), sort_log);
-
-  image733 = gtk_image_new_from_stock ("gtk-go-down", GTK_ICON_SIZE_MENU);
-  gtk_widget_show (image733);
-  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (sort_log), image733);
-
-	separator2 = gtk_menu_item_new ();
-	gtk_widget_show (separator2);
-	gtk_container_add (GTK_CONTAINER (tools_menu), separator2);
-	gtk_widget_set_sensitive (separator2, FALSE);
-
-	view_toolbar = gtk_check_menu_item_new_with_mnemonic (_("View Toolbar"));
-	gtk_widget_show (view_toolbar);
-	gtk_container_add (GTK_CONTAINER (tools_menu), view_toolbar);
-	gtk_widget_add_accelerator (view_toolbar, "activate", accel_group, GDK_t, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
-
-	worked = gtk_check_menu_item_new_with_mnemonic (_("Worked Before"));
-	gtk_widget_show (worked);
-	gtk_container_add (GTK_CONTAINER (tools_menu), worked);
-	gtk_widget_add_accelerator (worked, "activate", accel_group, GDK_w, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
-
-	settings = gtk_menu_item_new_with_mnemonic (_("_Settings"));
-	gtk_widget_show (settings);
-	gtk_container_add (GTK_CONTAINER (menubar), settings);
-
-	settings_menu = gtk_menu_new ();
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (settings), settings_menu);
-
-	defaults = gtk_image_menu_item_new_with_mnemonic (_("Defaults"));
-	gtk_widget_show (defaults);
-	gtk_container_add (GTK_CONTAINER (settings_menu), defaults);
-
-	image715 = gtk_image_new_from_stock ("gtk-index", GTK_ICON_SIZE_MENU);
-	gtk_widget_show (image715);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (defaults), image715);
-
-	dialogs = gtk_image_menu_item_new_with_mnemonic (_("Dialogs"));
-	gtk_widget_show (dialogs);
-	gtk_container_add (GTK_CONTAINER (settings_menu), dialogs);
-
-	image716 = gtk_image_new_from_stock ("gtk-justify-fill", GTK_ICON_SIZE_MENU);
-	gtk_widget_show (image716);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (dialogs), image716);
-
-	separator1 = gtk_menu_item_new ();
-	gtk_widget_show (separator1);
-	gtk_container_add (GTK_CONTAINER (settings_menu), separator1);
-	gtk_widget_set_sensitive (separator1, FALSE);
-
-	preferences = gtk_image_menu_item_new_with_mnemonic (_("Preferences..."));
-	gtk_widget_show (preferences);
-	gtk_container_add (GTK_CONTAINER (settings_menu), preferences);
-
-	image717 = gtk_image_new_from_stock ("gtk-preferences", GTK_ICON_SIZE_MENU);
-	gtk_widget_show (image717);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (preferences), image717);
-
-	help = gtk_menu_item_new_with_mnemonic (_("_Help"));
-	gtk_widget_show (help);
-	gtk_container_add (GTK_CONTAINER (menubar), help);
-
-	help_menu = gtk_menu_new ();
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (help), help_menu);
-
-	documentation1 = gtk_image_menu_item_new_with_mnemonic (_("Documentation"));
-	gtk_widget_show (documentation1);
-	gtk_container_add (GTK_CONTAINER (help_menu), documentation1);
-
-	image718 = gtk_image_new_from_stock ("gtk-help", GTK_ICON_SIZE_MENU);
-	gtk_widget_show (image718);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (documentation1), image718);
-
-	documentation1_menu = gtk_menu_new ();
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (documentation1), documentation1_menu);
-
-	helpfaq = gtk_menu_item_new_with_mnemonic (_("Faq"));
-	gtk_widget_show (helpfaq);
-	gtk_container_add (GTK_CONTAINER (documentation1_menu), helpfaq);
-
-	helpmanual = gtk_image_menu_item_new_with_mnemonic (_("Manual"));
-	gtk_widget_show (helpmanual);
-	gtk_container_add (GTK_CONTAINER (documentation1_menu), helpmanual);
-
-	image719 = create_pixmap (mainwindow, "book.xpm");
-	gtk_widget_show (image719);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (helpmanual), image719);
-
-	helpreadme = gtk_image_menu_item_new_with_mnemonic (_("Readme"));
-	gtk_widget_show (helpreadme);
-	gtk_container_add (GTK_CONTAINER (documentation1_menu), helpreadme);
-
-	image720 = gtk_image_new_from_stock ("gtk-dialog-warning", GTK_ICON_SIZE_MENU);
-	gtk_widget_show (image720);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (helpreadme), image720);
-
-	helpthanks = gtk_menu_item_new_with_mnemonic (_("Thanks"));
-	gtk_widget_show (helpthanks);
-	gtk_container_add (GTK_CONTAINER (documentation1_menu), helpthanks);
-
-	helptodo = gtk_menu_item_new_with_mnemonic (_("Todo"));
-	gtk_widget_show (helptodo);
-	gtk_container_add (GTK_CONTAINER (documentation1_menu), helptodo);
-
-	scheidingslijn1 = gtk_menu_item_new ();
-	gtk_widget_show (scheidingslijn1);
-	gtk_container_add (GTK_CONTAINER (help_menu), scheidingslijn1);
-	gtk_widget_set_sensitive (scheidingslijn1, FALSE);
-
-	about = gtk_image_menu_item_new_with_mnemonic (_("About"));
-	gtk_widget_show (about);
-	gtk_container_add (GTK_CONTAINER (help_menu), about);
-
-	image721 = gtk_image_new_from_stock ("gtk-dialog-info", GTK_ICON_SIZE_MENU);
-	gtk_widget_show (image721);
-	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (about), image721);
+#if !WANT_HAMLIB
+	trace_hamlib = gtk_ui_manager_get_widget (ui_manager,
+		"/MainMenu/ToolsMenu/Trace Hamlib");
+	gtk_widget_hide (trace_hamlib);
+#endif
 
 	hpaned = gtk_hpaned_new ();
 	gtk_widget_show (hpaned);
@@ -533,10 +366,12 @@ create_mainwindow (void)
 	gtk_widget_show (hbox165);
 	gtk_container_add (GTK_CONTAINER (handlebox), hbox165);
 
+	buttontooltips = gtk_tooltips_new ();
 	abutton = gtk_button_new ();
 	gtk_widget_show (abutton);
 	gtk_box_pack_start (GTK_BOX (hbox165), abutton, TRUE, TRUE, 0);
-	gtk_tooltips_set_tip (tooltips, abutton, _("Add a new QSO to the log [Ctrl-A]"), NULL);
+	gtk_tooltips_set_tip (buttontooltips, abutton, 
+		_("Add a new QSO to the log [Ctrl-A]"), NULL);
 	gtk_widget_add_accelerator (abutton, "clicked", accel_group, GDK_a, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
 	vbox55 = gtk_vbox_new (FALSE, 0);
@@ -554,7 +389,8 @@ create_mainwindow (void)
 	ubutton = gtk_button_new ();
 	gtk_widget_show (ubutton);
 	gtk_box_pack_start (GTK_BOX (hbox165), ubutton, TRUE, TRUE, 0);
-	gtk_tooltips_set_tip (tooltips, ubutton, _("Update a modified log entry [Ctrl-U]"), NULL);
+	gtk_tooltips_set_tip (buttontooltips, ubutton, 
+		_("Update a modified log entry [Ctrl-U]"), NULL);
 	gtk_widget_add_accelerator (ubutton, "clicked", accel_group, GDK_u, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
 	vbox56 = gtk_vbox_new (FALSE, 0);
@@ -572,7 +408,8 @@ create_mainwindow (void)
 	dbutton = gtk_button_new ();
 	gtk_widget_show (dbutton);
 	gtk_box_pack_start (GTK_BOX (hbox165), dbutton, TRUE, TRUE, 0);
-	gtk_tooltips_set_tip (tooltips, dbutton, _("Delete a selected log entry [Ctrl-D]"), NULL);
+	gtk_tooltips_set_tip (buttontooltips, dbutton, 
+		_("Delete a selected log entry [Ctrl-D]"), NULL);
 	gtk_widget_add_accelerator (dbutton, "clicked", accel_group, GDK_d, GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
 
 	vbox57 = gtk_vbox_new (FALSE, 0);
@@ -701,15 +538,7 @@ create_mainwindow (void)
 	bandhbox2 = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (bandhbox2);
 	gtk_box_pack_start (GTK_BOX (bandhbox), bandhbox2, TRUE, TRUE, 0);
-
-	bandoptionmenu = gtk_option_menu_new ();
-	gtk_widget_show (bandoptionmenu);
-	gtk_box_pack_start (GTK_BOX (bandhbox2), bandoptionmenu, TRUE, TRUE, 0);
-	gtk_widget_set_size_request (bandoptionmenu, 130, 27);
-
-	convertwidget3 = gtk_menu_new ();
-
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (bandoptionmenu), convertwidget3);
+	GLADE_HOOKUP_OBJECT (mainwindow, bandhbox2, "bandhbox2");
 
 	bandentry = gtk_entry_new ();
 	gtk_widget_show (bandentry);
@@ -740,15 +569,7 @@ create_mainwindow (void)
 	modehbox2 = gtk_hbox_new (FALSE, 0);
 	gtk_widget_show (modehbox2);
 	gtk_box_pack_start (GTK_BOX (modehbox), modehbox2, TRUE, TRUE, 0);
-
-	modeoptionmenu = gtk_option_menu_new ();
-	gtk_widget_show (modeoptionmenu);
-	gtk_box_pack_start (GTK_BOX (modehbox2), modeoptionmenu, TRUE, TRUE, 0);
-	gtk_widget_set_size_request (modeoptionmenu, 130, 27);
-
-	convertwidget4 = gtk_menu_new ();
-
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (modeoptionmenu), convertwidget4);
+	GLADE_HOOKUP_OBJECT (mainwindow, modehbox2, "modehbox2");
 
 	modeentry = gtk_entry_new ();
 	gtk_widget_show (modeentry);
@@ -1069,33 +890,7 @@ create_mainwindow (void)
 	gtk_misc_set_padding (GTK_MISC (clocklabel), 5, 0);
 
 	g_signal_connect ((gpointer) mainwindow, "delete_event", G_CALLBACK (on_mainwindow_delete_event), NULL);
-	g_signal_connect ((gpointer) new, "activate", G_CALLBACK (on_menu_new_activate), NULL);
-	g_signal_connect ((gpointer) open, "activate", G_CALLBACK (on_menu_open_activate), NULL);
-	g_signal_connect ((gpointer) save, "activate", G_CALLBACK (on_menu_save_activate), NULL);
-	g_signal_connect ((gpointer) saveas, "activate", G_CALLBACK (on_menu_saveas_activate), NULL);
-	g_signal_connect ((gpointer) close, "activate", G_CALLBACK (on_menu_close_activate), NULL);
-	g_signal_connect ((gpointer) print, "activate", G_CALLBACK (on_menu_print_activate), NULL);
-	g_signal_connect ((gpointer) exit, "activate", G_CALLBACK (on_menu_exit_activate), NULL);
-	g_signal_connect ((gpointer) clearframe, "activate", G_CALLBACK (on_clearframe_activate), NULL);
-	g_signal_connect ((gpointer) search, "activate", G_CALLBACK (on_menu_search_activate), NULL);
-	g_signal_connect ((gpointer) clickall, "activate", G_CALLBACK (on_clickall_activate), NULL);
-	g_signal_connect ((gpointer) log_editor, "activate", G_CALLBACK (on_menu_logeditor_activate), NULL);
-	g_signal_connect ((gpointer) dupecheck, "activate", G_CALLBACK (on_menu_dupecheck_activate), NULL);
-#if WANT_HAMLIB
-	g_signal_connect ((gpointer) trace_hamlib, "activate", G_CALLBACK (on_trace_hamlib_activate), NULL);
-#endif
-  g_signal_connect ((gpointer) sort_log, "activate", G_CALLBACK (on_sort_log_activate), NULL);
-	g_signal_connect ((gpointer) view_toolbar, "activate", G_CALLBACK (on_view_toolbar_activate), NULL);
-	g_signal_connect ((gpointer) worked, "activate", G_CALLBACK (on_menu_worked_activate), NULL);
-	g_signal_connect ((gpointer) defaults, "activate", G_CALLBACK (on_menu_defaults_activate), NULL);
-	g_signal_connect ((gpointer) dialogs, "activate", G_CALLBACK (on_menu_dialogs_activate), NULL);
-	g_signal_connect ((gpointer) preferences, "activate", G_CALLBACK (on_menu_preferences_activate), NULL);
-	g_signal_connect ((gpointer) helpfaq, "activate", G_CALLBACK (on_helpfaq_activate), NULL);
-	g_signal_connect ((gpointer) helpmanual, "activate", G_CALLBACK (on_helpmanual_activate), NULL);
-	g_signal_connect ((gpointer) helpreadme, "activate", G_CALLBACK (on_helpreadme_activate), NULL);
-	g_signal_connect ((gpointer) helpthanks, "activate", G_CALLBACK (on_helpthanks_activate), NULL);
-	g_signal_connect ((gpointer) helptodo, "activate", G_CALLBACK (on_helptodo_activate), NULL);
-	g_signal_connect ((gpointer) about, "activate", G_CALLBACK (on_menu_about_activate), NULL);
+
 	g_signal_connect ((gpointer) abutton, "clicked", G_CALLBACK (on_abutton_clicked), NULL);
 	g_signal_connect ((gpointer) ubutton, "clicked", G_CALLBACK (on_ubutton_clicked), NULL);
 	g_signal_connect ((gpointer) dbutton, "clicked", G_CALLBACK (on_dbutton_clicked), NULL);
@@ -1104,26 +899,14 @@ create_mainwindow (void)
 	g_signal_connect ((gpointer) endbutton, "clicked", G_CALLBACK (on_endbutton_clicked), NULL);
 	g_signal_connect ((gpointer) callentry, "insert_text", G_CALLBACK (on_callentry_insert_text), NULL);
 	g_signal_connect ((gpointer) callentry, "changed", G_CALLBACK (on_callentry_changed), NULL);
-	g_signal_connect ((gpointer) bandoptionmenu, "key_press_event", G_CALLBACK (on_bandoptionmenu_key_press_event), NULL);
-	g_signal_connect ((gpointer) modeoptionmenu, "key_press_event", G_CALLBACK (on_modeoptionmenu_key_press_event), NULL);
 	g_signal_connect ((gpointer) locatorentry, "changed", G_CALLBACK (on_locatorentry_changed), NULL);
 
+
 	/* Store pointers to all widgets, for use by lookup_widget(). */
 	GLADE_HOOKUP_OBJECT_NO_REF (mainwindow, mainwindow, "mainwindow");
 	
-	/* next 2 menus used in newlogdialog */
-	GLADE_HOOKUP_OBJECT (mainwindow, menubar, "menubar");
-	GLADE_HOOKUP_OBJECT (mainwindow, log_editor, "log_editor");
-	GLADE_HOOKUP_OBJECT (mainwindow, clearframe, "clearframe");
-
-	GLADE_HOOKUP_OBJECT (mainwindow, view_toolbar, "view_toolbar");
-	GLADE_HOOKUP_OBJECT (mainwindow, worked, "worked");
-	GLADE_HOOKUP_OBJECT (mainwindow, trace_hamlib, "trace_hamlib");
-	GLADE_HOOKUP_OBJECT (mainwindow, sort_log, "sort_log");
-
 	GLADE_HOOKUP_OBJECT (mainwindow, handlebox, "handlebox");
 	GLADE_HOOKUP_OBJECT (mainwindow, hpaned, "hpaned");
-
 	GLADE_HOOKUP_OBJECT (mainwindow, qsoframe, "qsoframe");
 	GLADE_HOOKUP_OBJECT (mainwindow, datebutton, "datebutton");
 	GLADE_HOOKUP_OBJECT (mainwindow, dateentry, "dateentry");
@@ -1136,11 +919,9 @@ create_mainwindow (void)
 	GLADE_HOOKUP_OBJECT (mainwindow, callentry, "callentry");
 	GLADE_HOOKUP_OBJECT (mainwindow, mhzbutton, "mhzbutton");
 	GLADE_HOOKUP_OBJECT (mainwindow, mhzlabel, "mhzlabel");
-	GLADE_HOOKUP_OBJECT (mainwindow, bandoptionmenu, "bandoptionmenu");
 	GLADE_HOOKUP_OBJECT (mainwindow, bandentry, "bandentry");
 	GLADE_HOOKUP_OBJECT (mainwindow, modebutton, "modebutton");
 	GLADE_HOOKUP_OBJECT (mainwindow, modelabel, "modelabel");
-	GLADE_HOOKUP_OBJECT (mainwindow, modeoptionmenu, "modeoptionmenu");
 	GLADE_HOOKUP_OBJECT (mainwindow, modeentry, "modeentry");
 	GLADE_HOOKUP_OBJECT (mainwindow, rstbutton, "rstbutton");
 	GLADE_HOOKUP_OBJECT (mainwindow, rstlabel, "rstlabel");
@@ -1193,7 +974,5 @@ create_mainwindow (void)
 	GLADE_HOOKUP_OBJECT (mainwindow, clockhandlebox, "clockhandlebox");
 	GLADE_HOOKUP_OBJECT (mainwindow, clocklabel, "clocklabel");
 
-	gtk_window_add_accel_group (GTK_WINDOW (mainwindow), accel_group);
-
 	return mainwindow;
 }
