@@ -28,11 +28,14 @@
 #include <string.h>
 
 #include "gui_newlogdialog.h"
+#include "gui_logeditordialog.h"
 #include "gui_warningdialog.h"
+#include "callbacks_mainwindow_menu.h"
 #include "support.h"
 #include "types.h"
 #include "log.h"
 #include "utils.h"
+#include "gui_utils.h"
 
 extern GList *logwindowlist;
 extern GtkWidget *mainnotebook;
@@ -73,8 +76,7 @@ void
 on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
 	GtkWidget *newlogdialog, *dialog_vbox, *vbox, *label1, *hbox, *label2,
-		*newlogentry, *dialog_action_area, *newlogcancelbutton, *newlogokbutton,
-		*menubar, *log_editor_menu, *clearframe_menu;
+		*newlogentry, *dialog_action_area, *newlogcancelbutton, *newlogokbutton;
 	GdkPixbuf *newlogdialog_icon_pixbuf;
 	gchar *entry, *filename, *xlogbackupfile;
 	logtype *logwindow = NULL;
@@ -154,6 +156,7 @@ on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 					gtk_notebook_set_current_page (GTK_NOTEBOOK(mainnotebook), i);
 					set_qsoframe (logwindow);
 					logopen = TRUE;
+					update_statusbar (_("A log with the same name is already open"));
 					break;
 				}
 			}
@@ -174,9 +177,11 @@ on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 						logwindowlist =	g_list_append (logwindowlist, logwindow);
 						gtk_notebook_set_current_page(GTK_NOTEBOOK (mainnotebook), state.logwindows - 1);
 						set_qsoframe (logwindow);
+						set_tabs_menu ();
 						xlogbackupfile =	g_strconcat (filename, ".backup", NULL);
 						savelog (logwindow, xlogbackupfile, TYPE_FLOG, 1, logwindow->qsos);
 						g_free (xlogbackupfile);
+						update_statusbar (_("A log with this name already exists"));
 					}
 					g_free (filename);
 					g_string_free (logs, TRUE);
@@ -190,9 +195,11 @@ on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 				{
 					logwindow =	openlog (lp, entry, state.logwindows++);
 					log_file_close (lp);
+					logwindow->filename = g_strdup (filename);
 					logwindowlist =	g_list_append (logwindowlist, logwindow);
 					gtk_notebook_set_current_page (GTK_NOTEBOOK(mainnotebook), state.logwindows - 1);
 					set_qsoframe (logwindow);
+					set_tabs_menu ();
 				}	
 				g_free (filename);
 			}
@@ -203,8 +210,7 @@ on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 			gtk_widget_destroy (newlogdialog);
 			return;
 		}
-		clearframe_menu = lookup_widget (mainwindow, "clearframe");
-		g_signal_emit_by_name (G_OBJECT (clearframe_menu), "activate");
+		on_clearframe_activate (NULL, NULL);
 		gtk_widget_destroy (newlogdialog);
 
 		if (logexist && state.utf8error) 
@@ -217,9 +223,7 @@ on_menu_new_activate (GtkMenuItem * menuitem, gpointer user_data)
 		/* now fire up the logeditor */
 		if ((!logopen) && (!logexist))
 		{
-			menubar = lookup_widget (mainwindow, "menubar");
-			log_editor_menu = lookup_widget (menubar, "log_editor");
-			g_signal_emit_by_name (G_OBJECT (log_editor_menu), "activate");
+			on_menu_logeditor_activate (NULL, NULL);
 		}
 	} /* cancel clicked */
 	else
