@@ -116,13 +116,9 @@ create_preferencesdialog (void)
 	GtkWidget *labelloc;
 	GtkWidget *hbox148;
 	GtkWidget *latentry;
-	GtkWidget *combo4;
-	GList *combo4_items = NULL;
-	GtkWidget *NScomboentry;
+	GtkWidget *NScombo;
 	GtkWidget *longentry;
-	GtkWidget *combo5;
-	GList *combo5_items = NULL;
-	GtkWidget *EWcomboentry;
+	GtkWidget *EWcombo;
 	GtkWidget *hbox154;
 	GtkWidget *label103;
 	GtkWidget *qthlocatorentry;
@@ -131,8 +127,6 @@ create_preferencesdialog (void)
 	GtkWidget *hbox10;
 	GtkWidget *labeldist;
 	GtkWidget *unitscombo;
-	GList *unitscombo_items = NULL;
-	GtkWidget *unitscomboentry;
 	GtkWidget *label111;
 	GtkWidget *preferenceslabel3;
 	GtkWidget *vbox12;
@@ -142,13 +136,9 @@ create_preferencesdialog (void)
 	GtkWidget *hbox25;
 	GtkWidget *radiolabel;
 	GtkWidget *radiocombo;
-	GList *radiocombo_items = NULL;
-	GtkWidget *radiocomboentry;
 	GtkWidget *hbox26;
 	GtkWidget *devicelabel;
 	GtkWidget *devicecombo;
-	GList *devicecombo_items = NULL;
-	GtkWidget *devicecomboentry;
 	GtkWidget *hseparator10;
 	GtkWidget *label202;
 	GtkWidget *rigsetconfentry;
@@ -158,8 +148,6 @@ create_preferencesdialog (void)
 	GtkWidget *hbox161;
 	GtkWidget *label197;
 	GtkWidget *pollcombo;
-	GList *pollcombo_items = NULL;
-	GtkWidget *pollcomboentry;
 	GtkWidget *label198;
 	GtkWidget *label200;
 	GtkWidget *smetercheckbutton;
@@ -176,8 +164,6 @@ create_preferencesdialog (void)
 	GtkWidget *hbox36;
 	GtkWidget *label39;
 	GtkWidget *digitscombo;
-	GList *digitscombo_items = NULL;
-	GtkWidget *digitscomboentry;
 	GtkWidget *label40;
 	GtkWidget *label201;
 	GtkWidget *label112;
@@ -206,8 +192,6 @@ create_preferencesdialog (void)
 	GtkWidget *hbox37;
 	GtkWidget *label41;
 	GtkWidget *autosavecombo;
-	GList *autosavecombo_items = NULL;
-	GtkWidget *autosavecomboentry;
 	GtkWidget *label42;
 	GtkWidget *label114;
 	GtkWidget *label92;
@@ -543,19 +527,11 @@ create_preferencesdialog (void)
 	gtk_widget_set_size_request (latentry, 50, 23);
 	gtk_entry_set_max_length (GTK_ENTRY (latentry), 8);
 
-	combo4 = gtk_combo_new ();
-	g_object_set_data (G_OBJECT (GTK_COMBO (combo4)->popwin),	"GladeParentKey", combo4);
-	gtk_widget_show (combo4);
-	gtk_box_pack_start (GTK_BOX (hbox148), combo4, TRUE, TRUE, 0);
-	gtk_widget_set_size_request (combo4, 50, 23);
-	combo4_items = g_list_append (combo4_items, (gpointer) _("N"));
-	combo4_items = g_list_append (combo4_items, (gpointer) _("S"));
-	gtk_combo_set_popdown_strings (GTK_COMBO (combo4), combo4_items);
-	g_list_free (combo4_items);
-
-	NScomboentry = GTK_COMBO (combo4)->entry;
-	gtk_widget_show (NScomboentry);
-	gtk_editable_set_editable (GTK_EDITABLE (NScomboentry), FALSE);
+	NScombo = gtk_combo_box_new_text ();
+	gtk_widget_show (NScombo);
+	gtk_box_pack_start (GTK_BOX (hbox148), NScombo, TRUE, TRUE, 0);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (NScombo), _("N"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (NScombo), _("S"));
 
 	longentry = gtk_entry_new ();
 	gtk_widget_show (longentry);
@@ -563,19 +539,11 @@ create_preferencesdialog (void)
 	gtk_widget_set_size_request (longentry, 50, 23);
 	gtk_entry_set_max_length (GTK_ENTRY (longentry), 8);
 
-	combo5 = gtk_combo_new ();
-	g_object_set_data (G_OBJECT (GTK_COMBO (combo5)->popwin),	"GladeParentKey", combo5);
-	gtk_widget_show (combo5);
-	gtk_box_pack_start (GTK_BOX (hbox148), combo5, TRUE, TRUE, 0);
-	gtk_widget_set_size_request (combo5, 50, 23);
-	combo5_items = g_list_append (combo5_items, (gpointer) _("E"));
-	combo5_items = g_list_append (combo5_items, (gpointer) _("W"));
-	gtk_combo_set_popdown_strings (GTK_COMBO (combo5), combo5_items);
-	g_list_free (combo5_items);
-
-	EWcomboentry = GTK_COMBO (combo5)->entry;
-	gtk_widget_show (EWcomboentry);
-	gtk_editable_set_editable (GTK_EDITABLE (EWcomboentry), FALSE);
+	EWcombo = gtk_combo_box_new_text ();
+	gtk_widget_show (EWcombo);
+	gtk_box_pack_start (GTK_BOX (hbox148), EWcombo, TRUE, TRUE, 0);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (EWcombo), _("E"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (EWcombo), _("W"));
 
 	hbox154 = gtk_hbox_new (TRUE, 0);
 	gtk_widget_show (hbox154);
@@ -612,20 +580,11 @@ create_preferencesdialog (void)
 	gtk_label_set_justify (GTK_LABEL (labeldist), GTK_JUSTIFY_CENTER);
 	gtk_label_set_line_wrap (GTK_LABEL (labeldist), TRUE);
 
-	unitscombo = gtk_combo_new ();
-	g_object_set_data (G_OBJECT (GTK_COMBO (unitscombo)->popwin),	"GladeParentKey", unitscombo);
+	unitscombo = gtk_combo_box_new_text ();
 	gtk_widget_show (unitscombo);
 	gtk_box_pack_start (GTK_BOX (hbox10), unitscombo, TRUE, TRUE, 0);
-	gtk_widget_set_size_request (unitscombo, 50, 23);
-	gtk_combo_set_value_in_list (GTK_COMBO (unitscombo), TRUE, FALSE);
-	unitscombo_items = g_list_append (unitscombo_items, (gpointer) _("Kilometers"));
-	unitscombo_items = g_list_append (unitscombo_items, (gpointer) _("Miles"));
-	gtk_combo_set_popdown_strings (GTK_COMBO (unitscombo), unitscombo_items);
-	g_list_free (unitscombo_items);
-
-	unitscomboentry = GTK_COMBO (unitscombo)->entry;
-	gtk_widget_show (unitscomboentry);
-	gtk_editable_set_editable (GTK_EDITABLE (unitscomboentry), FALSE);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (unitscombo), _("Kilometers"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (unitscombo), _("Miles"));
 
 	label111 = gtk_label_new (_("Units"));
 	gtk_widget_show (label111);
@@ -663,18 +622,10 @@ create_preferencesdialog (void)
 	gtk_label_set_line_wrap (GTK_LABEL (radiolabel), TRUE);
 	gtk_misc_set_padding (GTK_MISC (radiolabel), 5, 0);
 
-	radiocombo = gtk_combo_new ();
-	g_object_set_data (G_OBJECT (GTK_COMBO (radiocombo)->popwin),	"GladeParentKey", radiocombo);
+	radiocombo = gtk_combo_box_entry_new_text ();
 	gtk_widget_show (radiocombo);
-	gtk_box_pack_start (GTK_BOX (hbox25), radiocombo, TRUE, TRUE, 5);
-	gtk_widget_set_size_request (radiocombo, 100, 23);
-	radiocombo_items = g_list_append (radiocombo_items, (gpointer) "");
-	gtk_combo_set_popdown_strings (GTK_COMBO (radiocombo), radiocombo_items);
-	g_list_free (radiocombo_items);
-
-	radiocomboentry = GTK_COMBO (radiocombo)->entry;
-	gtk_widget_show (radiocomboentry);
-	gtk_editable_set_editable (GTK_EDITABLE (radiocomboentry), FALSE);
+	gtk_box_pack_start (GTK_BOX (hbox25), radiocombo, TRUE, TRUE, 0);
+	gtk_editable_set_editable (GTK_EDITABLE (GTK_BIN(radiocombo)->child), FALSE);
 
 	hbox26 = gtk_hbox_new (TRUE, 0);
 	gtk_widget_show (hbox26);
@@ -687,22 +638,15 @@ create_preferencesdialog (void)
 	gtk_label_set_line_wrap (GTK_LABEL (devicelabel), TRUE);
 	gtk_misc_set_padding (GTK_MISC (devicelabel), 5, 0);
 
-	devicecombo = gtk_combo_new ();
-	g_object_set_data (G_OBJECT (GTK_COMBO (devicecombo)->popwin),	"GladeParentKey", devicecombo);
+	devicecombo = gtk_combo_box_entry_new_text ();
 	gtk_widget_show (devicecombo);
-	gtk_box_pack_start (GTK_BOX (hbox26), devicecombo, TRUE, TRUE, 5);
-	gtk_widget_set_size_request (devicecombo, 100, 23);
-	devicecombo_items = g_list_append (devicecombo_items, (gpointer) "/dev/ttyS0");
-	devicecombo_items = g_list_append (devicecombo_items, (gpointer) "/dev/ttyS1");
-	devicecombo_items = g_list_append (devicecombo_items, (gpointer) "/dev/ttyS2");
-	devicecombo_items = g_list_append (devicecombo_items, (gpointer) "/dev/ttyS3");
-	devicecombo_items = g_list_append (devicecombo_items, (gpointer) "localhost");
-	gtk_combo_set_popdown_strings (GTK_COMBO (devicecombo), devicecombo_items);
-	g_list_free (devicecombo_items);
-
-	devicecomboentry = GTK_COMBO (devicecombo)->entry;
-	gtk_widget_show (devicecomboentry);
-	gtk_entry_set_max_length (GTK_ENTRY (devicecomboentry), 30);
+	gtk_box_pack_start (GTK_BOX (hbox26), devicecombo, TRUE, TRUE, 0);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyS0");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyS1");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyS2");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "/dev/ttyS3");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (devicecombo), "localhost");
+	gtk_entry_set_max_length (GTK_ENTRY (GTK_BIN(devicecombo)->child), 30);
 
 	hseparator10 = gtk_hseparator_new ();
 	gtk_widget_show (hseparator10);
@@ -745,24 +689,17 @@ create_preferencesdialog (void)
 	gtk_label_set_line_wrap (GTK_LABEL (label197), TRUE);
 	gtk_misc_set_padding (GTK_MISC (label197), 5, 0);
 
-	pollcombo = gtk_combo_new ();
-	g_object_set_data (G_OBJECT (GTK_COMBO (pollcombo)->popwin),	"GladeParentKey", pollcombo);
+	pollcombo = gtk_combo_box_entry_new_text ();
 	gtk_widget_show (pollcombo);
 	gtk_box_pack_start (GTK_BOX (hbox161), pollcombo, FALSE, FALSE, 5);
-	gtk_widget_set_size_request (pollcombo, 100, 23);
-	pollcombo_items = g_list_append (pollcombo_items, (gpointer) "300");
-	pollcombo_items = g_list_append (pollcombo_items, (gpointer) "400");
-	pollcombo_items = g_list_append (pollcombo_items, (gpointer) "500");
-	pollcombo_items = g_list_append (pollcombo_items, (gpointer) "700");
-	pollcombo_items = g_list_append (pollcombo_items, (gpointer) "1000");
-	pollcombo_items = g_list_append (pollcombo_items, (gpointer) "2000");
-	pollcombo_items = g_list_append (pollcombo_items, (gpointer) "3000");
-	gtk_combo_set_popdown_strings (GTK_COMBO (pollcombo), pollcombo_items);
-	g_list_free (pollcombo_items);
-
-	pollcomboentry = GTK_COMBO (pollcombo)->entry;
-	gtk_widget_show (pollcomboentry);
-	gtk_editable_set_editable (GTK_EDITABLE (pollcomboentry), FALSE);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (pollcombo), "300");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (pollcombo), "400");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (pollcombo), "500");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (pollcombo), "700");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (pollcombo), "1000");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (pollcombo), "2000");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (pollcombo), "3000");
+	gtk_editable_set_editable (GTK_EDITABLE (GTK_BIN(pollcombo)->child), FALSE);
 
 	label198 = gtk_label_new (_("milliseconds"));
 	gtk_widget_show (label198);
@@ -836,23 +773,16 @@ create_preferencesdialog (void)
 	gtk_label_set_line_wrap (GTK_LABEL (label39), TRUE);
 	gtk_misc_set_padding (GTK_MISC (label39), 5, 0);
 
-	digitscombo = gtk_combo_new ();
-	g_object_set_data (G_OBJECT (GTK_COMBO (digitscombo)->popwin),	"GladeParentKey", digitscombo);
+	digitscombo = gtk_combo_box_entry_new_text ();
 	gtk_widget_show (digitscombo);
 	gtk_box_pack_start (GTK_BOX (hbox36), digitscombo, FALSE, FALSE, 5);
-	gtk_widget_set_size_request (digitscombo, 100, 23);
-	digitscombo_items = g_list_append (digitscombo_items, (gpointer) "0");
-	digitscombo_items = g_list_append (digitscombo_items, (gpointer) "1");
-	digitscombo_items = g_list_append (digitscombo_items, (gpointer) "2");
-	digitscombo_items = g_list_append (digitscombo_items, (gpointer) "3");
-	digitscombo_items = g_list_append (digitscombo_items, (gpointer) "4");
-	digitscombo_items = g_list_append (digitscombo_items, (gpointer) "5");
-	gtk_combo_set_popdown_strings (GTK_COMBO (digitscombo), digitscombo_items);
-	g_list_free (digitscombo_items);
-
-	digitscomboentry = GTK_COMBO (digitscombo)->entry;
-	gtk_widget_show (digitscomboentry);
-	gtk_editable_set_editable (GTK_EDITABLE (digitscomboentry), FALSE);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (digitscombo), "0");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (digitscombo), "1");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (digitscombo), "2");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (digitscombo), "3");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (digitscombo), "4");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (digitscombo), "5");
+	gtk_editable_set_editable (GTK_EDITABLE (GTK_BIN(digitscombo)->child), FALSE);
 
 	label40 = gtk_label_new (_("characters"));
 	gtk_widget_show (label40);
@@ -980,26 +910,20 @@ create_preferencesdialog (void)
 	gtk_label_set_line_wrap (GTK_LABEL (label41), TRUE);
 	gtk_misc_set_padding (GTK_MISC (label41), 5, 0);
 
-	autosavecombo = gtk_combo_new ();
-	g_object_set_data (G_OBJECT (GTK_COMBO (autosavecombo)->popwin),	"GladeParentKey", autosavecombo);
+	autosavecombo = gtk_combo_box_entry_new_text ();
 	gtk_widget_show (autosavecombo);
-	gtk_box_pack_start (GTK_BOX (hbox37), autosavecombo, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox37), autosavecombo, FALSE, FALSE, 5);
 	gtk_widget_set_size_request (autosavecombo, 100, 23);
-	autosavecombo_items = g_list_append (autosavecombo_items, (gpointer) "5");
-	autosavecombo_items = g_list_append (autosavecombo_items, (gpointer) "10");
-	autosavecombo_items = g_list_append (autosavecombo_items, (gpointer) "20");
-	autosavecombo_items = g_list_append (autosavecombo_items, (gpointer) "30");
-	autosavecombo_items = g_list_append (autosavecombo_items, (gpointer) "40");
-	autosavecombo_items = g_list_append (autosavecombo_items, (gpointer) "50");
-	autosavecombo_items = g_list_append (autosavecombo_items, (gpointer) "60");
-	autosavecombo_items = g_list_append (autosavecombo_items, (gpointer) "90");
-	autosavecombo_items = g_list_append (autosavecombo_items, (gpointer) "120");
-	gtk_combo_set_popdown_strings (GTK_COMBO (autosavecombo), autosavecombo_items);
-	g_list_free (autosavecombo_items);
-
-	autosavecomboentry = GTK_COMBO (autosavecombo)->entry;
-	gtk_widget_show (autosavecomboentry);
-	gtk_editable_set_editable (GTK_EDITABLE (autosavecomboentry), FALSE);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (autosavecombo), "5");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (autosavecombo), "10");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (autosavecombo), "20");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (autosavecombo), "30");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (autosavecombo), "40");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (autosavecombo), "50");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (autosavecombo), "60");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (autosavecombo), "90");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (autosavecombo), "120");
+	gtk_editable_set_editable (GTK_EDITABLE (GTK_BIN(autosavecombo)->child), FALSE);
 
 	label42 = gtk_label_new (_("minutes"));
 	gtk_widget_show (label42);
@@ -1110,32 +1034,26 @@ create_preferencesdialog (void)
 	GLADE_HOOKUP_OBJECT (preferencesdialog, bandsentry, "bandsentry");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, callsignentry, "callsignentry");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, latentry, "latentry");
-	GLADE_HOOKUP_OBJECT (preferencesdialog, NScomboentry, "NScomboentry");
+	GLADE_HOOKUP_OBJECT (preferencesdialog, NScombo, "NScombo");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, longentry, "longentry");
-	GLADE_HOOKUP_OBJECT (preferencesdialog, EWcomboentry, "EWcomboentry");
+	GLADE_HOOKUP_OBJECT (preferencesdialog, EWcombo, "EWcombo");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, qthlocatorentry, "qthlocatorentry");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, unitscombo, "unitscombo");
-	GLADE_HOOKUP_OBJECT (preferencesdialog, unitscomboentry, "unitscomboentry");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, hamlibcheckbutton, "hamlibcheckbutton");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, radiocombo, "radiocombo");
-	GLADE_HOOKUP_OBJECT (preferencesdialog, radiocomboentry, "radiocomboentry");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, devicecombo, "devicecombo");
-	GLADE_HOOKUP_OBJECT (preferencesdialog, devicecomboentry, "devicecomboentry");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, rigsetconfentry, "rigsetconfentry");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, pollingcheckbutton, "pollingcheckbutton");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, pollcombo, "pollcombo");
-	GLADE_HOOKUP_OBJECT (preferencesdialog, pollcomboentry, "pollcomboentry");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, smetercheckbutton, "smetercheckbutton");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, frequencycheckbutton, "frequencycheckbutton");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, digitscombo, "digitscombo");
-	GLADE_HOOKUP_OBJECT (preferencesdialog, digitscomboentry, "digitscomboentry");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, pathentry, "pathentry");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, pathbutton, "pathbutton");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, logsentry, "logsentry");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, savecheckbutton, "savecheckbutton");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, autosavecheckbutton, "autosavecheckbutton");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, autosavecombo, "autosavecombo");
-	GLADE_HOOKUP_OBJECT (preferencesdialog, autosavecomboentry, "autosavecomboentry");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, typeaheadfindcheckbutton, "typeaheadfindcheckbutton");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, remoteradiobutton1, "remoteradiobutton1");
 	GLADE_HOOKUP_OBJECT (preferencesdialog, remoteradiobutton2, "remoteradiobutton2");
@@ -1151,22 +1069,21 @@ create_preferencesdialog (void)
 void
 on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	GtkWidget *latentry, *longentry, *NScomboentry,
-		*EWcomboentry, *unitscomboentry, *modesentry, *bandsentry,
+	GtkWidget *latentry, *longentry, *NScombo,
+		*EWcombo, *unitscombo, *modesentry, *bandsentry,
 		*modesradiobutton1, *modesradiobutton2, *bandsradiobutton1,
 		*bandsradiobutton2, *modeslabel, *bandslabel, *clockcheckbutton,
-		*exampleframe, *examplelabel, *autosavecomboentry, 
+		*exampleframe, *examplelabel, *autosavecombo, 
 		*themecheckbutton, *pathentry, *logsentry, *qthlocatorentry,
 		*callsignentry, *fontentry, *savecheckbutton, *autosavecheckbutton,
 		*autosaveframe, *typeaheadfindcheckbutton, *remoteradiobutton1,
 		*remoteradiobutton2;
 	gchar *temp;
 #if WANT_HAMLIB
-	GtkWidget *hamlibcheckbutton, *radiocombo, *hamlibframe, *radiocomboentry,
-		*devicecomboentry, *frequencycheckbutton, *digitscomboentry,
-		*smetercheckbutton, *pollingcheckbutton, *rigsetconfentry, *pollcomboentry;
-	GList *combolist = NULL;
-	gint i, numrigs;
+	GtkWidget *hamlibcheckbutton, *radiocombo, *hamlibframe,
+		*devicecombo, *frequencycheckbutton, *digitscombo,
+		*smetercheckbutton, *pollingcheckbutton, *rigsetconfentry, *pollcombo;
+	gint i, indexradio = -1, numrigs;
 	struct rig_caps *rcaps;
 #else
 	GtkWidget *notebook;
@@ -1212,9 +1129,8 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 
 	/* saving */
 	temp = g_strdup_printf ("%d", preferences.autosave);
-	autosavecomboentry =
-		lookup_widget (preferencesdialog, "autosavecomboentry");
-	gtk_entry_set_text (GTK_ENTRY (autosavecomboentry), temp);
+	autosavecombo =	lookup_widget (preferencesdialog, "autosavecombo");
+	gtk_entry_set_text (GTK_ENTRY (GTK_BIN(autosavecombo)->child), temp);
 	autosavecheckbutton = lookup_widget (preferencesdialog, "autosavecheckbutton");
 	autosaveframe = lookup_widget (preferencesdialog, "autosaveframe");
 	savecheckbutton = lookup_widget (preferencesdialog, "savecheckbutton");
@@ -1257,63 +1173,64 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		lookup_widget (preferencesdialog, "frequencycheckbutton");
 	smetercheckbutton = lookup_widget (preferencesdialog, "smetercheckbutton");
 	if (preferences.hamlib == 0)
-		{
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (hamlibcheckbutton),
-						FALSE);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (frequencycheckbutton),
-						FALSE);
-			gtk_widget_set_sensitive (hamlibframe, 0);
-		}
-	else
-		{
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (hamlibcheckbutton),
-						TRUE);
-			if (preferences.hamlib == 2)
 	{
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
-					(frequencycheckbutton), TRUE);
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (smetercheckbutton),
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (hamlibcheckbutton),
 					FALSE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (frequencycheckbutton),
+					FALSE);
+		gtk_widget_set_sensitive (hamlibframe, 0);
 	}
-			else if (preferences.hamlib == 3)
-	{
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
-					(frequencycheckbutton), FALSE);
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (smetercheckbutton),
-					TRUE);
-	}
-			else if (preferences.hamlib == 4)
-	{
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
-					(frequencycheckbutton), TRUE);
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (smetercheckbutton),
-					TRUE);
-	}
-			gtk_widget_set_sensitive (hamlibframe, 1);
-		}
-	numrigs = g_list_length (riglist);
-	if (numrigs > 0)
-		{
-			for (i = 0; i < numrigs; i++)
-	{
-		rcaps = (struct rig_caps *) g_list_nth_data (riglist, i);
-		combolist = g_list_append (combolist, (gchar *) rcaps->model_name);
-	}
-		}
 	else
-		combolist = g_list_append (combolist, "");
+	{
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (hamlibcheckbutton),
+						TRUE);
+		if (preferences.hamlib == 2)
+		{
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+					(frequencycheckbutton), TRUE);
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (smetercheckbutton),
+					FALSE);
+		}
+		else if (preferences.hamlib == 3)
+		{
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+					(frequencycheckbutton), FALSE);
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (smetercheckbutton),
+					TRUE);
+		}
+		else if (preferences.hamlib == 4)
+		{
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+					(frequencycheckbutton), TRUE);
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (smetercheckbutton),
+					TRUE);
+		}
+		gtk_widget_set_sensitive (hamlibframe, 1);
+	}
 
+	numrigs = g_list_length (riglist);
 	radiocombo = lookup_widget (preferencesdialog, "radiocombo");
-	gtk_combo_set_popdown_strings (GTK_COMBO (radiocombo), combolist);
-	g_list_free (combolist);
+	if (numrigs > 0)
+	{
+		for (i = 0; i < numrigs; i++)
+		{
+			rcaps = (struct rig_caps *) g_list_nth_data (riglist, i);
+			gtk_combo_box_append_text (GTK_COMBO_BOX (radiocombo), 
+				(gchar *) rcaps->model_name);
+			if (g_ascii_strcasecmp (rcaps->model_name, preferences.radio) == 0)
+				indexradio = i;
+		}
+		if (indexradio != -1)
+			gtk_combo_box_set_active (GTK_COMBO_BOX (radiocombo), indexradio);
+	}
+
+	devicecombo = lookup_widget (preferencesdialog, "devicecombo");
+	gtk_entry_set_text (GTK_ENTRY (GTK_BIN(devicecombo)->child), 
+		preferences.device);
 
-	devicecomboentry = lookup_widget (preferencesdialog, "devicecomboentry");
-	gtk_entry_set_text (GTK_ENTRY (devicecomboentry), preferences.device);
-	radiocomboentry = lookup_widget (preferencesdialog, "radiocomboentry");
-	gtk_entry_set_text (GTK_ENTRY (radiocomboentry), preferences.radio);
 	temp = g_strdup_printf ("%d", preferences.round);
-	digitscomboentry = lookup_widget (preferencesdialog, "digitscomboentry");
-	gtk_entry_set_text (GTK_ENTRY (digitscomboentry), temp);
+	digitscombo = lookup_widget (preferencesdialog, "digitscombo");
+	gtk_entry_set_text (GTK_ENTRY (GTK_BIN(digitscombo)->child), temp);
 	rigsetconfentry = lookup_widget (preferencesdialog, "rigsetconfentry");
 	if (g_ascii_strcasecmp (preferences.rigconf, "?"))
 		gtk_entry_set_text (GTK_ENTRY (rigsetconfentry), preferences.rigconf);
@@ -1321,18 +1238,21 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	/* polling */
 	pollingcheckbutton =
 		lookup_widget (preferencesdialog, "pollingcheckbutton");
-	pollcomboentry = lookup_widget (preferencesdialog, "pollcomboentry");
+	pollcombo = lookup_widget (preferencesdialog, "pollcombo");
+
 	if (preferences.polltime == 0)
+	{
+		gtk_entry_set_text (GTK_ENTRY (GTK_BIN(pollcombo)->child), "300");
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pollingcheckbutton), 
 			FALSE);
+	}
 	else
-		{
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pollingcheckbutton), 
-				TRUE);
-			temp = g_strdup_printf ("%d", preferences.polltime);
-			pollcomboentry = lookup_widget (preferencesdialog, "pollcomboentry");
-			gtk_entry_set_text (GTK_ENTRY (pollcomboentry), temp);
-		}
+	{
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (pollingcheckbutton), 
+			TRUE);
+		temp = g_strdup_printf ("%d", preferences.polltime);
+		gtk_entry_set_text (GTK_ENTRY (GTK_BIN(pollcombo)->child), temp);
+	}
 
 #else /* hide hamlib page in notebook if no hamlib support */
 	notebook = lookup_widget (preferencesdialog, "preferencesnotebook");
@@ -1343,24 +1263,24 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	temp = g_strdup_printf ("%3.2f", preferences.latitude);
 	latentry = lookup_widget (preferencesdialog, "latentry");
 	gtk_entry_set_text (GTK_ENTRY (latentry), temp);
-	NScomboentry = lookup_widget (preferencesdialog, "NScomboentry");
+	NScombo = lookup_widget (preferencesdialog, "NScombo");
 	if (preferences.NS == 1)
-		gtk_entry_set_text (GTK_ENTRY (NScomboentry), _("N"));
+		gtk_combo_box_set_active (GTK_COMBO_BOX (NScombo), 0);
 	else
-		gtk_entry_set_text (GTK_ENTRY (NScomboentry), _("S"));
+		gtk_combo_box_set_active (GTK_COMBO_BOX (NScombo), 1);
 	temp = g_strdup_printf ("%3.2f", preferences.longitude);
 	longentry = lookup_widget (preferencesdialog, "longentry");
 	gtk_entry_set_text (GTK_ENTRY (longentry), temp);
-	EWcomboentry = lookup_widget (preferencesdialog, "EWcomboentry");
+	EWcombo = lookup_widget (preferencesdialog, "EWcombo");
 	if (preferences.EW == 1)
-		gtk_entry_set_text (GTK_ENTRY (EWcomboentry), _("E"));
+		gtk_combo_box_set_active (GTK_COMBO_BOX (EWcombo), 0);
 	else
-		gtk_entry_set_text (GTK_ENTRY (EWcomboentry), _("W"));
-	unitscomboentry = lookup_widget (preferencesdialog, "unitscomboentry");
+		gtk_combo_box_set_active (GTK_COMBO_BOX (EWcombo), 1);
+	unitscombo = lookup_widget (preferencesdialog, "unitscombo");
 	if (preferences.units == 1)
-		gtk_entry_set_text (GTK_ENTRY (unitscomboentry), _("Kilometers"));
+		gtk_combo_box_set_active (GTK_COMBO_BOX (unitscombo), 0);
 	else
-		gtk_entry_set_text (GTK_ENTRY (unitscomboentry), _("Miles"));
+		gtk_combo_box_set_active (GTK_COMBO_BOX (unitscombo), 1);
 	g_free (temp);
 
 	/* locator */
