@@ -37,8 +37,7 @@ void
 on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
 	GtkWidget *printallradiobutton, *printrangeradiobutton, *printlowentry,
-		*printhighentry, *printrangelabel, *sizecomboentry, *pointcomboentry,
-		*orientationcomboentry, *filedestinationradiobutton, 
+		*printhighentry, *printrangelabel, *filedestinationradiobutton, 
 		*printerdestinationradiobutton;
 	GtkWidget *p1, *p2, *p3, *p4, *p5, *p6, *p7, *p8, *p9, *p10,
 		*p11, *p12, *p13, *p14, *p15, *p16, *p17, *p18;
@@ -65,15 +64,12 @@ on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 	GtkWidget *hbox17;
 	GtkWidget *label14;
 	GtkWidget *papersizecombo;
-	GList *papersizecombo_items = NULL;
 	GtkWidget *hbox18;
 	GtkWidget *label15;
 	GtkWidget *pointsizecombo;
-	GList *pointsizecombo_items = NULL;
 	GtkWidget *hbox162;
 	GtkWidget *label204;
 	GtkWidget *orientationcombo;
-	GList *orientationcombo_items = NULL;
 	GtkWidget *label178;
 	GtkWidget *frame22;
 	GtkWidget *hbox164;
@@ -212,19 +208,13 @@ on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_box_pack_start (GTK_BOX (hbox17), label14, TRUE, TRUE, 0);
 	gtk_label_set_line_wrap (GTK_LABEL (label14), TRUE);
 
-	papersizecombo = gtk_combo_new ();
-	g_object_set_data (G_OBJECT (GTK_COMBO (papersizecombo)->popwin),	"GladeParentKey", papersizecombo);
+	papersizecombo = gtk_combo_box_entry_new_text ();
 	gtk_widget_show (papersizecombo);
 	gtk_box_pack_start (GTK_BOX (hbox17), papersizecombo, TRUE, TRUE, 0);
-	gtk_widget_set_size_request (papersizecombo, 100, 23);
-	papersizecombo_items = g_list_append (papersizecombo_items, (gpointer) "a4");
-	papersizecombo_items = g_list_append (papersizecombo_items, (gpointer) "letter");
-	gtk_combo_set_popdown_strings (GTK_COMBO (papersizecombo), papersizecombo_items);
-	g_list_free (papersizecombo_items);
-
-	sizecomboentry = GTK_COMBO (papersizecombo)->entry;
-	gtk_widget_show (sizecomboentry);
-	gtk_editable_set_editable (GTK_EDITABLE (sizecomboentry), FALSE);
+	gtk_widget_set_size_request (papersizecombo, 80, -1);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (papersizecombo), "a4");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (papersizecombo), "letter");
+	gtk_editable_set_editable (GTK_EDITABLE (GTK_BIN(papersizecombo)->child), FALSE);
 
 	hbox18 = gtk_hbox_new (TRUE, 5);
 	gtk_widget_show (hbox18);
@@ -236,26 +226,21 @@ on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_box_pack_start (GTK_BOX (hbox18), label15, TRUE, TRUE, 0);
 	gtk_label_set_line_wrap (GTK_LABEL (label15), TRUE);
 
-	pointsizecombo = gtk_combo_new ();
-	g_object_set_data (G_OBJECT (GTK_COMBO (pointsizecombo)->popwin),	"GladeParentKey", pointsizecombo);
+	pointsizecombo = gtk_combo_box_entry_new_text ();
 	gtk_widget_show (pointsizecombo);
 	gtk_box_pack_start (GTK_BOX (hbox18), pointsizecombo, TRUE, TRUE, 0);
-	gtk_widget_set_size_request (pointsizecombo, 100, 23);
-	pointsizecombo_items = g_list_append (pointsizecombo_items, (gpointer) "6");
-	pointsizecombo_items = g_list_append (pointsizecombo_items, (gpointer) "7");
-	pointsizecombo_items = g_list_append (pointsizecombo_items, (gpointer) "8");
-	pointsizecombo_items = g_list_append (pointsizecombo_items, (gpointer) "9");
-	pointsizecombo_items = g_list_append (pointsizecombo_items, (gpointer) "10");
-	pointsizecombo_items = g_list_append (pointsizecombo_items, (gpointer) "11");
-	pointsizecombo_items = g_list_append (pointsizecombo_items, (gpointer) "12");
-	pointsizecombo_items = g_list_append (pointsizecombo_items, (gpointer) "13");
-	pointsizecombo_items = g_list_append (pointsizecombo_items, (gpointer) "14");
-	gtk_combo_set_popdown_strings (GTK_COMBO (pointsizecombo), pointsizecombo_items);
-	g_list_free (pointsizecombo_items);
-
-	pointcomboentry = GTK_COMBO (pointsizecombo)->entry;
-	gtk_widget_show (pointcomboentry);
-	gtk_editable_set_editable (GTK_EDITABLE (pointcomboentry), FALSE);
+	gtk_widget_set_size_request (pointsizecombo, 80, -1);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (pointsizecombo), "6");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (pointsizecombo), "7");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (pointsizecombo), "8");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (pointsizecombo), "9");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (pointsizecombo), "10");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (pointsizecombo), "11");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (pointsizecombo), "12");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (pointsizecombo), "13");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (pointsizecombo), "14");
+	gtk_editable_set_editable (GTK_EDITABLE (GTK_BIN(pointsizecombo)->child),
+		FALSE);
 
 	hbox162 = gtk_hbox_new (TRUE, 5);
 	gtk_widget_show (hbox162);
@@ -267,19 +252,14 @@ on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_box_pack_start (GTK_BOX (hbox162), label204, TRUE, TRUE, 0);
 	gtk_label_set_line_wrap (GTK_LABEL (label204), TRUE);
 
-	orientationcombo = gtk_combo_new ();
-	g_object_set_data (G_OBJECT (GTK_COMBO (orientationcombo)->popwin),	"GladeParentKey", orientationcombo);
+	orientationcombo = gtk_combo_box_entry_new_text ();
 	gtk_widget_show (orientationcombo);
 	gtk_box_pack_start (GTK_BOX (hbox162), orientationcombo, TRUE, TRUE, 0);
-	gtk_widget_set_size_request (orientationcombo, 100, 23);
-	orientationcombo_items = g_list_append (orientationcombo_items, (gpointer) _("portrait"));
-	orientationcombo_items = g_list_append (orientationcombo_items, (gpointer) _("landscape"));
-	gtk_combo_set_popdown_strings (GTK_COMBO (orientationcombo), orientationcombo_items);
-	g_list_free (orientationcombo_items);
-
-	orientationcomboentry = GTK_COMBO (orientationcombo)->entry;
-	gtk_widget_show (orientationcomboentry);
-	gtk_editable_set_editable (GTK_EDITABLE (orientationcomboentry), FALSE);
+	gtk_widget_set_size_request (orientationcombo, 80, -1);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (orientationcombo), _("portrait"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (orientationcombo), _("landscape"));
+	gtk_editable_set_editable (GTK_EDITABLE (GTK_BIN(orientationcombo)->child),
+		FALSE);
 
 	label178 = gtk_label_new (_("Paper"));
 	gtk_widget_show (label178);
@@ -417,11 +397,8 @@ on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 	GLADE_HOOKUP_OBJECT (printdialog, printerdestinationradiobutton, "printerdestinationradiobutton");
 	GLADE_HOOKUP_OBJECT (printdialog, filedestinationradiobutton, "filedestinationradiobutton");
 	GLADE_HOOKUP_OBJECT (printdialog, papersizecombo, "papersizecombo");
-	GLADE_HOOKUP_OBJECT (printdialog, sizecomboentry, "sizecomboentry");
 	GLADE_HOOKUP_OBJECT (printdialog, pointsizecombo, "pointsizecombo");
-	GLADE_HOOKUP_OBJECT (printdialog, pointcomboentry, "pointcomboentry");
 	GLADE_HOOKUP_OBJECT (printdialog, orientationcombo, "orientationcombo");
-	GLADE_HOOKUP_OBJECT (printdialog, orientationcomboentry, "orientationcomboentry");
 	GLADE_HOOKUP_OBJECT (printdialog, p1, "p1");
 	GLADE_HOOKUP_OBJECT (printdialog, p2, "p2");
 	GLADE_HOOKUP_OBJECT (printdialog, p3, "p3");
@@ -448,42 +425,42 @@ on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 	g_signal_handlers_block_by_func (GTK_OBJECT (printrangeradiobutton),
 		on_printradiobutton_toggled, user_data);
 	if (preferences.printall == 0)
-		{
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (printallradiobutton),
-						TRUE);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (printrangeradiobutton),
-						FALSE);
-			gtk_widget_set_sensitive (printlowentry, 0);
-			gtk_widget_set_sensitive (printhighentry, 0);
-			gtk_widget_set_sensitive (printrangelabel, 0);
-		}
+	{
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (printallradiobutton),
+					TRUE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (printrangeradiobutton),
+					FALSE);
+		gtk_widget_set_sensitive (printlowentry, 0);
+		gtk_widget_set_sensitive (printhighentry, 0);
+		gtk_widget_set_sensitive (printrangelabel, 0);
+	}
 	else
-		{
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (printallradiobutton),
-						FALSE);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (printrangeradiobutton),
-						TRUE);
-			gtk_widget_set_sensitive (printlowentry, 1);
-			gtk_widget_set_sensitive (printhighentry, 1);
-			gtk_widget_set_sensitive (printrangelabel, 1);
-		}
+	{
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (printallradiobutton),
+					FALSE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (printrangeradiobutton),
+					TRUE);
+		gtk_widget_set_sensitive (printlowentry, 1);
+		gtk_widget_set_sensitive (printhighentry, 1);
+		gtk_widget_set_sensitive (printrangelabel, 1);
+	}
 	g_signal_handlers_unblock_by_func (GTK_OBJECT (printrangeradiobutton),
 		on_printradiobutton_toggled, user_data);
 
 	if (preferences.printdestination == 0)
-		{
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
-						(printerdestinationradiobutton), TRUE);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
-						(filedestinationradiobutton), FALSE);
-		}
+	{
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+					(printerdestinationradiobutton), TRUE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+					(filedestinationradiobutton), FALSE);
+	}
 	else
-		{
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
-						(printerdestinationradiobutton), FALSE);
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
-						(filedestinationradiobutton), TRUE);
-		}
+	{
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+					(printerdestinationradiobutton), FALSE);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+					(filedestinationradiobutton), TRUE);
+	}
 
 	logwindow = g_list_nth_data (logwindowlist, page);
 
@@ -494,33 +471,35 @@ on_menu_print_activate (GtkMenuItem * menuitem, gpointer user_data)
 	g_free (temp);
 
 	if (preferences.printsize == 0)
-		gtk_entry_set_text (GTK_ENTRY (sizecomboentry), "a4");
+		gtk_entry_set_text (GTK_ENTRY (GTK_BIN(papersizecombo)->child), "a4");
 	else
-		gtk_entry_set_text (GTK_ENTRY (sizecomboentry), "letter");
+		gtk_entry_set_text (GTK_ENTRY (GTK_BIN(papersizecombo)->child), "letter");
 
 	if (preferences.printpoint == 0)
-		gtk_entry_set_text (GTK_ENTRY (pointcomboentry), "10");
+		gtk_entry_set_text (GTK_ENTRY (GTK_BIN(pointsizecombo)->child), "10");
 	else if (preferences.printpoint == 1)
-		gtk_entry_set_text (GTK_ENTRY (pointcomboentry), "11");
+		gtk_entry_set_text (GTK_ENTRY (GTK_BIN(pointsizecombo)->child), "11");
 	else if (preferences.printpoint == 2)
-		gtk_entry_set_text (GTK_ENTRY (pointcomboentry), "12");
+		gtk_entry_set_text (GTK_ENTRY (GTK_BIN(pointsizecombo)->child), "12");
 	else if (preferences.printpoint == 3)
-		gtk_entry_set_text (GTK_ENTRY (pointcomboentry), "13");
+		gtk_entry_set_text (GTK_ENTRY (GTK_BIN(pointsizecombo)->child), "13");
 	else if (preferences.printpoint == 4)
-		gtk_entry_set_text (GTK_ENTRY (pointcomboentry), "14");
+		gtk_entry_set_text (GTK_ENTRY (GTK_BIN(pointsizecombo)->child), "14");
 	else if (preferences.printpoint == 5)
-		gtk_entry_set_text (GTK_ENTRY (pointcomboentry), "6");
+		gtk_entry_set_text (GTK_ENTRY (GTK_BIN(pointsizecombo)->child), "6");
 	else if (preferences.printpoint == 6)
-		gtk_entry_set_text (GTK_ENTRY (pointcomboentry), "7");
+		gtk_entry_set_text (GTK_ENTRY (GTK_BIN(pointsizecombo)->child), "7");
 	else if (preferences.printpoint == 7)
-		gtk_entry_set_text (GTK_ENTRY (pointcomboentry), "8");
+		gtk_entry_set_text (GTK_ENTRY (GTK_BIN(pointsizecombo)->child), "8");
 	else if (preferences.printpoint == 8)
-		gtk_entry_set_text (GTK_ENTRY (pointcomboentry), "9");
+		gtk_entry_set_text (GTK_ENTRY (GTK_BIN(pointsizecombo)->child), "9");
 
 	if (preferences.printorientation == 0)
-		gtk_entry_set_text (GTK_ENTRY (orientationcomboentry), _("portrait"));
+		gtk_entry_set_text (GTK_ENTRY (GTK_BIN(orientationcombo)->child),
+			_("portrait"));
 	else
-		gtk_entry_set_text (GTK_ENTRY (orientationcomboentry), _("landscape"));
+		gtk_entry_set_text (GTK_ENTRY (GTK_BIN(orientationcombo)->child),
+			_("landscape"));
 
 	column = gtk_tree_view_get_column (GTK_TREE_VIEW (logwindow->treeview), NR);
 	if (gtk_tree_view_column_get_visible (GTK_TREE_VIEW_COLUMN(column)))
