@@ -44,7 +44,7 @@ static void
 on_searchokbutton_clicked (GtkButton * button, gpointer user_data)
 {
 	GtkWidget *dialog_vbox, *dialog_action_area, *searchresultokbutton, 
-		*searchdialog, *searchresultdialog, *searchcomboentry, *resultlabel, 
+		*searchdialog, *searchresultdialog, *resultlabel, 
 		*searchcheckbutton, *searchcombo;
 	GdkPixbuf *searchresultdialog_icon_pixbuf;
 	gchar *searchstr, *upsearchstr, *callsign, *current, *nr, *labeltext;
@@ -59,15 +59,18 @@ on_searchokbutton_clicked (GtkButton * button, gpointer user_data)
 
 	searchdialog = gtk_widget_get_toplevel (GTK_WIDGET (button));
 	searchcombo = lookup_widget (searchdialog, "searchcombo");
-	searchcomboentry = lookup_widget (searchdialog, "searchcomboentry");
 	searchcheckbutton = lookup_widget (searchdialog, "searchcheckbutton");
 
 	searchopen = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(searchcheckbutton));
-	searchstr =	gtk_editable_get_chars (GTK_EDITABLE (searchcomboentry), 0,	-1);
+	searchstr =	gtk_editable_get_chars 
+		(GTK_EDITABLE (GTK_BIN(searchcombo)->child), 0, -1);
 
 	node = g_list_find_custom (searchhistory, searchstr, (GCompareFunc) strcmp);
 	if (!node)
+	{
 		searchhistory =	g_list_prepend (searchhistory, g_strdup(searchstr));
+		gtk_combo_box_append_text (GTK_COMBO_BOX (searchcombo), searchstr);
+	}
 	if (g_list_length (searchhistory) > SEARCHHISTORY)
 		searchhistory = g_list_remove (searchhistory, g_list_last (searchhistory)->data);
 
@@ -144,6 +147,7 @@ on_searchokbutton_clicked (GtkButton * button, gpointer user_data)
 		GTK_WIDGET_SET_FLAGS (searchresultokbutton, GTK_CAN_DEFAULT);
 
 		gtk_dialog_run (GTK_DIALOG(searchresultdialog));
+		gtk_editable_delete_text (GTK_EDITABLE (GTK_BIN(searchcombo)->child), 0, -1);
 		gtk_widget_destroy (searchresultdialog);
 	}
 
@@ -153,12 +157,7 @@ on_searchokbutton_clicked (GtkButton * button, gpointer user_data)
 		gtk_widget_set_sensitive (mainwindow, 1);
 		gtk_widget_destroy (searchdialog);
 	}
-	else
-	{
-		if (searchhistory)
-			gtk_combo_set_popdown_strings (GTK_COMBO(searchcombo), searchhistory);
-		gtk_entry_set_text (GTK_ENTRY (searchcomboentry), searchstr);
-	}
+
 	g_free (searchstr);
 	g_free (upsearchstr);
 }
@@ -175,7 +174,7 @@ on_searchcancelbutton_clicked (GtkButton * button, gpointer user_data)
 
 /* search changed, reset saved state */
 static void
-on_searchcomboentry_changed (GtkEditable * editable, gpointer user_data)
+on_searchcombo_changed (GtkEditable * editable, gpointer user_data)
 {
 	state.searchstr = g_strdup ("");
 }
@@ -206,9 +205,11 @@ void
 on_menu_search_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
 	GtkWidget *searchdialog, *dialog_vbox, *vbox, *searchlabel, *searchcombo,
-		*searchcomboentry, *searchcheckbutton, *dialog_action_area, 
-		*searchcancelbutton, *searchokbutton;
+		*searchcheckbutton, *dialog_action_area, *searchcancelbutton, 
+		*searchokbutton;
 	GdkPixbuf *searchdialog_icon_pixbuf;
+	gint i, num;
+	gchar *s;
 
 	searchdialog = gtk_dialog_new ();
 	gtk_window_set_title (GTK_WINDOW (searchdialog), _("xlog - search"));
@@ -234,16 +235,10 @@ on_menu_search_activate (GtkMenuItem * menuitem, gpointer user_data)
 	gtk_label_set_justify (GTK_LABEL (searchlabel), GTK_JUSTIFY_CENTER);
 	gtk_label_set_line_wrap (GTK_LABEL (searchlabel), TRUE);
 
-	searchcombo = gtk_combo_new ();
-	g_object_set_data (G_OBJECT (GTK_COMBO (searchcombo)->popwin),
-										 "GladeParentKey", searchcombo);
+	searchcombo = gtk_combo_box_entry_new_text ();
 	gtk_widget_show (searchcombo);
 	gtk_box_pack_start (GTK_BOX (vbox), searchcombo, FALSE, FALSE, 0);
 
-	searchcomboentry = GTK_COMBO (searchcombo)->entry;
-	gtk_widget_show (searchcomboentry);
-	gtk_entry_set_max_length (GTK_ENTRY (searchcomboentry), 15);
-
 	searchcheckbutton = gtk_check_button_new_with_mnemonic (_("Keep this dialog open"));
 	gtk_widget_show (searchcheckbutton);
 	gtk_box_pack_start (GTK_BOX (vbox), searchcheckbutton, FALSE, FALSE, 0);
@@ -265,8 +260,8 @@ on_menu_search_activate (GtkMenuItem * menuitem, gpointer user_data)
 	g_signal_connect ((gpointer) searchdialog, "delete_event",
 										G_CALLBACK (on_searchdialog_delete_event),
 										NULL);
-	g_signal_connect ((gpointer) searchcomboentry, "changed",
-										G_CALLBACK (on_searchcomboentry_changed),
+	g_signal_connect ((gpointer) searchcombo, "changed",
+										G_CALLBACK (on_searchcombo_changed),
 										NULL);
 	g_signal_connect ((gpointer) searchcheckbutton, "toggled",
 										G_CALLBACK (on_searchcheckbutton_toggled),
@@ -281,13 +276,17 @@ on_menu_search_activate (GtkMenuItem * menuitem, gpointer user_data)
 	/* Store pointers to all widgets, for use by lookup_widget(). */
 	GLADE_HOOKUP_OBJECT_NO_REF (searchdialog, searchdialog, "searchdialog");
 	GLADE_HOOKUP_OBJECT (searchdialog, searchcombo, "searchcombo");
-	GLADE_HOOKUP_OBJECT (searchdialog, searchcomboentry, "searchcomboentry");
 	GLADE_HOOKUP_OBJECT (searchdialog, searchcheckbutton, "searchcheckbutton");
 
-	gtk_widget_grab_focus (searchcomboentry);
 	if (searchhistory)
-		gtk_combo_set_popdown_strings (GTK_COMBO (searchcombo), searchhistory);
-	gtk_editable_delete_text (GTK_EDITABLE (searchcomboentry), 0, -1);
+	{
+		num = g_list_length (searchhistory);
+		for (i = 0; i < num; i++)
+		{
+			s = g_list_nth_data (searchhistory, i);
+			gtk_combo_box_append_text (GTK_COMBO_BOX (searchcombo), s);
+		}
+	}
 	gtk_widget_set_sensitive (mainwindow, 0);
 	gtk_widget_show (searchdialog);
 }
