@@ -69,7 +69,9 @@ stop_tracing (void)
 	dup2 (saved_fd, STDERR_FILENO);
 	close (saved_fd);
 #ifndef __NetBSD__
+#ifndef WIN32
 	stderr = fdopen (STDERR_FILENO, "w");
+#endif
 #endif
 	hamlibresult = start_hamlib (preferences.radio, preferences.device, RIG_DEBUG_NONE, preferences.polltime);
 }
@@ -213,7 +215,7 @@ on_trace_hamlib_activate(GtkMenuItem * menuitem, gpointer user_data)
 		finfo.fd = freopen (finfo.filename, "w", stderr);
 		hamlibresult = start_hamlib (preferences.radio, preferences.device, 
 			RIG_DEBUG_TRACE, preferences.polltime);
-		tracetimer = gtk_timeout_add (1000, (GtkFunction) updatetrace, tracedialog_textview);
+		tracetimer = g_timeout_add (1000, (GSourceFunc) updatetrace, tracedialog_textview);
 
 		tracestr = g_strdup_printf (_("Saving to %s"), finfo.filename);
 		gtk_label_set_text (GTK_LABEL (tracelabel), tracestr);
