@@ -23,8 +23,11 @@
 
 #include <gtk/gtk.h>
 #include "types.h"
+#include "log.h"
 
 extern GdkColormap *colormap;
+extern GtkUIManager *ui_manager;
+extern GList *logwindowlist;
 
 /* set style of a label */
 void
@@ -79,7 +82,45 @@ getlabelcolor (GtkWidget * label)
 	labelcolor = labelstyle->fg[GTK_STATE_NORMAL];
 
 	col = g_strdup_printf("#%02X%02X%02X",	 
-			labelcolor.red >> 8, labelcolor.green >> 8, labelcolor.blue >> 8);
+	labelcolor.red >> 8, labelcolor.green >> 8, labelcolor.blue >> 8);
 
 	return (col);
 }
+
+
+/* configure "Tabs" menu */
+void set_tabs_menu (void)
+{
+	gchar *menupath;
+	GtkWidget *menuitem;
+	GList *children, *cur;
+	logtype *logw;
+	gint i;
+
+	for (i = 1; i < 11; i++)
+	{
+		menupath = g_strdup_printf ("/MainMenu/TabsMenu/%d", i);
+		menuitem = gtk_ui_manager_get_widget (ui_manager, menupath);
+		gtk_widget_hide (menuitem);
+		g_free (menupath);
+	}
+	for (i = 0; i < g_list_length(logwindowlist); i++)
+	{
+		if (i < 10)
+		{
+			menupath = g_strdup_printf ("/MainMenu/TabsMenu/%d", i + 1);
+			menuitem = gtk_ui_manager_get_widget (ui_manager, menupath);
+			gtk_widget_show (menuitem);
+			children = gtk_container_get_children (GTK_CONTAINER (menuitem));
+			cur = children;
+			logw = g_list_nth_data (logwindowlist, i);
+			while (cur) 
+			{
+				if (GTK_IS_LABEL (cur->data))
+					gtk_label_set_text (GTK_LABEL (cur->data), logw->logname);
+				cur = cur->next;
+			}
+			g_free (menupath);
+		}
+	}
+}
