@@ -33,6 +33,76 @@
 
 preferencestype preferences;
 extern gchar *xlogdir;
+#define PREFERENCES_VERSION 2
+gboolean newprefsfile = FALSE;
+
+static void make_default_preferences (void)
+{
+	GString *sdir = g_string_new ("");
+
+	preferences.version = 0;
+	preferences.x = 10;
+	preferences.y = 30;
+	preferences.width = 750;
+	preferences.height = 540;
+	preferences.latitude = 0.0;
+	preferences.NS = 1;
+	preferences.longitude = 0.0;
+	preferences.EW = 1;
+	preferences.units = 1;
+	preferences.bands = g_strdup ("1.8,3.5,7,10,14,18,21,24,28");
+	preferences.modes = g_strdup ("CW,USB,LSB,FM,PSK31,MFSK,MT63,SSTV");
+	preferences.bandseditbox = 0;
+	preferences.modeseditbox = 0;
+	preferences.bandoptionmenu = 0;
+	preferences.modeoptionmenu = 0;
+	preferences.printall = 0;
+	preferences.printsize = 0;
+	preferences.printpoint = 0;
+	preferences.printorientation = 0;
+	preferences.printdestination = 0;
+	preferences.hamlib = 0;
+	preferences.radio = g_strdup ("Dummy");
+	preferences.device = g_strdup ("/dev/ttyS1");
+	preferences.rigconf = g_strdup ("?");
+	preferences.round = 3;
+	preferences.polltime = 0;
+	preferences.clock = 0;
+	preferences.themecolor = g_strdup ("blue");
+	preferences.themefont = g_strdup ("Sans 10");
+	preferences.logcolor = 1;
+	preferences.autosave = 5;
+	g_string_printf (sdir, "%s.", G_DIR_SEPARATOR_S);
+	g_string_append (sdir, PACKAGE);
+	preferences.savedir = g_strconcat (g_get_home_dir (), sdir->str, NULL);
+	g_string_free (sdir, TRUE);
+	preferences.saving = 1;
+	preferences.logstoload = g_strdup ("*");
+	preferences.locator = g_strdup ("AA00AA");
+	preferences.freefield1 = g_strdup ("UNKNOWN");
+	preferences.freefield2 = g_strdup ("UNKNOWN");
+	preferences.callsign = g_strdup ("N0CALL");
+	preferences.defaultmhz = g_strdup ("?");
+	preferences.defaultmode = g_strdup ("?");
+	preferences.defaulttxrst = g_strdup ("?");
+	preferences.defaultrxrst = g_strdup ("?");
+	preferences.defaultpower = g_strdup ("?");
+	preferences.defaultfreefield1 = g_strdup ("?");
+	preferences.defaultfreefield2 = g_strdup ("?");
+	preferences.defaultremarks = g_strdup ("?");
+	preferences.b4columns = g_strdup ("1,1,1,1,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0");
+	preferences.logcwidths = g_strdup ("50,100,50,50,100,50,50,50,50,50,50,50,100,100,100,100,100,200");
+	preferences.typeaheadfind = 1;
+	preferences.remoteadding = 1;
+	preferences.viewtoolbar = 1;
+	preferences.viewb4 = 0;
+	preferences.b4x = 10;
+	preferences.b4y = 30;
+	preferences.b4width = 500;
+	preferences.b4height = 300;
+	preferences.saveasadif = 0;
+	preferences.saveaslabels = 0;
+}
 
 void
 parseloadpreferences (xmlDocPtr p, xmlNodePtr cur)
@@ -41,335 +111,595 @@ parseloadpreferences (xmlDocPtr p, xmlNodePtr cur)
 	cur = cur->xmlChildrenNode;
 	while (cur != NULL)
 	{
+		if ((!xmlStrcmp(cur->name, (const xmlChar *)"version")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.version = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
+			xmlFree (key);
+#endif
+		}
 		if ((!xmlStrcmp(cur->name, (const xmlChar *)"x")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.x = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"y")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.y = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"width")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.width = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"height")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.height = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"latitude")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.latitude = atof (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"NS")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.NS = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"longitude")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.longitude = atof (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"EW")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.EW = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"units")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.units = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"bands")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.bands = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"modes")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.modes = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"modeseditbox")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.modeseditbox = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"bandseditbox")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.bandseditbox = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"bandoptionmenu")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.bandoptionmenu = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"modeoptionmenu")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.modeoptionmenu = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"printall")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.printall = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"printsize")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.printsize = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"printpoint")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.printpoint = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"printdestination")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.printdestination = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"printorientation")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.printorientation = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"hamlib")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.hamlib = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"radio")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.radio = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"device")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.device = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"rigconf")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.rigconf = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"round")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.round = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"polltime")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.polltime = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"clock")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.clock = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"themecolor")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.themecolor = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"themefont")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.themefont = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"logcolor")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.logcolor = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"autosave")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.autosave = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"savedir")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.savedir = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"saving")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.saving = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"logstoload")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.logstoload = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"locator")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.locator = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"freefield1")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.freefield1 = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"freefield2")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.freefield2 = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"callsign")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.callsign = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"defaultmhz")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.defaultmhz = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"defaultmode")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.defaultmode = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"defaulttxrst")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.defaulttxrst = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"defaultrxrst")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.defaultrxrst = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"defaultpower")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.defaultpower = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"defaultfreefield1")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.defaultfreefield1 = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"defaultfreefield2")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.defaultfreefield2 = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"defaultremarks")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.defaultremarks = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"b4columns")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.b4columns = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"logcwidths")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.logcwidths = g_strdup (key);
+#ifdef WIN32
+			free (key);
+#else
+			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"typeaheadfind")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.typeaheadfind = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"remoteadding")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.remoteadding = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"viewtoolbar")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.viewtoolbar = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"viewb4")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.viewb4 = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"b4x")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.b4x = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"b4y")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.b4y = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"b4width")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.b4width = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"b4height")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.b4height = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
 			xmlFree (key);
+#endif
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"saveasadif")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.saveasadif = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
+			xmlFree (key);
+#endif
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"saveaslabels")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.saveaslabels = atoi (key);
+#ifdef WIN32
+			free (key);
+#else
+			xmlFree (key);
+#endif
 		}
 	cur = cur->next;
 	}
@@ -383,6 +713,12 @@ void parsesavepreferences (xmlNodePtr cur)
 
 	for (node = cur->children; node != NULL; node = node->next)
 	{
+		if (!strcmp (node->name, "version"))
+		{
+			key = g_strdup_printf ("%d", PREFERENCES_VERSION);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
 		if (!strcmp (node->name, "x"))
 		{
 			key = g_strdup_printf ("%d", preferences.x);
@@ -665,6 +1001,12 @@ void parsesavepreferences (xmlNodePtr cur)
 			xmlNodeSetContent (node, key);
 			g_free (key);
 		}
+		else if (!strcmp (node->name, "logcwidths"))
+		{
+			key = g_strdup (preferences.logcwidths);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
 		else if (!strcmp (node->name, "typeaheadfind"))
 		{
 			key = g_strdup_printf ("%d", preferences.typeaheadfind);
@@ -713,74 +1055,30 @@ void parsesavepreferences (xmlNodePtr cur)
 			xmlNodeSetContent (node, key);
 			g_free (key);
 		}
+		else if (!strcmp (node->name, "saveasadif"))
+		{
+			key = g_strdup_printf ("%d", preferences.saveasadif);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "saveaslabels"))
+		{
+			key = g_strdup_printf ("%d", preferences.saveaslabels);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
 	}
 }
 
-void
+
+static void
 newsavepreferences (xmlNodePtr cur)
 {
 	gchar *key;
-	GString *sdir = g_string_new ("");
 
-	preferences.x = 10;
-	preferences.y = 30;
-	preferences.width = 750;
-	preferences.height = 540;
-	preferences.latitude = 0.0;
-	preferences.NS = 1;
-	preferences.longitude = 0.0;
-	preferences.EW = 1;
-	preferences.units = 1;
-	preferences.bands = g_strdup ("1.8,3.5,7,10,14,18,21,24,28");
-	preferences.modes = g_strdup ("CW,SSB,PSK31,MFSK,MT63,SSTV");
-	preferences.bandseditbox = 0;
-	preferences.modeseditbox = 0;
-	preferences.bandoptionmenu = 0;
-	preferences.modeoptionmenu = 0;
-	preferences.printall = 0;
-	preferences.printsize = 0;
-	preferences.printpoint = 0;
-	preferences.printorientation = 0;
-	preferences.printdestination = 0;
-	preferences.hamlib = 0;
-	preferences.radio = g_strdup ("Dummy");
-	preferences.device = g_strdup ("/dev/ttyS1");
-	preferences.rigconf = g_strdup ("?");
-	preferences.round = 0;
-	preferences.polltime = 0;
-	preferences.clock = 0;
-	preferences.themecolor = g_strdup ("blue");
-	preferences.themefont = g_strdup ("Sans 10");
-	preferences.logcolor = 1;
-	preferences.autosave = 5;
-	g_string_printf (sdir, "%s.", G_DIR_SEPARATOR_S);
-	g_string_append (sdir, PACKAGE);
-	preferences.savedir = g_strconcat (g_get_home_dir (), sdir->str, NULL);
-	g_string_free (sdir, TRUE);
-	preferences.saving = 1;
-	preferences.logstoload = g_strdup ("*");
-	preferences.locator = g_strdup ("AA00AA");
-	preferences.freefield1 = g_strdup ("UNKNOWN");
-	preferences.freefield2 = g_strdup ("UNKNOWN");
-	preferences.callsign = g_strdup ("N0CALL");
-	preferences.defaultmhz = g_strdup ("?");
-	preferences.defaultmode = g_strdup ("?");
-	preferences.defaulttxrst = g_strdup ("?");
-	preferences.defaultrxrst = g_strdup ("?");
-	preferences.defaultpower = g_strdup ("?");
-	preferences.defaultfreefield1 = g_strdup ("?");
-	preferences.defaultfreefield2 = g_strdup ("?");
-	preferences.defaultremarks = g_strdup ("?");
-	preferences.b4columns = g_strdup ("1,1,1,1,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0");
-	preferences.typeaheadfind = 1;
-	preferences.remoteadding = 1;
-	preferences.viewtoolbar = 1;
-	preferences.viewb4 = 0;
-	preferences.b4x = 10;
-	preferences.b4y = 30;
-	preferences.b4width = 500;
-	preferences.b4height = 300;
- 
+	make_default_preferences ();
+	key = g_strdup_printf ("%d", PREFERENCES_VERSION);
+	xmlNewTextChild (cur, NULL, "version", key);
 	key = g_strdup_printf ("%d", preferences.x);
 	xmlNewTextChild (cur, NULL, "x", key);
 	key = g_strdup_printf ("%d", preferences.y);
@@ -875,6 +1173,8 @@ newsavepreferences (xmlNodePtr cur)
 	xmlNewTextChild (cur, NULL, "defaultremarks", key);
 	key = g_strdup_printf ("%s", preferences.b4columns);
 	xmlNewTextChild (cur, NULL, "b4columns", key);
+	key = g_strdup_printf ("%s", preferences.logcwidths);
+	xmlNewTextChild (cur, NULL, "logcwidths", key);
 	key = g_strdup_printf ("%d", preferences.typeaheadfind);
 	xmlNewTextChild (cur, NULL, "typeaheadfind", key);
 	key = g_strdup_printf ("%d", preferences.remoteadding);
@@ -891,6 +1191,10 @@ newsavepreferences (xmlNodePtr cur)
 	xmlNewTextChild (cur, NULL, "b4width", key);
 	key = g_strdup_printf ("%d", preferences.b4height);
 	xmlNewTextChild (cur, NULL, "b4height", key);
+	key = g_strdup_printf ("%d", preferences.saveasadif);
+	xmlNewTextChild (cur, NULL, "saveasadif", key);
+	key = g_strdup_printf ("%d", preferences.saveaslabels);
+	xmlNewTextChild (cur, NULL, "saveaslabels", key);
 	g_free (key);
 }
 
@@ -901,6 +1205,8 @@ loadpreferences (void)
 	xmlDocPtr prefs;
 	xmlNodePtr cur, node;
 
+
+	make_default_preferences ();
 	/* open preferences file */
 	preferencesfile =
 		g_strconcat (xlogdir, G_DIR_SEPARATOR_S, "preferences.xml", NULL);
@@ -943,6 +1249,7 @@ loadpreferences (void)
 		newsavepreferences (node);
 		xmlSaveFormatFile (preferencesfile, prefs, 1);
 		xmlFreeDoc (prefs);
+		newprefsfile = TRUE;
 	}
 	g_free (preferencesfile);
 }
@@ -950,9 +1257,9 @@ loadpreferences (void)
 void
 savepreferences (void)
 {
-	gchar *preferencesfile;
+	gchar *preferencesfile, *key;
 	xmlDocPtr prefs;
-	xmlNodePtr cur;
+	xmlNodePtr root, cur;
 
 	/* open preferences file */
 	preferencesfile =
@@ -963,24 +1270,44 @@ savepreferences (void)
 		g_warning (_("preferences not parsed successfully"));
 		return;
 	}
-	cur = xmlDocGetRootElement (prefs);
-	if (cur == NULL)
+	root = xmlDocGetRootElement (prefs);
+	if (root == NULL)
 	{
 		g_warning (_("empty preferences file"));
 		xmlFreeDoc (prefs);
 		return;
 	}
-	if (xmlStrcmp(cur->name, (const xmlChar *) "xlog"))
+	if (xmlStrcmp(root->name, (const xmlChar *) "xlog"))
 	{
 		g_warning (_("document of the wrong type, root node is not xlog"));
 		xmlFreeDoc (prefs);
 		return;
 	}
-	cur = cur->xmlChildrenNode;
+	cur = root->xmlChildrenNode;
 	while (cur != NULL)
 	{
 		if ((!xmlStrcmp(cur->name, (const xmlChar *)"xlog_preferences")))
+		{
 			parsesavepreferences (cur);
+			if (!newprefsfile && (preferences.version < 1))
+			{	
+		        /* introduced in xlog version 0.9.8 */
+				key = g_strdup_printf ("%d", PREFERENCES_VERSION);
+				xmlNewTextChild (cur, NULL, "version", key);
+				key = g_strdup_printf ("%s", preferences.logcwidths);
+				xmlNewTextChild (cur, NULL, "logcwidths", key);
+				g_free (key);
+			}
+			if (!newprefsfile && (preferences.version < 2))
+			{	
+		        /* introduced in xlog version 0.9.10 */
+				key = g_strdup_printf ("%d", preferences.saveasadif);
+				xmlNewTextChild (cur, NULL, "saveasadif", key);
+				key = g_strdup_printf ("%d", preferences.saveaslabels);
+				xmlNewTextChild (cur, NULL, "saveaslabels", key);
+				g_free (key);
+			}
+		}
 		cur = cur->next;
 	}
 	xmlSaveFormatFile (preferencesfile, prefs, 0);
