@@ -27,6 +27,7 @@
 /* preferences saved to ~/.xlog/preferences */
 typedef struct
 {
+	gint version;			/* revision number of the preferences file */
 	gint x;
 	gint y;
 	gint width;
@@ -35,31 +36,31 @@ typedef struct
 	gint NS;
 	gdouble longitude;
 	gint EW;
-	gint units;			/* kilometers or nautical miles */
+	gint units;				/* kilometers or nautical miles */
 	gchar *modes;
 	gchar *bands;
 	gint bandseditbox;		/* optionmenu or entry for bands? */
 	gint modeseditbox;		/* optionmenu or entry modes? */
 	gint bandoptionmenu;	/* position of optionmenu */
 	gint modeoptionmenu;	/* position of optionmenu */
-	gint printall;								/* 0 = all, 1 = range */
-	gint printsize;							 /* A4 or letter */
-	gint printpoint;							/* pointsize (10, 11, 12) */
-	gint printorientation;				/* 0 = portrait, 1 = landscape */
-	gint printdestination;				/* 0 = printer, 1 = file */
+	gint printall;			/* 0 = all, 1 = range */
+	gint printsize;			/* A4 or letter */
+	gint printpoint;		/* pointsize (10, 11, 12) */
+	gint printorientation;	/* 0 = portrait, 1 = landscape */
+	gint printdestination;	/* 0 = printer, 1 = file */
 	gint hamlib;			/* hamlib enabled? 0 = no, 1 = yes, 2 = display freq on statusbar */
 	gchar *radio;			/* what type of radio do you use? */
 	gchar *device;		/* which serial port does it use? */
-	gchar *rigconf;	 /* string for rig_set_conf */
+	gchar *rigconf;		/* string for rig_set_conf */
 	gint round;			/* how many digits to round to */
-	gint polltime;	/* poll every 'polltime' milliseconds, 0 = no polling */
+	gint polltime;		/* poll every 'polltime' milliseconds, 0 = no polling */
 	gint clock;			/* clock on the statusbar? */
 	gchar *themecolor;
 	gchar *themefont;
 	gint logcolor;		/* do we want to color the log? */
 	gint autosave;
 	gchar *savedir;
-	gint saving;									/* 1= autosave, 2=save with click on toolbar */
+	gint saving;		/* 1= autosave, 2=save with click on toolbar */
 	gchar *logstoload;
 	gchar *locator;
 	gchar *freefield1;
@@ -74,14 +75,17 @@ typedef struct
 	gchar *defaultfreefield2;
 	gchar *defaultremarks;
 	gchar *b4columns;
-	gint typeaheadfind;					 /* do we want type ahead find */
-	gint remoteadding;						/* add remote data to log or qso frame */
-	gint viewtoolbar;
-	gint viewb4;
+	gchar *logcwidths;
+	gint typeaheadfind;	/* do we want type ahead find */
+	gint remoteadding;	/* add remote data to log or qso frame */
+	gint viewtoolbar;	/* do we want to see the toolbar button */
+	gint viewb4;		/* do we want to see the worked before dialog */
 	gint b4x;
 	gint b4y;
 	gint b4width;
 	gint b4height;
+	gint saveasadif;
+	gint saveaslabels;
 }
 preferencestype;
 
