@@ -27,17 +27,26 @@
 #include <time.h>
 #include <errno.h>
 #include <sys/types.h>
-#include <sys/ipc.h>
-#include <sys/msg.h>
-#include <sys/shm.h>
 #include <string.h>
 #include <gtk/gtk.h>
+
+#if defined(HAVE_SYS_IPC_H)
+#include <sys/ipc.h>
+#include <sys/msg.h>
+#endif
+
+#if defined(HAVE_SYS_SHM_H)
+#include <sys/ipc.h>
+#include <sys/shm.h>
+#endif
+
 #include "types.h"
 #include "log.h"
 #include "utils.h"
 #include "preferences.h"
 #include "support.h"
 #include "history.h"
+#include "dxcc.h"
 
 #if WANT_HAMLIB
 #	include <hamlib/rig.h>
@@ -50,18 +59,15 @@ extern GtkWidget *b4dialog;
 extern preferencestype preferences;
 extern statetype state;
 extern remotetype remote;
-extern gchar **bandsplit;
-extern gchar **modesplit;
 extern gchar **qso;
-extern dxcc_data *dxcc;
 extern gchar *xlogdir;
 extern gint remotetimer;
 extern gint clocktimer, savetimer;
 extern glong msgid;
-extern GHashTable *prefixes;
 extern void *shareCall;
 extern GList *logwindowlist;
 extern gchar *searchpx;
+extern GtkUIManager *ui_manager;
 
 #if WANT_HAMLIB
 extern GList *riglist;
@@ -92,22 +98,63 @@ setlocation (gdouble lat, gint NS, gdouble lon, gint EW)
 
 /* update the menu items of an optionmenu */
 void
-updateoptionmenu (GtkWidget * optionmenu, gchar ** split)
+makebandoptionmenu (gchar *bands)
 {
-	GtkWidget *menu, *menuitem;
+	GtkWidget *bandhbox2, *bandoptionmenu, *old;
+	gchar **split;
 	gint index = 0;
 
-	menu = gtk_menu_new ();
+	old = g_object_get_data (G_OBJECT (mainwindow), "bandoptionmenu");
+	if (old) gtk_widget_destroy (old);
+
+	bandoptionmenu = gtk_combo_box_new_text ();
+	gtk_widget_show (bandoptionmenu);
+	bandhbox2 = lookup_widget (mainwindow, "bandhbox2");
+	gtk_box_pack_start (GTK_BOX (bandhbox2), bandoptionmenu, TRUE, TRUE, 0);
+	gtk_widget_set_size_request (bandoptionmenu, 130, 27);
+
+	split = g_strsplit (bands, ",", -1);
 	for (;;)
-		{
-			if (split[index] == NULL)
-	break;
-			menuitem = gtk_menu_item_new_with_label (split[index]);
-			gtk_widget_show (menuitem);
-			gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-			index++;
-		}
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu), menu);
+	{
+		if (split[index] == NULL)
+			break;
+		gtk_combo_box_append_text (GTK_COMBO_BOX(bandoptionmenu), split[index]);
+		index++;
+	}
+	g_strfreev (split);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (bandoptionmenu),
+		preferences.bandoptionmenu);
+	GLADE_HOOKUP_OBJECT (mainwindow, bandoptionmenu, "bandoptionmenu");
+}
+
+void
+makemodeoptionmenu (gchar *modes)
+{
+	GtkWidget *modehbox2, *modeoptionmenu, *old;
+	gchar **split;
+	gint index = 0;
+
+	old = g_object_get_data (G_OBJECT (mainwindow), "modeoptionmenu");
+	if (old) gtk_widget_destroy (old);
+
+	modeoptionmenu = gtk_combo_box_new_text ();
+	gtk_widget_show (modeoptionmenu);
+	modehbox2 = lookup_widget (mainwindow, "modehbox2");
+	gtk_box_pack_start (GTK_BOX (modehbox2), modeoptionmenu, TRUE, TRUE, 0);
+	gtk_widget_set_size_request (modeoptionmenu, 130, 27);
+
+	split = g_strsplit (modes, ",", -1);
+	for (;;)
+	{
+		if (split[index] == NULL)
+			break;
+		gtk_combo_box_append_text (GTK_COMBO_BOX(modeoptionmenu), split[index]);
+		index++;
+	}
+	g_strfreev (split);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (modeoptionmenu),
+		preferences.modeoptionmenu);
+	GLADE_HOOKUP_OBJECT (mainwindow, modeoptionmenu, "modeoptionmenu");
 }
 
 /* removing leading and trailing whitespaces from an array of strings */
@@ -117,12 +164,12 @@ deletespaces (gchar ** split)
 	gint index = 0;
 
 	for (;;)
-		{
-			if (split[index] == NULL)
-	break;
-			g_strstrip (split[index]);
-			index++;
-		}
+	{
+		if (split[index] == NULL)
+			break;
+		g_strstrip (split[index]);
+		index++;
+	}
 }
 
 /* clear statusbar */
@@ -134,7 +181,7 @@ statusbar_timeout (gpointer data)
 	statusbar = lookup_widget (mainwindow, "statusbar");
 	gtk_statusbar_pop (GTK_STATUSBAR (statusbar), 1);
 	gtk_statusbar_push (GTK_STATUSBAR (statusbar), 1, _("Ready."));
-	gtk_timeout_remove (statusbartimer);
+	g_source_remove (statusbartimer);
 	state.statustimer = FALSE;
 	return FALSE;
 }
@@ -149,19 +196,11 @@ update_statusbar (gchar * string)
 	gtk_statusbar_pop (GTK_STATUSBAR (statusbar), 1);
 	gtk_statusbar_push (GTK_STATUSBAR (statusbar), 1, string);
 	if (state.statustimer)
-		gtk_timeout_remove (statusbartimer);
-	statusbartimer = gtk_timeout_add (30000, statusbar_timeout, NULL);
+		g_source_remove (statusbartimer);
+	statusbartimer = g_timeout_add (30000, statusbar_timeout, NULL);
 	state.statustimer = TRUE;
 }
 
-/* Needed by g_hash_table_foreach_remove, to free every key in the hash table */
-gboolean
-remove_prefixes (gchar * key, gpointer value, gpointer user_data)
-{
-	g_free (key);
-	return (TRUE);
-}
-
 /* free mem in state struct */
 static void
 freestate (void)
@@ -191,17 +230,10 @@ void
 save_windowsize_and_cleanup (void)
 {
 	gint i;
-	GtkWidget *bandoptionmenu, *modeoptionmenu, *view_toolbar, *worked;
+	GtkWidget *bandoptionmenu, *modeoptionmenu, *handlebox;
 
 	/* free the dxcc array */
-	for (i = 0; i < state.countries; i++)
-		{
-			g_free (dxcc[i].countryname);
-			g_free (dxcc[i].continent);
-			g_free (dxcc[i].px);
-			g_free (dxcc[i].exceptions);
-		}
-	g_free (dxcc);
+	cleanup_dxcc ();
 
 	/* free the qso array */
 	for (i = 0; i < QSO_FIELDS; i++)
@@ -217,23 +249,31 @@ save_windowsize_and_cleanup (void)
 	bandoptionmenu = lookup_widget (mainwindow, "bandoptionmenu");
 	modeoptionmenu = lookup_widget (mainwindow, "modeoptionmenu");
 	preferences.modeoptionmenu = 
-		gtk_option_menu_get_history (GTK_OPTION_MENU (modeoptionmenu));
+		gtk_combo_box_get_active (GTK_COMBO_BOX(modeoptionmenu));
 	preferences.bandoptionmenu = 
-		gtk_option_menu_get_history (GTK_OPTION_MENU (bandoptionmenu));
-	view_toolbar = lookup_widget (mainwindow, "view_toolbar");
-	if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM(view_toolbar)))
+		gtk_combo_box_get_active (GTK_COMBO_BOX(bandoptionmenu));
+
+	handlebox = lookup_widget (mainwindow, "handlebox");
+	if (GTK_WIDGET_VISIBLE(handlebox))
 		preferences.viewtoolbar = 1;
 	else
 		preferences.viewtoolbar = 0;
-	worked = lookup_widget (mainwindow, "worked");
-	if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM(worked)))
+	if (GTK_WIDGET_VISIBLE(b4dialog))
+	{
 		preferences.viewb4 = 1;
+		gtk_window_get_size (GTK_WINDOW(b4dialog), 
+			&preferences.b4width, &preferences.b4height);
+		gtk_window_get_position (GTK_WINDOW(b4dialog), 
+			&preferences.b4x, &preferences.b4y);
+	}
 	else
+	{
 		preferences.viewb4 = 0;
-	gtk_window_get_size (GTK_WINDOW(b4dialog), 
-		&preferences.b4width, &preferences.b4height);
-	gtk_window_get_position (GTK_WINDOW(b4dialog), 
-		&preferences.b4x, &preferences.b4y);
+		preferences.b4x = 10;
+        preferences.b4y = 30;
+        preferences.b4width = 500;
+        preferences.b4height = 300;
+	}
 	savepreferences ();
 	savehistory ();
 
@@ -244,13 +284,6 @@ save_windowsize_and_cleanup (void)
 		g_list_free (riglist);
 #endif
 
-	if (prefixes)
-		{
-			g_hash_table_foreach_remove (prefixes, (GHRFunc) remove_prefixes, NULL);
-			g_hash_table_destroy (prefixes);
-		}
-	g_strfreev (bandsplit);
-	g_strfreev (modesplit);
 	g_free (xlogdir);
 	if (remotetimer != -1)
 		g_source_remove (remotetimer);
@@ -260,15 +293,19 @@ save_windowsize_and_cleanup (void)
 		g_source_remove (clocktimer);
 
 	/* remove message queue */
+#if defined(HAVE_SYS_IPC_H)
 	if (msgid != -1)
 		msgctl (msgid, IPC_RMID, 0);
+#endif
 
 	/* detach shared mem and destroy it */
+#if defined(HAVE_SYS_SHM_H)
 	if (state.shmid != -1)
 		{
 			shmdt (shareCall);
 			shmctl (state.shmid, IPC_RMID, NULL);
 		}
+#endif
 
 	g_free(searchpx);
 
@@ -440,36 +477,26 @@ gettime (void)
 
 /* look up mode in a list of modes */
 gchar *
-lookup_mode (gchar * selectedmode)
+lookup_mode (gint index)
 {
-	gint modeindex = 0;
+	gchar **s, *mode;
 
-	for (;;)
-		{
-			if (g_ascii_strcasecmp (selectedmode, modesplit[modeindex]) == 0)
-	{
-		break;
-	}
-			modeindex++;
-		}
-	return (g_strdup (modesplit[modeindex]));
+	s = g_strsplit (preferences.modes, ",", -1);
+	mode = g_strdup (s[index]);
+	g_strfreev (s);
+	return (mode);
 }
 
 /* look up band in a list of bands */
 gchar *
-lookup_band (gchar * selectedband)
+lookup_band (gint index)
 {
-	gint bandindex = 0;
+	gchar **s, *band;
 
-	for (;;)
-		{
-			if (g_ascii_strcasecmp (selectedband, bandsplit[bandindex]) == 0)
-	{
-		break;
-	}
-			bandindex++;
-		}
-	return (g_strdup (bandsplit[bandindex]));
+	s = g_strsplit (preferences.bands, ",", -1);
+	band = g_strdup (s[index]);
+	g_strfreev (s);
+	return (band);
 }
 
 /* clock which updates a label in the statusbar */
@@ -515,33 +542,28 @@ gint
 autosave (void)
 {
 	gint i;
-	logtype *logwindow;
-	gchar *logfile, *temp;
+	logtype *logw;
+	gchar *temp;
 	gboolean message = FALSE;
 
 	for (i = 0; i < g_list_length (logwindowlist); i++)
-		{
-			logwindow = g_list_nth_data (logwindowlist, i);
-			if (logwindow->logchanged)
 	{
-		logfile =
-			g_strconcat (preferences.savedir, G_DIR_SEPARATOR_S,
-			 logwindow->logname, ".xlog", NULL);
-		savelog (logwindow, logfile, TYPE_FLOG, 1, logwindow->qsos);
-		logwindow->logchanged = FALSE;
-		gtk_label_set_text (GTK_LABEL (logwindow->label),
-						logwindow->logname);
-		g_free (logfile);
-		message = TRUE;
-	}
+		logw = g_list_nth_data (logwindowlist, i);
+		if (logw->logchanged)
+		{
+			savelog (logw, logw->filename, TYPE_FLOG, 1, logw->qsos);
+			logw->logchanged = FALSE;
+			gtk_label_set_text (GTK_LABEL (logw->label), logw->logname);
+			message = TRUE;
 		}
+	}
 
 	if (message)
-		{
-			temp = g_strdup_printf (_("Log(s) autosaved"));
-			update_statusbar (temp);
-			g_free (temp);
-		}
+	{
+		temp = g_strdup_printf (_("Log(s) autosaved"));
+		update_statusbar (temp);
+		g_free (temp);
+	}
 	return 1;
 }
 
@@ -558,107 +580,122 @@ set_qsoframe (gpointer arg)
 		*locatorframe, *remarksvbox;
 	logtype *logw = (logtype *) arg;
 
-	for (i = 0; i < QSO_FIELDS; i++)
-		{
-			for (j = 0; j < logw->columns; j++)
+	endhbox = lookup_widget (mainwindow, "endhbox");
+	powerhbox = lookup_widget (mainwindow, "powerhbox");
+	qslhbox = lookup_widget (mainwindow, "qslhbox");
+	namehbox = lookup_widget (mainwindow, "namehbox");
+	qthhbox = lookup_widget (mainwindow, "qthhbox");
+	locatorhbox = lookup_widget (mainwindow, "locatorhbox");
+	locatorframe = lookup_widget (mainwindow, "locatorframe");
+	unknown1hbox = lookup_widget (mainwindow, "unknown1hbox");
+	unknown2hbox = lookup_widget (mainwindow, "unknown2hbox");
+	remarksvbox = lookup_widget (mainwindow, "remarksvbox");
+
+	if (logw) for (i = 0; i < QSO_FIELDS; i++)
 	{
+		for (j = 0; j < logw->columns; j++)
+		{
 		if (i == logw->logfields[j])
 			break;
-	}
-			if (i == GMTEND)
-	{
-		endhbox = lookup_widget (mainwindow, "endhbox");
-		if (j == logw->columns)
-			gtk_widget_hide (endhbox);
-		else
-			gtk_widget_show (endhbox);
-	}
-			else if (i == POWER)
-	{
-		powerhbox = lookup_widget (mainwindow, "powerhbox");
-		powerbutton = lookup_widget (mainwindow, "powerbutton");
-		powerlabel = lookup_widget (mainwindow, "powerlabel");
-		if (j == logw->columns)
-			gtk_widget_hide (powerhbox);
-		else
+		}
+		if (i == GMTEND)
+		{
+			if (j == logw->columns)
+				gtk_widget_hide (endhbox);
+			else
+				gtk_widget_show (endhbox);
+		}
+		else if (i == POWER)
+		{
+			powerbutton = lookup_widget (mainwindow, "powerbutton");
+			powerlabel = lookup_widget (mainwindow, "powerlabel");
+			if (j == logw->columns)
+				gtk_widget_hide (powerhbox);
+			else
 			{
 				gtk_widget_show (powerhbox);
 				if (preferences.hamlib > 0)
-		{
-			gtk_widget_show (powerbutton);
-			gtk_widget_hide (powerlabel);
-		}
+				{
+					gtk_widget_show (powerbutton);
+					gtk_widget_hide (powerlabel);
+				}
 				else
-		{
-			gtk_widget_hide (powerbutton);
-			gtk_widget_show (powerlabel);
-		}
+				{
+					gtk_widget_hide (powerbutton);
+					gtk_widget_show (powerlabel);
+				}
 			}
-	}
-			else if (i == QSLOUT)
-	{
-		qslhbox = lookup_widget (mainwindow, "qslhbox");
-		if (j == logw->columns)
-			gtk_widget_hide (qslhbox);
-		else
-			gtk_widget_show (qslhbox);
-	}
-			else if (i == NAME)
-	{
-		namehbox = lookup_widget (mainwindow, "namehbox");
-		if (j == logw->columns)
-			gtk_widget_hide (namehbox);
-		else
-			gtk_widget_show (namehbox);
-	}
-			else if (i == QTH)
-	{
-		qthhbox = lookup_widget (mainwindow, "qthhbox");
-		if (j == logw->columns)
-			gtk_widget_hide (qthhbox);
-		else
-			gtk_widget_show (qthhbox);
-	}
-			else if (i == LOCATOR)
-	{
-		locatorhbox = lookup_widget (mainwindow, "locatorhbox");
-		locatorframe = lookup_widget (mainwindow, "locatorframe");
-		if (j == logw->columns)
+		}
+		else if (i == QSLOUT)
+		{
+			if (j == logw->columns)
+				gtk_widget_hide (qslhbox);
+			else
+				gtk_widget_show (qslhbox);
+		}
+		else if (i == NAME)
+		{
+			if (j == logw->columns)
+				gtk_widget_hide (namehbox);
+			else
+				gtk_widget_show (namehbox);
+		}
+		else if (i == QTH)
+		{
+			if (j == logw->columns)
+				gtk_widget_hide (qthhbox);
+			else
+				gtk_widget_show (qthhbox);
+		}
+		else if (i == LOCATOR)
+		{
+			if (j == logw->columns)
 			{
 				gtk_widget_hide (locatorhbox);
 				gtk_widget_hide (locatorframe);
 			}
-		else
+			else
 			{
 				gtk_widget_show (locatorhbox);
 				gtk_widget_show (locatorframe);
 			}
-	}
-			else if (i == U1)
-	{
-		unknown1hbox = lookup_widget (mainwindow, "unknown1hbox");
-		if (j == logw->columns)
-			gtk_widget_hide (unknown1hbox);
-		else
-			gtk_widget_show (unknown1hbox);
-	}
-			else if (i == U2)
-	{
-		unknown2hbox = lookup_widget (mainwindow, "unknown2hbox");
-		if (j == logw->columns)
-			gtk_widget_hide (unknown2hbox);
-		else
-			gtk_widget_show (unknown2hbox);
-	}
-			else if (i == REMARKS)
-	{
-		remarksvbox = lookup_widget (mainwindow, "remarksvbox");
-		if (j == logw->columns)
-			gtk_widget_hide (remarksvbox);
-		else
-			gtk_widget_show (remarksvbox);
-	}
 		}
+		else if (i == U1)
+		{
+			if (j == logw->columns)
+				gtk_widget_hide (unknown1hbox);
+			else
+				gtk_widget_show (unknown1hbox);
+		}
+		else if (i == U2)
+		{
+			if (j == logw->columns)
+				gtk_widget_hide (unknown2hbox);
+			else
+				gtk_widget_show (unknown2hbox);
+		}
+		else if (i == REMARKS)
+		{
+			if (j == logw->columns)
+				gtk_widget_hide (remarksvbox);
+			else
+				gtk_widget_show (remarksvbox);
+		}
+	}
+	else
+	{
+		gtk_widget_hide (endhbox);
+		gtk_widget_show (qslhbox);
+		gtk_widget_hide (powerhbox);
+		gtk_widget_hide (namehbox);
+		gtk_widget_hide (qthhbox);
+		gtk_widget_hide (locatorhbox);
+		gtk_widget_hide (locatorframe);
+		gtk_widget_hide (endhbox);
+		gtk_widget_hide (unknown1hbox);
+		gtk_widget_hide (unknown2hbox);
+		gtk_widget_show (remarksvbox);
+	}
 }
 
 gboolean
