@@ -218,12 +218,17 @@ wwl (gchar * my, gchar * dx)
 
 	p = (gint) (atan (sqrt (d) / c) * 6371.33) + .5;
 	if (p < 0) p = 20002 + p;
-	m = (gint) (p * 1.609);
+	if (p < 1) p = 0;
+	m = (gint) (p / 1.609);
 
-	if (preferences.units == 1)
-		result = g_strdup_printf (_("Distance: %d km, azimuth: %d deg"), p, l);
-	else
-		result = g_strdup_printf (_("Distance: %d m, azimuth: %d deg"), m, l);
+	if (p != 0)
+	{
+		if (preferences.units == 1)
+			result = g_strdup_printf (_("Distance: %d km, azimuth: %d deg"), p, l);
+		else
+			result = g_strdup_printf (_("Distance: %d m, azimuth: %d deg"), m, l);
+	}
+	else result = g_strdup ("");
 	return (result);
 }
 
